@@ -9,7 +9,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2004, VIZRT Inc.
- * Copyright (c) 2008-2014, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2014, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -47,15 +47,12 @@
 #include "cpl_error.h"
 #include "cpl_vsi.h"
 
-CPL_CVSID("$Id: thinplatespline.cpp 9ff327806cd64df6d73a6c91f92d12ca0c5e07df 2018-04-07 20:25:06 +0200 Even Rouault $")
+CPL_CVSID("$Id: thinplatespline.cpp 5426fbb5939ec949739e29d63c02930a2e1788a2 2019-09-02 21:19:22 +0200 mamofejo $")
 
 //////////////////////////////////////////////////////////////////////////////
 //// vizGeorefSpline2D
 //////////////////////////////////////////////////////////////////////////////
 
-#define A(r,c) _AA[ _nof_eqs * (r) + (c) ]
-#define Ainv(r,c) _Ainv[ _nof_eqs * (r) + (c) ]
-
 // #define VIZ_GEOREF_SPLINE_DEBUG 0
 
 bool VizGeorefSpline2D::grow_points()
@@ -559,21 +556,21 @@ int VizGeorefSpline2D::solve()
         return 0;
     }
 
-    double* _AA = static_cast<double *>(
-        VSI_CALLOC_VERBOSE(_nof_eqs * _nof_eqs, sizeof(double)));
-
-    if( _AA == nullptr )
+    GDALMatrix A(_nof_eqs, _nof_eqs);
+    x_mean = 0;
+    y_mean = 0;
+    for( int c = 0; c < _nof_points; c++ )
     {
-        return 0;
+        x_mean += x[c];
+        y_mean += y[c];
     }
-
-    // Calc the values of the matrix A.
-    for( int r = 0; r < 3; r++ )
-        for( int c = 0; c < 3; c++ )
-            A(r, c) = 0.0;
+    x_mean /= _nof_points;
+    y_mean /= _nof_points;
 
     for( int c = 0; c < _nof_points; c++ )
     {
+        x[c] -= x_mean;
+        y[c] -= y_mean;
         A(0, c+3) = 1.0;
         A(1, c+3) = x[c];
         A(2, c+3) = y[c];
@@ -602,28 +599,21 @@ int VizGeorefSpline2D::solve()
 
 #endif
 
-    double* adfRHS = static_cast<double*>(VSICalloc( _nof_eqs * _nof_vars, sizeof(double) ));
+    GDALMatrix RHS(_nof_eqs, _nof_vars);
     for( int iRHS = 0; iRHS < _nof_vars; iRHS++ )
         for( int iRow = 0; iRow < _nof_eqs; iRow++ )
-            adfRHS[iRow * _nof_vars + iRHS] = rhs[iRHS][iRow];
+            RHS(iRow, iRHS) = rhs[iRHS][iRow];
 
-    double* adfCoef = static_cast<double*>(VSICalloc( _nof_eqs * _nof_vars, sizeof(double) ));
+    GDALMatrix Coef(_nof_eqs, _nof_vars);
 
-    if( !GDALLinearSystemSolve( _nof_eqs, _nof_vars, _AA, adfRHS, adfCoef ) )
+    if( !GDALLinearSystemSolve(A, RHS, Coef ) )
     {
-        VSIFree(adfRHS);
-        VSIFree(adfCoef);
-        VSIFree(_AA);
         return 0;
     }
 
     for( int iRHS = 0; iRHS < _nof_vars; iRHS++ )
         for( int iRow = 0; iRow < _nof_eqs; iRow++ )
-            coef[iRHS][iRow] = adfCoef[iRow * _nof_vars + iRHS];
-
-    VSIFree(adfRHS);
-    VSIFree(adfCoef);
-    VSIFree(_AA);
+            coef[iRHS][iRow] = Coef(iRow, iRHS);
 
     return 4;
 }
@@ -686,9 +676,9 @@ int VizGeorefSpline2D::get_point( const double Px, const double Py,
     }
     case VIZ_GEOREF_SPLINE_FULL:
     {
-        const double Pxy[2] = { Px, Py };
+        const double Pxy[2] = { Px - x_mean, Py -y_mean };
         for( int v = 0; v < _nof_vars; v++ )
-            vars[v] = coef[v][0] + coef[v][1] * Px + coef[v][2] * Py;
+            vars[v] = coef[v][0] + coef[v][1] * Pxy[0] + coef[v][2] * Pxy[1];
 
         int r = 0;  // Used after for.
         for( ; r < (_nof_points & (~3)); r+=4 )
@@ -703,7 +693,7 @@ int VizGeorefSpline2D::get_point( const double Px, const double Py,
         }
         for( ; r < _nof_points; r++ )
         {
-            const double tmp = VizGeorefSpline2DBase_func( Px, Py, x[r], y[r] );
+            const double tmp = VizGeorefSpline2DBase_func( Pxy[0], Pxy[1], x[r], y[r] );
             for( int v= 0; v < _nof_vars; v++ )
                 vars[v] += coef[v][r+3] * tmp;
         }
