@@ -6,7 +6,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2003, Applied Coherent Technology (www.actgate.com).
- * Copyright (c) 2008-2013, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2013, Even Rouault <even dot rouault at spatialys.com>
  * Copyright (c) 2018, Oslandia <infos at oslandia dot com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -37,7 +37,7 @@
 #include "ogr_srs_api.h"
 #include "commonutils.h"
 
-CPL_CVSID("$Id: gdal_contour.cpp 15d54f60967d9c0d7d63fe22caa6600c50a533a8 2019-04-30 13:00:55 +0200 Even Rouault $")
+CPL_CVSID("$Id: gdal_contour.cpp b04ca419afe96b637a7b77773997361cf605e88f 2019-11-28 16:14:29 +0100 Even Rouault $")
 
 /************************************************************************/
 /*                            ArgIsNumeric()                            */
@@ -150,31 +150,37 @@ MAIN_START(argc, argv)
         else if( EQUAL(argv[i],"-a") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             pszElevAttrib = argv[++i];
         }
         else if( EQUAL(argv[i],"-amin") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             pszElevAttribMin = argv[++i];
         }
         else if( EQUAL(argv[i],"-amax") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             pszElevAttribMax = argv[++i];
         }
         else if( EQUAL(argv[i],"-off") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             dfOffset = CPLAtof(argv[++i]);
         }
         else if( EQUAL(argv[i],"-i") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             dfInterval = CPLAtof(argv[++i]);
         }
         else if( EQUAL(argv[i],"-e") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             dfExpBase = CPLAtof(argv[++i]);
         }
         else if( EQUAL(argv[i],"-p") )
@@ -190,26 +196,31 @@ MAIN_START(argc, argv)
                    && nFixedLevelCount
                    < static_cast<int>(sizeof(adfFixedLevels)/sizeof(double))
                    && ArgIsNumeric(argv[i+1]) )
+                // coverity[tainted_data]
                 adfFixedLevels[nFixedLevelCount++] = CPLAtof(argv[++i]);
         }
         else if( EQUAL(argv[i],"-b") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             nBandIn = atoi(argv[++i]);
         }
         else if( EQUAL(argv[i],"-f") || EQUAL(argv[i],"-of") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             pszFormat = argv[++i];
         }
         else if( EQUAL(argv[i],"-dsco") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             papszDSCO = CSLAddString(papszDSCO, argv[++i] );
         }
         else if( EQUAL(argv[i],"-lco") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             papszLCO = CSLAddString(papszLCO, argv[++i] );
         }
         else if( EQUAL(argv[i],"-3d")  )
@@ -220,11 +231,13 @@ MAIN_START(argc, argv)
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
             bNoDataSet = TRUE;
+            // coverity[tainted_data]
             dfNoData = CPLAtof(argv[++i]);
         }
         else if( EQUAL(argv[i],"-nln") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            // coverity[tainted_data]
             pszNewLayerName = argv[++i];
         }
         else if( EQUAL(argv[i],"-inodata") )
@@ -262,6 +275,12 @@ MAIN_START(argc, argv)
         Usage("Missing destination filename.");
     }
 
+    if( strcmp(pszDstFilename, "/vsistdout/") == 0 ||
+        strcmp(pszDstFilename, "/dev/stdout") == 0 )
+    {
+        bQuiet = true;
+    }
+
     if (!bQuiet)
         pfnProgress = GDALTermProgress;
 
