@@ -29,10 +29,11 @@
 #include "cpl_vsi.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
+#include "gdal_version"
 #include "gdal_priv.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: gdalasyncread.cpp 35931 2016-10-25 16:20:52Z goatbar $");
+CPL_CVSID("$Id: gdalasyncread.cpp 2809cd757416b752b5c316c2a72dfa2d923e9e81 2018-07-19 10:58:35 +0900 Hiroshi Miura $")
 
 /* ******************************************************************** */
 /*                               Usage()                                */
@@ -57,9 +58,9 @@ static void Usage()
     {
         GDALDriverH hDriver = GDALGetDriver(iDr);
 
-        if( GDALGetMetadataItem( hDriver, GDAL_DCAP_CREATE, NULL ) != NULL
+        if( GDALGetMetadataItem( hDriver, GDAL_DCAP_CREATE, nullptr ) != nullptr
             || GDALGetMetadataItem( hDriver, GDAL_DCAP_CREATECOPY,
-                                    NULL ) != NULL )
+                                    nullptr ) != nullptr )
         {
             printf( "  %s: %s\n",
                     GDALGetDriverShortName( hDriver ),
@@ -76,23 +77,23 @@ int main( int argc, char ** argv )
 
 {
     GDALDatasetH        hSrcDS, hDstDS;
-    GDALDataset *       poSrcDS, *poDstDS = NULL;
+    GDALDataset *       poSrcDS, *poDstDS = nullptr;
     int                 i;
     int                 nRasterXSize, nRasterYSize;
-    const char          *pszSource=NULL, *pszDest=NULL, *pszFormat = "GTiff";
+    const char          *pszSource=nullptr, *pszDest=nullptr, *pszFormat = "GTiff";
     GDALDriverH         hDriver;
-    int                 *panBandList = NULL, nBandCount = 0, bDefBands = TRUE;
+    int                 *panBandList = nullptr, nBandCount = 0, bDefBands = TRUE;
     GDALDataType        eOutputType = GDT_Unknown;
     int                 nOXSize = 0, nOYSize = 0;
-    char                **papszCreateOptions = NULL;
-    char                **papszAsyncOptions = NULL;
+    char                **papszCreateOptions = nullptr;
+    char                **papszAsyncOptions = nullptr;
     int                 anSrcWin[4];
     int                 bQuiet = FALSE;
     GDALProgressFunc    pfnProgress = GDALTermProgress;
     int                 iSrcFileArg = -1, iDstFileArg = -1;
     int                 bMulti = FALSE;
     double              dfTimeout = -1.0;
-    const char          *pszOXSize = NULL, *pszOYSize = NULL;
+    const char          *pszOXSize = nullptr, *pszOYSize = nullptr;
 
     anSrcWin[0] = 0;
     anSrcWin[1] = 0;
@@ -123,7 +124,7 @@ int main( int argc, char ** argv )
                    argv[0], GDAL_RELEASE_NAME, GDALVersionInfo("RELEASE_NAME"));
             return 0;
         }
-        else if( EQUAL(argv[i],"-of") && i < argc-1 )
+        else if( (EQUAL(argv[i],"-of") || EQUAL(argv[i],"-f")) && i < argc-1 )
             pszFormat = argv[++i];
 
         else if( EQUAL(argv[i],"-quiet") )
@@ -136,7 +137,7 @@ int main( int argc, char ** argv )
         {
             for( int iType = 1; iType < GDT_TypeCount; iType++ )
             {
-                if( GDALGetDataTypeName((GDALDataType)iType) != NULL
+                if( GDALGetDataTypeName((GDALDataType)iType) != nullptr
                     && EQUAL(GDALGetDataTypeName((GDALDataType)iType),
                              argv[i+1]) )
                 {
@@ -165,8 +166,8 @@ int main( int argc, char ** argv )
             }
 
             nBandCount++;
-            panBandList = (int *)
-                CPLRealloc(panBandList, sizeof(int) * nBandCount);
+            panBandList = static_cast<int *>(
+                CPLRealloc(panBandList, sizeof(int) * nBandCount));
             panBandList[nBandCount-1] = atoi(argv[++i]);
 
             if( panBandList[nBandCount-1] != nBandCount )
@@ -213,12 +214,12 @@ int main( int argc, char ** argv )
             GDALDestroyDriverManager();
             exit( 2 );
         }
-        else if( pszSource == NULL )
+        else if( pszSource == nullptr )
         {
             iSrcFileArg = i;
             pszSource = argv[i];
         }
-        else if( pszDest == NULL )
+        else if( pszDest == nullptr )
         {
             pszDest = argv[i];
             iDstFileArg = i;
@@ -233,7 +234,7 @@ int main( int argc, char ** argv )
         }
     }
 
-    if( pszDest == NULL )
+    if( pszDest == nullptr )
     {
         Usage();
         GDALDestroyDriverManager();
@@ -254,7 +255,7 @@ int main( int argc, char ** argv )
     hSrcDS = GDALOpenShared( pszSource, GA_ReadOnly );
     poSrcDS = (GDALDataset *) hSrcDS;
 
-    if( hSrcDS == NULL )
+    if( hSrcDS == nullptr )
     {
         fprintf( stderr,
                  "GDALOpen failed - %d\n%s\n",
@@ -281,16 +282,16 @@ int main( int argc, char ** argv )
 /* -------------------------------------------------------------------- */
 /*      Establish output size.                                          */
 /* -------------------------------------------------------------------- */
-    if( pszOXSize == NULL )
+    if( pszOXSize == nullptr )
     {
         nOXSize = anSrcWin[2];
         nOYSize = anSrcWin[3];
     }
     else
     {
-        nOXSize = (int) ((pszOXSize[strlen(pszOXSize)-1]=='%'
+        nOXSize = static_cast<int>((pszOXSize[strlen(pszOXSize)-1]=='%'
                           ? CPLAtof(pszOXSize)/100*anSrcWin[2] : atoi(pszOXSize)));
-        nOYSize = (int) ((pszOYSize[strlen(pszOYSize)-1]=='%'
+        nOYSize = static_cast<int>((pszOYSize[strlen(pszOYSize)-1]=='%'
                           ? CPLAtof(pszOYSize)/100*anSrcWin[3] : atoi(pszOYSize)));
     }
 
@@ -307,7 +308,7 @@ int main( int argc, char ** argv )
             exit(1 );
         }
 
-        panBandList = (int *) CPLMalloc(sizeof(int)*nBandCount);
+        panBandList = static_cast<int *>(CPLMalloc(sizeof(int) * nBandCount));
         for( i = 0; i < nBandCount; i++ )
             panBandList[i] = i+1;
     }
@@ -354,25 +355,25 @@ int main( int argc, char ** argv )
 /* -------------------------------------------------------------------- */
     hDriver = GDALGetDriverByName( pszFormat );
 
-    if( hDriver == NULL )
+    if( hDriver == nullptr )
     {
         printf( "Output driver `%s' not recognised.\n", pszFormat );
     }
-    else if( GDALGetMetadataItem( hDriver, GDAL_DCAP_CREATE, NULL ) == NULL )
+    else if( GDALGetMetadataItem( hDriver, GDAL_DCAP_CREATE, nullptr ) == nullptr )
     {
         printf( "Output driver '%s' does not support direct creation.\n",
                 pszFormat );
-        hDriver = NULL;
+        hDriver = nullptr;
     }
 
-    if( hDriver == NULL )
+    if( hDriver == nullptr )
     {
         printf( "The following format drivers are configured and support output:\n" );
         for( int iDr = 0; iDr < GDALGetDriverCount(); iDr++ )
         {
             GDALDriverH hDriver = GDALGetDriver(iDr);
 
-            if( GDALGetMetadataItem( hDriver, GDAL_DCAP_CREATE, NULL ) != NULL )
+            if( GDALGetMetadataItem( hDriver, GDAL_DCAP_CREATE, nullptr ) != nullptr )
             {
                 printf( "  %s: %s\n",
                         GDALGetDriverShortName( hDriver  ),
@@ -402,9 +403,9 @@ int main( int argc, char ** argv )
 /* -------------------------------------------------------------------- */
     const int nBytesPerPixel =
         nBandCount * GDALGetDataTypeSizeBytes(eOutputType);
-    void *pImage = VSIMalloc3( nOXSize, nOYSize, nBytesPerPixel );
+    void *pImage = VSIMalloc3(nOXSize, nOYSize, nBytesPerPixel);
 
-    if( pImage == NULL )
+    if( pImage == nullptr )
     {
         printf( "Unable to allocate %dx%dx%d byte window buffer.\n",
                 nOXSize, nOYSize, nBytesPerPixel );
@@ -425,7 +426,7 @@ int main( int argc, char ** argv )
         nBandCount, panBandList,
         nPixelSpace, nLineSpace, nBandSpace, papszAsyncOptions );
 
-    if( poAsyncReq == NULL )
+    if( poAsyncReq == nullptr )
         exit( 1 );
 
 /* -------------------------------------------------------------------- */
@@ -435,14 +436,14 @@ int main( int argc, char ** argv )
     CPLErr eErr = CE_None;
     int iMultiCounter = 0;
 
-    hDstDS = NULL;
+    hDstDS = nullptr;
 
     do
     {
 /* ==================================================================== */
 /*      Create the output file, and initialize if needed.               */
 /* ==================================================================== */
-        if( hDstDS == NULL )
+        if( hDstDS == nullptr )
         {
             CPLString osOutFilename = pszDest;
 
@@ -452,7 +453,7 @@ int main( int argc, char ** argv )
             hDstDS = GDALCreate( hDriver, osOutFilename, nOXSize, nOYSize,
                                  nBandCount, eOutputType,
                                  papszCreateOptions );
-            if (hDstDS == NULL)
+            if (hDstDS == nullptr)
             {
                 exit(1);
             }
@@ -516,8 +517,8 @@ int main( int argc, char ** argv )
                                + nUpXOff * nPixelSpace
                                + nUpYOff * nLineSpace,
                                nUpXSize, nUpYSize, eOutputType,
-                               nBandCount, NULL,
-                               nPixelSpace, nLineSpace, nBandSpace, NULL );
+                               nBandCount, nullptr,
+                               nPixelSpace, nLineSpace, nBandSpace, nullptr );
         poAsyncReq->UnlockBuffer();
 
 /* -------------------------------------------------------------------- */
@@ -527,7 +528,7 @@ int main( int argc, char ** argv )
         if( bMulti )
         {
             GDALClose( hDstDS );
-            hDstDS = NULL;
+            hDstDS = nullptr;
         }
         else
         {
