@@ -35,7 +35,7 @@
 #include <limits>
 #include <set>
 
-CPL_CVSID("$Id: gdalmdiminfo_lib.cpp b309b2f9b4b2fe3551a58be94a6914b7f135ac78 2020-01-27 16:30:33 +0100 Even Rouault $")
+CPL_CVSID("$Id: gdalmdiminfo_lib.cpp 2e6733101e6356653e8c999cb7fe808abc22ed11 2020-08-11 14:57:51 +0200 Even Rouault $")
 
 /************************************************************************/
 /*                       GDALMultiDimInfoOptions                        */
@@ -49,6 +49,7 @@ struct GDALMultiDimInfoOptions
     size_t nLimitValuesByDim = 0;
     CPLStringList aosArrayOptions{};
     std::string osArrayName{};
+    bool bStats = false;
 };
 
 /************************************************************************/
@@ -600,7 +601,8 @@ static void DumpStructuralInfo(CSLConstList papszStructuralInfo,
 /*                             DumpArray()                              */
 /************************************************************************/
 
-static void DumpArray(std::shared_ptr<GDALMDArray> array,
+static void DumpArray(GDALDataset* poDS,
+                      std::shared_ptr<GDALMDArray> array,
                      CPLJSonStreamingWriter& serializer,
                      const GDALMultiDimInfoOptions *psOptions,
                      std::set<std::string>& alreadyDumpedDimensions,
@@ -717,13 +719,48 @@ static void DumpArray(std::shared_ptr<GDALMDArray> array,
             DumpArrayRec(array, serializer, 0, dimSizes, startIdx, psOptions);
         }
     }
+
+    if( psOptions->bStats )
+    {
+        double dfMin = 0.0;
+        double dfMax = 0.0;
+        double dfMean = 0.0;
+        double dfStdDev = 0.0;
+        GUInt64 nValidCount = 0;
+        if( array->GetStatistics( poDS, false, true,
+                              &dfMin, &dfMax, &dfMean, &dfStdDev,
+                              &nValidCount,
+                              nullptr, nullptr ) == CE_None )
+        {
+            serializer.AddObjKey("statistics");
+            auto statContext(serializer.MakeObjectContext());
+            if( nValidCount > 0 )
+            {
+                serializer.AddObjKey("min");
+                serializer.Add(dfMin);
+
+                serializer.AddObjKey("max");
+                serializer.Add(dfMax);
+
+                serializer.AddObjKey("mean");
+                serializer.Add(dfMean);
+
+                serializer.AddObjKey("stddev");
+                serializer.Add(dfStdDev);
+            }
+
+            serializer.AddObjKey("valid_sample_count");
+            serializer.Add(nValidCount);
+        }
+    }
 }
 
 /************************************************************************/
 /*                            DumpArrays()                              */
 /************************************************************************/
 
-static void DumpArrays(std::shared_ptr<GDALGroup> group,
+static void DumpArrays(GDALDataset* poDS,
+                       std::shared_ptr<GDALGroup> group,
                        const std::vector<std::string>& arrayNames,
                        CPLJSonStreamingWriter& serializer,
                        const GDALMultiDimInfoOptions *psOptions,
@@ -740,7 +777,7 @@ static void DumpArrays(std::shared_ptr<GDALGroup> group,
         if( array )
         {
             serializer.AddObjKey(array->GetName());
-            DumpArray( array, serializer, psOptions,
+            DumpArray( poDS, array, serializer, psOptions,
                        alreadyDumpedDimensions, false, false );
         }
     }
@@ -750,7 +787,8 @@ static void DumpArrays(std::shared_ptr<GDALGroup> group,
 /*                             DumpGroup()                              */
 /************************************************************************/
 
-static void DumpGroup(std::shared_ptr<GDALGroup> group,
+static void DumpGroup(GDALDataset* poDS,
+                      std::shared_ptr<GDALGroup> group,
                       const char* pszDriverName,
                       CPLJSonStreamingWriter& serializer,
                       const GDALMultiDimInfoOptions *psOptions,
@@ -798,7 +836,7 @@ static void DumpGroup(std::shared_ptr<GDALGroup> group,
     if( !arrayNames.empty() )
     {
         serializer.AddObjKey("arrays");
-        DumpArrays(group, arrayNames, serializer, psOptions,
+        DumpArrays(poDS, group, arrayNames, serializer, psOptions,
                    alreadyDumpedDimensions);
     }
 
@@ -822,7 +860,7 @@ static void DumpGroup(std::shared_ptr<GDALGroup> group,
                 if( subgroup )
                 {
                     serializer.AddObjKey(subgroupName);
-                    DumpGroup( subgroup, nullptr, serializer, psOptions,
+                    DumpGroup( poDS, subgroup, nullptr, serializer, psOptions,
                                alreadyDumpedDimensions, false, false );
                 }
             }
@@ -835,7 +873,7 @@ static void DumpGroup(std::shared_ptr<GDALGroup> group,
                 auto subgroup = group->OpenGroup(subgroupName);
                 if( subgroup )
                 {
-                    DumpGroup( subgroup, nullptr, serializer, psOptions,
+                    DumpGroup( poDS, subgroup, nullptr, serializer, psOptions,
                                alreadyDumpedDimensions, false, true );
                 }
             }
@@ -883,7 +921,8 @@ char *GDALMultiDimInfo( GDALDatasetH hDataset,
         psOptions->bStdoutOutput ? WriteToStdout : nullptr ,
         nullptr);
     serializer.SetPrettyFormatting(psOptions->bPretty);
-    auto group = GDALDataset::FromHandle(hDataset)->GetRootGroup();
+    GDALDataset* poDS = GDALDataset::FromHandle(hDataset);
+    auto group = poDS->GetRootGroup();
     if( !group )
         return nullptr;
 
@@ -893,10 +932,10 @@ char *GDALMultiDimInfo( GDALDatasetH hDataset,
         if( psOptions->osArrayName.empty() )
         {
             const char* pszDriverName = nullptr;
-            auto poDriver = GDALDataset::FromHandle(hDataset)->GetDriver();
+            auto poDriver = poDS->GetDriver();
             if( poDriver )
                 pszDriverName = poDriver->GetDescription();
-            DumpGroup(group, pszDriverName, serializer, psOptions,
+            DumpGroup(poDS, group, pszDriverName, serializer, psOptions,
                       alreadyDumpedDimensions, true, true);
         }
         else
@@ -922,7 +961,7 @@ char *GDALMultiDimInfo( GDALDatasetH hDataset,
                          "Cannot find array %s", pszArrayName);
                 return nullptr;
             }
-            DumpArray(array, serializer, psOptions,
+            DumpArray(poDS, array, serializer, psOptions,
                       alreadyDumpedDimensions, true, true);
         }
     }
@@ -1004,6 +1043,10 @@ GDALMultiDimInfoOptions *GDALMultiDimInfoOptionsNew(
             ++i;
             psOptions->nLimitValuesByDim = atoi(papszArgv[i]);
         }
+        else if( EQUAL(papszArgv[i], "-stats") )
+        {
+            psOptions->bStats = true;
+        }
         else if( papszArgv[i][0] == '-' )
         {
             CPLError(CE_Failure, CPLE_NotSupported,
