@@ -6,7 +6,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2007, Frank Warmerdam <warmerdam@pobox.com>
- * Copyright (c) 2008-2013, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2013, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -46,7 +46,13 @@
 #include "ogr_srs_api.h"
 #include "commonutils.h"
 
-CPL_CVSID("$Id: gdaltransform.cpp 9bae05435e199592be48a2a6c8ef5f649fa5d113 2018-03-26 14:16:35 +0200 Even Rouault $")
+#ifdef _WIN32
+#include <io.h>
+#else
+#include <unistd.h>
+#endif
+
+CPL_CVSID("$Id: gdaltransform.cpp 900cac300559af80bca19917f9acd1915c13995e 2019-08-12 22:17:29 +0200 Even Rouault $")
 
 /************************************************************************/
 /*                               Usage()                                */
@@ -58,7 +64,7 @@ static void Usage(const char* pszErrorMsg = nullptr)
     printf(
         "Usage: gdaltransform [--help-general]\n"
         "    [-i] [-s_srs srs_def] [-t_srs srs_def] [-to \"NAME=VALUE\"]\n"
-        "    [-order n] [-tps] [-rpc] [-geoloc] \n"
+        "    [-ct proj_string] [-order n] [-tps] [-rpc] [-geoloc] \n"
         "    [-gcp pixel line easting northing [elevation]]* [-output_xy]\n"
         "    [srcfile [dstfile]]\n"
         "\n" );
@@ -70,31 +76,29 @@ static void Usage(const char* pszErrorMsg = nullptr)
 }
 
 /************************************************************************/
-/*                             SanitizeSRS                              */
+/*                             IsValidSRS                               */
 /************************************************************************/
 
-static char *SanitizeSRS( const char *pszUserInput )
+static bool IsValidSRS( const char *pszUserInput )
 
 {
+    OGRSpatialReferenceH hSRS;
+    bool bRes = true;
+
     CPLErrorReset();
 
-    char *pszResult = nullptr;
-    OGRSpatialReferenceH hSRS = OSRNewSpatialReference(nullptr);
-    if( OSRSetFromUserInput( hSRS, pszUserInput ) == OGRERR_NONE )
-    {
-        OSRExportToWkt( hSRS, &pszResult );
-    }
-    else
+    hSRS = OSRNewSpatialReference( nullptr );
+    if( OSRSetFromUserInput( hSRS, pszUserInput ) != OGRERR_NONE )
     {
+        bRes = false;
         CPLError( CE_Failure, CPLE_AppDefined,
                   "Translating source or target SRS failed:\n%s",
                   pszUserInput );
-        exit( 1 );
     }
 
     OSRDestroySpatialReference( hSRS );
 
-    return pszResult;
+    return bRes;
 }
 
 /************************************************************************/
@@ -133,11 +137,12 @@ MAIN_START(argc, argv)
     int                 nGCPCount = 0;
     GDAL_GCP            *pasGCPs = nullptr;
     int                 bInverse = FALSE;
-    char              **papszTO = nullptr;
+    CPLStringList       aosTO;
     int                 bOutputXY = FALSE;
     double              dfX = 0.0;
     double              dfY = 0.0;
     double              dfZ = 0.0;
+    double              dfT = 0.0;
     bool                bCoordOnCommandLine = false;
 
 /* -------------------------------------------------------------------- */
@@ -160,35 +165,44 @@ MAIN_START(argc, argv)
         else if( EQUAL(argv[i],"-t_srs") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
-            char *pszSRS = SanitizeSRS(argv[++i]);
-            papszTO = CSLSetNameValue( papszTO, "DST_SRS", pszSRS );
-            CPLFree( pszSRS );
+            const char *pszSRS = argv[++i];
+            if( !IsValidSRS(pszSRS) )
+                exit(1);
+            aosTO.SetNameValue("DST_SRS", pszSRS );
         }
         else if( EQUAL(argv[i],"-s_srs") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
-            char *pszSRS = SanitizeSRS(argv[++i]);
-            papszTO = CSLSetNameValue( papszTO, "SRC_SRS", pszSRS );
-            CPLFree( pszSRS );
+            const char *pszSRS = argv[++i];
+            // coverity[tainted_data]
+            if( !IsValidSRS(pszSRS) )
+                exit(1);
+            aosTO.SetNameValue("SRC_SRS", pszSRS );
+        }
+        else if( EQUAL(argv[i],"-ct") )
+        {
+            CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
+            const char *pszCT = argv[++i];
+            aosTO.SetNameValue("COORDINATE_OPERATION", pszCT );
         }
         else if( EQUAL(argv[i],"-order") )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
             nOrder = atoi(argv[++i]);
-            papszTO = CSLSetNameValue( papszTO, "MAX_GCP_ORDER", argv[i] );
+            aosTO.SetNameValue("MAX_GCP_ORDER", argv[i] );
         }
         else if( EQUAL(argv[i],"-tps") )
         {
-            papszTO = CSLSetNameValue( papszTO, "METHOD", "GCP_TPS" );
+            aosTO.SetNameValue("METHOD", "GCP_TPS" );
             nOrder = -1;
         }
         else if( EQUAL(argv[i],"-rpc") )
         {
-            papszTO = CSLSetNameValue( papszTO, "METHOD", "RPC" );
+            aosTO.SetNameValue("METHOD", "RPC" );
         }
         else if( EQUAL(argv[i],"-geoloc") )
         {
-            papszTO = CSLSetNameValue( papszTO, "METHOD", "GEOLOC_ARRAY" );
+            aosTO.SetNameValue("METHOD", "GEOLOC_ARRAY" );
         }
         else if( EQUAL(argv[i],"-i") )
         {
@@ -197,7 +211,7 @@ MAIN_START(argc, argv)
         else if( EQUAL(argv[i],"-to")  )
         {
             CHECK_HAS_ENOUGH_ADDITIONAL_ARGS(1);
-            papszTO = CSLAddString( papszTO, argv[++i] );
+            aosTO.AddString( argv[++i] );
         }
         else if( EQUAL(argv[i],"-gcp") )
         {
@@ -210,9 +224,13 @@ MAIN_START(argc, argv)
                 CPLRealloc(pasGCPs, sizeof(GDAL_GCP) * nGCPCount));
             GDALInitGCPs( 1, pasGCPs + nGCPCount - 1 );
 
+            // coverity[tainted_data]
             pasGCPs[nGCPCount-1].dfGCPPixel = CPLAtof(argv[++i]);
+            // coverity[tainted_data]
             pasGCPs[nGCPCount-1].dfGCPLine = CPLAtof(argv[++i]);
+            // coverity[tainted_data]
             pasGCPs[nGCPCount-1].dfGCPX = CPLAtof(argv[++i]);
+            // coverity[tainted_data]
             pasGCPs[nGCPCount-1].dfGCPY = CPLAtof(argv[++i]);
             if( argv[i+1] != nullptr &&
                 (CPLStrtod(argv[i+1], &endptr) != 0.0 || argv[i+1][0] == '0') )
@@ -220,7 +238,10 @@ MAIN_START(argc, argv)
                 // Check that last argument is really a number and not a
                 // filename looking like a number (see ticket #863).
                 if (endptr && *endptr == 0)
+                {
+                    // coverity[tainted_data]
                     pasGCPs[nGCPCount-1].dfGCPZ = CPLAtof(argv[++i]);
+                }
             }
 
             /* should set id and info? */
@@ -236,7 +257,8 @@ MAIN_START(argc, argv)
             dfY = CPLAtof(argv[++i]);
             if( i + 1 < argc && CPLGetValueType(argv[i+1]) != CPL_VALUE_STRING )
                 dfZ = CPLAtof(argv[++i]);
-            bOutputXY = TRUE;
+            if( i + 1 < argc && CPLGetValueType(argv[i+1]) != CPL_VALUE_STRING )
+                dfT = CPLAtof(argv[++i]);
         }
         else if( argv[i][0] == '-' )
         {
@@ -303,11 +325,9 @@ MAIN_START(argc, argv)
     {
         pfnTransformer = GDALGenImgProjTransform;
         hTransformArg =
-            GDALCreateGenImgProjTransformer2( hSrcDS, hDstDS, papszTO );
+            GDALCreateGenImgProjTransformer2( hSrcDS, hDstDS, aosTO.List() );
     }
 
-    CSLDestroy( papszTO );
-
     if( hTransformArg == nullptr )
     {
         exit( 1 );
@@ -316,6 +336,24 @@ MAIN_START(argc, argv)
 /* -------------------------------------------------------------------- */
 /*      Read points from stdin, transform and write to stdout.          */
 /* -------------------------------------------------------------------- */
+    double dfLastT = 0.0;
+    
+    if( !bCoordOnCommandLine )
+    {
+        // Is it an interactive terminal ?
+        if( isatty(static_cast<int>(fileno(stdin))) )
+        {
+            if( pszSrcFilename != nullptr )
+            {
+                fprintf(stderr, "Enter column line values separated by space, and press Return.\n");
+            }
+            else
+            {
+                fprintf(stderr, "Enter X Y [Z [T]] values separated by space, and press Return.\n");
+            }
+        }
+    }
+
     while( bCoordOnCommandLine || !feof(stdin) )
     {
         if( !bCoordOnCommandLine )
@@ -326,8 +364,9 @@ MAIN_START(argc, argv)
                 break;
 
             char **papszTokens = CSLTokenizeString(szLine);
+            const int nCount = CSLCount(papszTokens);
 
-            if( CSLCount(papszTokens) < 2 )
+            if( nCount < 2 )
             {
                 CSLDestroy(papszTokens);
                 continue;
@@ -335,12 +374,30 @@ MAIN_START(argc, argv)
 
             dfX = CPLAtof(papszTokens[0]);
             dfY = CPLAtof(papszTokens[1]);
-            if( CSLCount(papszTokens) >= 3 )
+            if( nCount >= 3 )
                 dfZ = CPLAtof(papszTokens[2]);
             else
                 dfZ = 0.0;
+            if( nCount == 4 )
+                dfT = CPLAtof(papszTokens[3]);
+            else 
+                dfT = 0.0;
             CSLDestroy(papszTokens);
         }
+        if( dfT != dfLastT && nGCPCount == 0 )
+        {
+            if( dfT != 0.0 )
+            {
+                aosTO.SetNameValue("COORDINATE_EPOCH", CPLSPrintf("%g", dfT));
+            }
+            else
+            {
+                aosTO.SetNameValue("COORDINATE_EPOCH", nullptr);
+            }
+            GDALDestroyGenImgProjTransformer(hTransformArg);
+            hTransformArg =
+                GDALCreateGenImgProjTransformer2( hSrcDS, hDstDS, aosTO.List() );
+        }
 
         int bSuccess = TRUE;
         if( pfnTransformer( hTransformArg, bInverse, 1,
@@ -359,6 +416,7 @@ MAIN_START(argc, argv)
 
         if( bCoordOnCommandLine )
             break;
+        dfLastT = dfT;
     }
 
     if( nGCPCount != 0 && nOrder == -1 )
