@@ -53,7 +53,7 @@
 #include "ogrsf_frmts.h"
 
 
-CPL_CVSID("$Id: ogrinfo.cpp 1f94aee32f14dc23c8d708625a223aa0f88e8c33 2020-07-28 18:42:58 +0200 Even Rouault $")
+CPL_CVSID("$Id: ogrinfo.cpp 4d6b3014e77f40ca702be655e3c0f7dbde8b1822 2020-09-09 12:00:38 +0200 Even Rouault $")
 
 bool bVerbose = true;
 bool bSuperQuiet = false;
@@ -162,7 +162,7 @@ static void GDALInfoReportMetadata( GDALMajorObjectH hObject,
 
             while( papszIter != nullptr && *papszIter != nullptr )
             {
-                if( !EQUAL(*papszIter, "") )
+                if( !EQUAL(*papszIter, "") && !EQUAL(*papszIter, "SUBDATASETS") )
                 {
                     papszExtraMDDomainsExpanded = CSLAddString(papszExtraMDDomainsExpanded, *papszIter);
                 }
@@ -189,6 +189,7 @@ static void GDALInfoReportMetadata( GDALMajorObjectH hObject,
 
         CSLDestroy(papszExtraMDDomainsExpanded);
     }
+    GDALInfoPrintMetadata(hObject, "SUBDATASETS", "Subdatasets", pszIndent);
 }
 
 /************************************************************************/
@@ -399,10 +400,15 @@ static void ReportOnLayer( OGRLayer * poLayer, const char *pszWHERE,
                    pszType,
                    poField->GetWidth(),
                    poField->GetPrecision());
+            if( poField->IsUnique() )
+                printf(" UNIQUE");
             if( !poField->IsNullable() )
                 printf(" NOT NULL");
             if( poField->GetDefault() != nullptr )
                 printf(" DEFAULT %s", poField->GetDefault());
+            const char* pszAlias = poField->GetAlternativeNameRef();
+            if( pszAlias != nullptr && pszAlias[0])
+                printf(", alternative name=\"%s\"", pszAlias);
             printf("\n");
         }
     }
