@@ -2,8 +2,11 @@
 
 set -e
 
-export PYTHONPATH=$PWD/gdal/swig/python/build/lib.macosx-10.13-x86_64-2.7:$PWD/gdal/swig/python/build/lib.macosx-10.15-x86_64-3.8
+export PYTHONPATH=$PWD/gdal/swig/python/build/lib.macosx-10.9-x86_64-3.8
 export PYTEST="python3 -m pytest -vv -p no:sugar --color=no"
+export DYLD_LIBRARY_PATH=$HOME/install-gdal/lib
+export GDAL_DATA=$HOME/install-gdal/share/gdal
+export PROJ_NETWORK=ON
 
 echo 'Running CPP unit tests'
 (cd autotest/cpp && make quick_test)
