@@ -27,7 +27,8 @@ $SCRIPT_DIR/../common_install.sh
 cd gdal
 # --with-mongocxx=/usr/local
 
-CFLAGS=$ARCH_FLAGS CXXFLAGS=$ARCH_FLAGS ./configure --prefix=/usr --without-libtool --with-jpeg12 --with-python=/usr/bin/python3 --with-poppler --with-podofo --with-spatialite --with-mysql --with-liblzma --with-webp --with-java --with-mdb --with-jvm-lib-add-rpath --with-epsilon --with-ecw=/usr/local --with-mrsid=/usr/local --with-mrsid-lidar=/usr/local --with-fgdb=/usr/local --with-libkml --with-null -with-libtiff=internal --with-proj=/usr/local
+CFLAGS=$ARCH_FLAGS CXXFLAGS=$ARCH_FLAGS ./configure --prefix=/usr --without-libtool --with-jpeg12 --with-python=/usr/bin/python3 --with-poppler --with-podofo --with-spatialite --with-mysql --with-liblzma --with-webp --with-java --with-mdb --with-jvm-lib-add-rpath --with-epsilon --with-ecw=/usr/local  --with-fgdb=/usr/local --with-libkml --with-null -with-libtiff=internal --with-proj=/usr/local
+# --with-mrsid=/usr/local --with-mrsid-lidar=/usr/local
 # --with-gta
 
 make USER_DEFS="-Wextra -Werror" -j3
@@ -63,6 +64,6 @@ make -j3
 cd ../../gdal
 wget https://storage.googleapis.com/google-code-archive-downloads/v2/code.google.com/mdb-sqlite/mdb-sqlite-1.0.2.tar.bz2
 tar xjvf mdb-sqlite-1.0.2.tar.bz2
-sudo cp mdb-sqlite-1.0.2/lib/*.jar /usr/lib/jvm/java-7-openjdk-amd64/jre/lib/ext
+sudo cp mdb-sqlite-1.0.2/lib/*.jar /usr/lib/jvm/java-8-openjdk-amd64/jre/lib/ext
 
 ccache -s
