@@ -54,7 +54,7 @@ const int SERVER_DIMENSION_LIMIT = 10000;
 /*                          GDALEEDAIDataset                            */
 /************************************************************************/
 
-class GDALEEDAIDataset: public GDALEEDABaseDataset
+class GDALEEDAIDataset final: public GDALEEDABaseDataset
 {
             CPL_DISALLOW_COPY_ASSIGN(GDALEEDAIDataset)
 
@@ -83,8 +83,11 @@ class GDALEEDAIDataset: public GDALEEDABaseDataset
                 GDALEEDAIDataset();
                 virtual ~GDALEEDAIDataset();
 
-                virtual const char* GetProjectionRef() CPL_OVERRIDE;
-                virtual CPLErr GetGeoTransform( double* ) CPL_OVERRIDE;
+                virtual const char* _GetProjectionRef() override;
+                const OGRSpatialReference* GetSpatialRef() const override {
+                    return GetSpatialRefFromOldGetProjectionRef();
+                }
+                virtual CPLErr GetGeoTransform( double* ) override;
 
                 virtual CPLErr IRasterIO( GDALRWFlag eRWFlag,
                                  int nXOff, int nYOff, int nXSize, int nYSize,
@@ -93,7 +96,7 @@ class GDALEEDAIDataset: public GDALEEDABaseDataset
                                  int nBandCount, int *panBandMap,
                                  GSpacing nPixelSpace, GSpacing nLineSpace,
                                  GSpacing nBandSpace,
-                                 GDALRasterIOExtraArg* psExtraArg ) CPL_OVERRIDE;
+                                 GDALRasterIOExtraArg* psExtraArg ) override;
 
                 bool ComputeQueryStrategy();
 
@@ -104,7 +107,7 @@ class GDALEEDAIDataset: public GDALEEDABaseDataset
 /*                        GDALEEDAIRasterBand                           */
 /************************************************************************/
 
-class GDALEEDAIRasterBand: public GDALRasterBand
+class GDALEEDAIRasterBand final: public GDALRasterBand
 {
                 CPL_DISALLOW_COPY_ASSIGN(GDALEEDAIRasterBand)
 
@@ -1228,7 +1231,7 @@ bool GDALEEDAIDataset::ComputeQueryStrategy()
 /*                          GetProjectionRef()                          */
 /************************************************************************/
 
-const char* GDALEEDAIDataset::GetProjectionRef()
+const char* GDALEEDAIDataset::_GetProjectionRef()
 {
     return m_osWKT.c_str();
 }
@@ -1642,7 +1645,7 @@ void GDALRegister_EEDAI()
     poDriver->SetMetadataItem( GDAL_DCAP_RASTER, "YES" );
     poDriver->SetMetadataItem( GDAL_DMD_LONGNAME,
                                "Earth Engine Data API Image" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "frmt_eedai.html" );
+    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/raster/eedai.html" );
     poDriver->SetMetadataItem( GDAL_DMD_CONNECTION_PREFIX, "EEDAI:" );
     poDriver->SetMetadataItem( GDAL_DMD_OPENOPTIONLIST,
 "<OpenOptionList>"
