@@ -136,7 +136,7 @@ class GeoRasterWrapper;
 //  GeoRasterDataset, extends GDALDataset to support GeoRaster Datasets
 //  ---------------------------------------------------------------------------
 
-class GeoRasterDataset : public GDALDataset
+class GeoRasterDataset final: public GDALDataset
 {
     friend class GeoRasterRasterBand;
 
@@ -253,7 +253,7 @@ public:
 //  GeoRasterRasterBand, extends GDALRasterBand to support GeoRaster Band
 //  ---------------------------------------------------------------------------
 
-class GeoRasterRasterBand : public GDALRasterBand
+class GeoRasterRasterBand final: public GDALRasterBand
 {
     friend class GeoRasterDataset;
 
