@@ -35,7 +35,7 @@
 #include "cpl_vsi.h"
 #include "cpl_error.h"
 
-CPL_CVSID("$Id: georaster_rasterband.cpp e13dcd4dc171dfeed63f912ba06b9374ce4f3bb2 2018-03-18 21:37:41Z Even Rouault $")
+CPL_CVSID("$Id: georaster_rasterband.cpp 8ca42e1b9c2e54b75d35e49885df9789a2643aa4 2020-05-17 21:43:40 +0200 Even Rouault $")
 
 //  ---------------------------------------------------------------------------
 //                                                        GeoRasterRasterBand()
@@ -65,7 +65,13 @@ GeoRasterRasterBand::GeoRasterRasterBand( GeoRasterDataset *poGDS,
     pahNoDataArray      = nullptr;
     nNoDataArraySz      = 0;
     bHasNoDataArray     = false;
-   
+    dfMin               = 0.0;
+    dfMax               = 0.0;
+    dfMean              = 0.0;
+    dfMedian            = 0.0;
+    dfMode              = 0.0;
+    dfStdDev            = 0.0;
+
     poJP2Dataset        = poJP2DatasetIn;
 
     //  -----------------------------------------------------------------------
@@ -531,13 +537,11 @@ CPLErr GeoRasterRasterBand::SetDefaultRAT( const GDALRasterAttributeTable *poRAT
     // Check if RAT is just colortable and/or histogram
     // ----------------------------------------------------------
 
-    CPLString sColName = "";
-    int  iCol = 0;
     int  nColCount = poRAT->GetColumnCount();
 
-    for( iCol = 0; iCol < poRAT->GetColumnCount(); iCol++ )
+    for( int iCol = 0; iCol < poRAT->GetColumnCount(); iCol++ )
     {
-        sColName = poRAT->GetNameOfCol( iCol );
+        const CPLString sColName = poRAT->GetNameOfCol( iCol );
 
         if( EQUAL( sColName, "histogram" ) ||
             EQUAL( sColName, "red" ) ||
@@ -562,35 +566,27 @@ CPLErr GeoRasterRasterBand::SetDefaultRAT( const GDALRasterAttributeTable *poRAT
     // Format Table description
     // ----------------------------------------------------------
 
-    char szName[OWTEXT];
-    char szDescription[OWTEXT];
+    CPLString osDescription = "( ID NUMBER";
 
-    strcpy( szDescription, "( ID NUMBER" );
-
-    for( iCol = 0; iCol < poRAT->GetColumnCount(); iCol++ )
+    for( int iCol = 0; iCol < poRAT->GetColumnCount(); iCol++ )
     {
-        strcpy( szName, poRAT->GetNameOfCol( iCol ) );
-
-        strcpy( szDescription, CPLSPrintf( "%s, %s",
-            szDescription, szName ) );
+        osDescription += ", ";
+        osDescription += poRAT->GetNameOfCol( iCol );
 
         if( poRAT->GetTypeOfCol( iCol ) == GFT_Integer )
         {
-            strcpy( szDescription, CPLSPrintf( "%s NUMBER",
-                szDescription ) );
+            osDescription += " NUMBER";
         }
         if( poRAT->GetTypeOfCol( iCol ) == GFT_Real )
         {
-            strcpy( szDescription, CPLSPrintf( "%s NUMBER",
-                szDescription ) );
+            osDescription += " NUMBER";
         }
         if( poRAT->GetTypeOfCol( iCol ) == GFT_String )
         {
-            strcpy( szDescription, CPLSPrintf( "%s VARCHAR2(%d)",
-                szDescription, MAXLEN_VATSTR) );
+            osDescription += CPLSPrintf(" VARCHAR2(%d)", MAXLEN_VATSTR);
         }
     }
-    strcpy( szDescription, CPLSPrintf( "%s )", szDescription ) );
+    osDescription += " )";
 
     // ----------------------------------------------------------
     // Create VAT named based on RDT and RID and Layer (nBand)
@@ -627,7 +623,7 @@ CPLErr GeoRasterRasterBand::SetDefaultRAT( const GDALRasterAttributeTable *poRAT
         "  END IF;\n"
         "\n"
         "  EXECUTE IMMEDIATE 'CREATE TABLE '||TAB||' %s';\n"
-        "END;", szDescription ) );
+        "END;", osDescription.c_str() ) );
 
     poStmt->Bind( pszVATName );
 
@@ -658,7 +654,7 @@ CPLErr GeoRasterRasterBand::SetDefaultRAT( const GDALRasterAttributeTable *poRAT
     papWriteFields[0] =
         (void*) VSIMalloc3(sizeof(int), sizeof(int), nEntryCount ); // ID field
 
-    for(iCol = 0; iCol < nColunsCount; iCol++)
+    for(int iCol = 0; iCol < nColunsCount; iCol++)
     {
         if( poRAT->GetTypeOfCol( iCol ) == GFT_String )
         {
@@ -685,7 +681,7 @@ CPLErr GeoRasterRasterBand::SetDefaultRAT( const GDALRasterAttributeTable *poRAT
     {
         ((int *)(papWriteFields[0]))[iEntry] = iEntry; // ID field
 
-        for(iCol = 0; iCol < nColunsCount; iCol++)
+        for(int iCol = 0; iCol < nColunsCount; iCol++)
         {
             if( poRAT->GetTypeOfCol( iCol ) == GFT_String )
             {
@@ -717,7 +713,7 @@ CPLErr GeoRasterRasterBand::SetDefaultRAT( const GDALRasterAttributeTable *poRAT
 
     CPLString osInsert = CPLSPrintf( "INSERT INTO %s VALUES (", pszVATName );
     
-    for( iCol = 0; iCol < ( nColunsCount + 1); iCol++ )
+    for( int iCol = 0; iCol < ( nColunsCount + 1); iCol++ )
     {
         if( iCol > 0 )
         {
@@ -735,7 +731,7 @@ CPLErr GeoRasterRasterBand::SetDefaultRAT( const GDALRasterAttributeTable *poRAT
 
     poStmt->Bind((int*) papWriteFields[0]); // ID field
     
-    for(iCol = 0; iCol < nColunsCount; iCol++)
+    for(int iCol = 0; iCol < nColunsCount; iCol++)
     {
         if( poRAT->GetTypeOfCol( iCol ) == GFT_String )
         {
@@ -764,7 +760,7 @@ CPLErr GeoRasterRasterBand::SetDefaultRAT( const GDALRasterAttributeTable *poRAT
     // Clean up
     // ---------------------------
 
-    for(iCol = 0; iCol < ( nColunsCount + 1); iCol++)
+    for(int iCol = 0; iCol < ( nColunsCount + 1); iCol++)
     {
         CPLFree( papWriteFields[iCol] );
     }
@@ -822,8 +818,7 @@ GDALRasterAttributeTable *GeoRasterRasterBand::GetDefaultRAT()
     int   nPrecision = 0;
     signed short nScale = 0;
 
-    char szColumnList[OWTEXT];
-    szColumnList[0] = '\0';
+    CPLString osColumnList;
 
     while( poGDS->poGeoRaster->poConnection->GetNextField(
                 phDesc, iCol, szField, &hType, &nSize, &nPrecision, &nScale ) )
@@ -862,28 +857,30 @@ GDALRasterAttributeTable *GeoRasterRasterBand::GetDefaultRAT()
                     "as GDAL RAT", l_pszVATName, szField, hType );
                 continue;
         }
-        strcpy( szColumnList, CPLSPrintf( "%s substr(%s,1,%d),",
-            szColumnList, szField, MIN(nSize,OWNAME) ) );
+        osColumnList += CPLSPrintf(
+                  "substr(%s,1,%d),",
+                  szField, MIN(nSize,OWNAME));
 
         iCol++;
     }
 
-    szColumnList[strlen(szColumnList) - 1] = '\0'; // remove the last comma
+    if( !osColumnList.empty() )
+        osColumnList.resize(osColumnList.size()-1); // remove the last comma
 
     // ----------------------------------------------------------
     // Read VAT and load RAT
     // ----------------------------------------------------------
 
     OWStatement* poStmt = poGeoRaster->poConnection->CreateStatement( CPLSPrintf (
-        "SELECT %s FROM %s", szColumnList, l_pszVATName ) );
+        "SELECT %s FROM %s", osColumnList.c_str(), l_pszVATName ) );
 
-    char** papszValue = (char**) CPLMalloc( sizeof(char**) * iCol );
+    char** papszValue = (char**) CPLCalloc( sizeof(char*), iCol + 1 );
 
     int i = 0;
 
     for( i = 0; i < iCol; i++ )
     {
-        papszValue[i] = (char*) CPLMalloc( sizeof(char*) * OWNAME );
+        papszValue[i] = (char*) CPLCalloc( 1, OWNAME + 1 );
         poStmt->Define( papszValue[i] );
     }
 
@@ -891,6 +888,8 @@ GDALRasterAttributeTable *GeoRasterRasterBand::GetDefaultRAT()
     {
         CPLError( CE_Failure, CPLE_AppDefined, "Error reading VAT %s",
             l_pszVATName );
+        CSLDestroy(papszValue);
+        delete poStmt;
         return nullptr;
     }
 
@@ -905,11 +904,7 @@ GDALRasterAttributeTable *GeoRasterRasterBand::GetDefaultRAT()
         iRow++;
     }
 
-    for( i = 0; i < iCol; i++ )
-    {
-        CPLFree( papszValue[i] );
-    }
-    CPLFree( papszValue );
+    CSLDestroy(papszValue);
 
     delete poStmt;
 
