@@ -29,7 +29,8 @@
 //#include "write.h"
 #include "degrib2.h"
 #include "degrib1.h"
-#ifdef ENABLE_TDLPACK
+#if 0
+/* tdlpack is no longer supported by GDAL */
 #include "tdlpack.h"
 #endif
 #include "grib2api.h"
@@ -124,7 +125,8 @@ int ReadSECT0 (VSILFILE *fp, char **buff, uInt4 *buffLen, sInt4 limit,
    } wordType;
 
    uChar gribMatch = 0; /* Counts how many letters in GRIB we've matched. */
-#ifdef ENABLE_TDLPACK
+#if 0
+/* tdlpack is no longer supported by GDAL */
    uChar tdlpMatch = 0; /* Counts how many letters in TDLP we've matched. */
 #endif
    wordType word;       /* Used to check that the edition is correct. */
@@ -154,7 +156,8 @@ int ReadSECT0 (VSILFILE *fp, char **buff, uInt4 *buffLen, sInt4 limit,
    }
 */
    while (
-#ifdef ENABLE_TDLPACK
+#if 0
+/* tdlpack is no longer supported by GDAL */
           (tdlpMatch != 4) && 
 #endif
           (gribMatch != 4)) {
@@ -169,7 +172,8 @@ int ReadSECT0 (VSILFILE *fp, char **buff, uInt4 *buffLen, sInt4 limit,
                }
             }
          }
-#ifdef ENABLE_TDLPACK
+#if 0
+/* tdlpack is no longer supported by GDAL */
          else if ((*buff)[i] == 'T') {
             if (((*buff)[i + 1] == 'D') && ((*buff)[i + 2] == 'L') &&
                 ((*buff)[i + 3] == 'P')) {
@@ -223,7 +227,8 @@ int ReadSECT0 (VSILFILE *fp, char **buff, uInt4 *buffLen, sInt4 limit,
    *buffLen = curLen;
 
    word.li = sect0[1];
-#ifdef ENABLE_TDLPACK
+#if 0
+/* tdlpack is no longer supported by GDAL */
    if (tdlpMatch == 4) {
       if (word.buffer[3] != 0) {
          errSprintf ("ERROR: unexpected version of TDLP in SECT0\n");
@@ -936,7 +941,8 @@ int ReadGrib2Record (VSILFILE *fp, sChar f_unit, double **Grib_Data,
          free (buff);
          return 0;
       }
-#ifdef ENABLE_TDLPACK
+#if 0
+/* tdlpack is no longer supported by GDAL */
       else if (version == -1) {
          if (ReadTDLPRecord (fp, Grib_Data, grib_DataLen, meta, IS,
                              sect0, gribLen, majEarth, minEarth) != 0) {
@@ -1072,8 +1078,11 @@ int ReadGrib2Record (VSILFILE *fp, sChar f_unit, double **Grib_Data,
         }
 
          IS->nd2x3 = nd2x3;
-         IS->iain = (sInt4 *) realloc ((void *) IS->iain,
-                                       IS->nd2x3 * sizeof (sInt4));
+         if( Grib_Data )
+         {
+            IS->iain = (sInt4 *) realloc ((void *) IS->iain,
+                                        IS->nd2x3 * sizeof (sInt4));
+         }
          IS->ib = (sInt4 *) realloc ((void *) IS->ib,
                                      IS->nd2x3 * sizeof (sInt4));
       }
@@ -1143,7 +1152,10 @@ int ReadGrib2Record (VSILFILE *fp, sChar f_unit, double **Grib_Data,
 
       /* Note we are getting data back either as a float or an int, but not
        * both, so we don't need to allocated room for both. */
-      unpk_g2ncep (&kfildo, (float *) (IS->iain), IS->iain, &(IS->nd2x3),
+      unpk_g2ncep (&kfildo,
+                   j == subgNum ? (float *) (IS->iain) : nullptr,
+                   j == subgNum ? IS->iain : nullptr,
+                  &(IS->nd2x3),
                   IS->idat, &(IS->nidat), IS->rdat, &(IS->nrdat), IS->is[0],
                   &(IS->ns[0]), IS->is[1], &(IS->ns[1]), IS->is[2],
                   &(IS->ns[2]), IS->is[3], &(IS->ns[3]), IS->is[4],
@@ -1281,7 +1293,7 @@ int ReadGrib2Record (VSILFILE *fp, sChar f_unit, double **Grib_Data,
    }
 #endif
 
-   if (strcmp (meta->element, "Wx") != 0) {
+   if (Grib_Data != nullptr && strcmp (meta->element, "Wx") != 0) {
       if (strcmp (meta->element, "WWA") != 0) {
          ParseGrid (fp, &(meta->gridAttrib), Grib_Data, grib_DataLen, Nx, Ny,
                     meta->gds.scan, IS->nd2x3, IS->iain, ibitmap, IS->ib, unitM, unitB, 0,
@@ -1306,7 +1318,7 @@ int ReadGrib2Record (VSILFILE *fp, sChar f_unit, double **Grib_Data,
             }
          }
       }
-   } else {
+   } else if( Grib_Data != nullptr ) {
       /* Handle weather grid.  ParseGrid looks up the values... If they are
        * "<Invalid>" it sets it to missing (or creates one).  If the table
        * entry is used it sets f_valid to 2. */
