@@ -69,7 +69,7 @@ CPL_C_END
 #include "ogr_spatialref.h"
 #include "memdataset.h"
 
-CPL_CVSID("$Id: gribdataset.cpp 60b8191d742dbb289016758760b5c5f81bc24924 2020-10-03 12:02:03 +0200 Even Rouault $")
+CPL_CVSID("$Id: gribdataset.cpp 583930fafd35914fac204ff5ca801e135cb0f3c0 2020-10-25 19:22:12 +0100 Even Rouault $")
 
 static CPLMutex *hGRIBMutex = nullptr;
 
@@ -387,7 +387,7 @@ void GRIBRasterBand::FindPDSTemplate()
     // Collect section 4 octet information.  We read the file
     // ourselves since the GRIB API does not appear to preserve all
     // this for us.
-    if( abyHead[4] == 4 )
+    // if( abyHead[4] == 4 )
     {
         memcpy(&nSectSize, abyHead, 4);
         CPL_MSBPTR32(&nSectSize);
@@ -2015,6 +2015,15 @@ GDALDataset *GRIBDataset::OpenMultiDim( GDALOpenInfo *poOpenInfo )
 
     poDS->fp = nullptr;
     poDS->m_poRootGroup = poRootGroup;
+
+    poDS->SetDescription(poOpenInfo->pszFilename);
+
+    // Release hGRIBMutex otherwise we'll deadlock with GDALDataset own
+    // hGRIBMutex.
+    CPLReleaseMutex(hGRIBMutex);
+    poDS->TryLoadXML();
+    CPLAcquireMutex(hGRIBMutex, 1000.0);
+
     return poDS;
 }
 
