@@ -7,7 +7,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2006, Kevin Locke <kwl7@cornell.edu>
- * Copyright (c) 2008-2012, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2012, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -38,7 +38,7 @@
 #include "gdal_frmts.h"
 #include "gdal_pam.h"
 
-CPL_CVSID("$Id: gsbgdataset.cpp a542b2797f15f2ed694cfcee9ff17d86b339dfee 2018-04-02 00:24:03 +0200 Even Rouault $")
+CPL_CVSID("$Id: gsbgdataset.cpp f6099e5ed704166bf5cc113a053dd1b2725cb391 2020-03-22 11:20:10 +0100 Kai Pastor $")
 
 /************************************************************************/
 /* ==================================================================== */
@@ -48,7 +48,7 @@ CPL_CVSID("$Id: gsbgdataset.cpp a542b2797f15f2ed694cfcee9ff17d86b339dfee 2018-04
 
 class GSBGRasterBand;
 
-class GSBGDataset : public GDALPamDataset
+class GSBGDataset final: public GDALPamDataset
 {
     friend class GSBGRasterBand;
 
@@ -94,7 +94,7 @@ const size_t GSBGDataset::nHEADER_SIZE = 56;
 /* ==================================================================== */
 /************************************************************************/
 
-class GSBGRasterBand : public GDALPamRasterBand
+class GSBGRasterBand final: public GDALPamRasterBand
 {
     friend class GSBGDataset;
 
@@ -1116,7 +1116,7 @@ void GDALRegister_GSBG()
     poDriver->SetMetadataItem( GDAL_DCAP_RASTER, "YES" );
     poDriver->SetMetadataItem( GDAL_DMD_LONGNAME,
                                "Golden Software Binary Grid (.grd)" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "frmt_various.html#GSBG" );
+    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/raster/gsbg.html" );
     poDriver->SetMetadataItem( GDAL_DMD_EXTENSION, "grd" );
     poDriver->SetMetadataItem( GDAL_DMD_CREATIONDATATYPES,
                                "Byte Int16 UInt16 Float32" );
