@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gt_overview.h 3694a56e6fb1dc15cf25674430d6be44f0de8452 2020-05-04 00:21:12 +0200 Even Rouault $
+ * $Id: gt_overview.h 7e9a593460d00a8e3ad3dd06bec239be55c85f20 2020-10-05 11:18:58 +0200 Thomas Bonfort $
  *
  * Project:  GeoTIFF Driver
  * Purpose:  Code to build overviews of external databases as a TIFF file.
@@ -35,6 +35,8 @@
 #include "gdal_priv.h"
 #include "tiffio.h"
 
+#include <utility>
+
 toff_t GTIFFWriteDirectory( TIFF *hTIFF, int nSubfileType,
                             int nXSize, int nYSize,
                             int nBitsPerPixel, int nPlanarConfig, int nSamples,
@@ -52,7 +54,8 @@ toff_t GTIFFWriteDirectory( TIFF *hTIFF, int nSubfileType,
                             const char* pszJPEGTablesMode,
                             const char* pszNoData,
                             const uint32* panLercAddCompressionAndVersion,
-                            bool DeferStrileArrayWriting );
+                            bool DeferStrileArrayWriting,
+                            const char * pszWebpLevel );
 
 void GTIFFBuildOverviewMetadata( const char *pszResampling,
                                  GDALDataset *poBaseDS,
@@ -61,7 +64,9 @@ void GTIFFBuildOverviewMetadata( const char *pszResampling,
 CPLErr
 GTIFFBuildOverviewsEx( const char * pszFilename,
                        int nBands, GDALRasterBand **papoBandList,
-                       int nOverviews, int * panOverviewList,
+                       int nOverviews,
+                       const int * panOverviewList,
+                       const std::pair<int, int>* pasOverviewSize,
                        const char * pszResampling,
                        const char* const* papszOptions,
                        GDALProgressFunc pfnProgress, void * pProgressData );
