@@ -47,7 +47,7 @@
 #include "gdal_frmts.h"
 #include "gdal_priv.h"
 
-CPL_CVSID("$Id: hdf5dataset.cpp 8ca42e1b9c2e54b75d35e49885df9789a2643aa4 2020-05-17 21:43:40 +0200 Even Rouault $")
+CPL_CVSID("$Id: hdf5dataset.cpp 7bfecfa72d986a33e07ea3110f2e5d38803a167a 2020-11-23 17:07:35 +0100 Even Rouault $")
 
 constexpr size_t MAX_METADATA_LEN = 32768;
 
@@ -372,10 +372,32 @@ int HDF5Dataset::Identify( GDALOpenInfo * poOpenInfo )
     if( !poOpenInfo->pabyHeader )
         return FALSE;
 
+    const CPLString osExt(CPLGetExtension(poOpenInfo->pszFilename));
+
+    const auto IsRecognizedByNetCDFDriver = [&osExt, poOpenInfo]()
+    {
+        if( (EQUAL(osExt, "NC") ||
+             EQUAL(osExt, "CDF") ||
+             EQUAL(osExt, "NC4")) &&
+            GDALGetDriverByName("netCDF") != nullptr )
+        {
+            const char *const apszAllowedDriver[] = { "netCDF", nullptr };
+            CPLPushErrorHandler(CPLQuietErrorHandler);
+            GDALDatasetH hDS = GDALOpenEx(poOpenInfo->pszFilename,
+                                          GDAL_OF_RASTER | GDAL_OF_VECTOR,
+                                          apszAllowedDriver, nullptr, nullptr);
+            CPLPopErrorHandler();
+            if( hDS )
+            {
+                GDALClose(hDS);
+                return true;
+            }
+        }
+        return false;
+    };
+
     if( memcmp(poOpenInfo->pabyHeader, achSignature, 8) == 0 )
     {
-        CPLString osExt(CPLGetExtension(poOpenInfo->pszFilename));
-
         // The tests to avoid opening KEA and BAG drivers are not
         // necessary when drivers are built in the core lib, as they
         // are registered after HDF5, but in the case of plugins, we
@@ -395,22 +417,9 @@ int HDF5Dataset::Identify( GDALOpenInfo * poOpenInfo )
 
         // Avoid opening NC files if the netCDF driver is available and
         // they are recognized by it.
-        if( (EQUAL(osExt, "NC") ||
-             EQUAL(osExt, "CDF") ||
-             EQUAL(osExt, "NC4")) &&
-            GDALGetDriverByName("netCDF") != nullptr )
+        if( IsRecognizedByNetCDFDriver() )
         {
-            const char *const apszAllowedDriver[] = { "netCDF", nullptr };
-            CPLPushErrorHandler(CPLQuietErrorHandler);
-            GDALDatasetH hDS = GDALOpenEx(poOpenInfo->pszFilename,
-                                          GDAL_OF_RASTER | GDAL_OF_VECTOR,
-                                          apszAllowedDriver, nullptr, nullptr);
-            CPLPopErrorHandler();
-            if( hDS )
-            {
-                GDALClose(hDS);
-                return FALSE;
-            }
+            return FALSE;
         }
 
         return TRUE;
@@ -422,6 +431,35 @@ int HDF5Dataset::Identify( GDALOpenInfo * poOpenInfo )
           return TRUE;
     }
 
+    // The HDF5 signature can be at offsets 512, 1024, 2048, etc.
+    if( poOpenInfo->fpL != nullptr &&
+        (EQUAL(osExt, "h5") || EQUAL(osExt, "hdf5") ||
+         EQUAL(osExt, "nc") || EQUAL(osExt, "cdf") || EQUAL(osExt, "nc4")) )
+    {
+        vsi_l_offset nOffset = 512;
+        for(int i = 0; i < 64; i++)
+        {
+            GByte abyBuf[8];
+            if( VSIFSeekL(poOpenInfo->fpL, nOffset, SEEK_SET) != 0 ||
+                VSIFReadL(abyBuf, 1, 8, poOpenInfo->fpL) != 8 )
+            {
+                break;
+            }
+            if( memcmp(abyBuf, achSignature, 8) == 0 )
+            {
+                // Avoid opening NC files if the netCDF driver is available and
+                // they are recognized by it.
+                if( IsRecognizedByNetCDFDriver() )
+                {
+                    return FALSE;
+                }
+
+                return TRUE;
+            }
+            nOffset *= 2;
+        }
+    }
+
     return FALSE;
 }
 
@@ -1353,7 +1391,7 @@ CPLErr HDF5Dataset::ReadGlobalAttributes(int bSUBDATASET)
  *
  * Important: It allocates the memory for the attributes internally,
  * so the caller must free the returned array after using it.
- * @param pszAttrName Name of the attribute to be read.
+ * @param pszAttrFullPath Name of the attribute to be read.
  *        the attribute name must be the form:
  *            root attribute name
  *            SUBDATASET/subdataset attribute name
