@@ -6,7 +6,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2004, ITC
- * Copyright (c) 2008-2010, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2010, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -38,7 +38,7 @@
 
 #include "gdal_frmts.h"
 
-CPL_CVSID("$Id: ilwisdataset.cpp 72134a97567b898bddf6a87820548109f22bb8c4 2018-06-24 18:53:19 +0200 Even Rouault $")
+CPL_CVSID("$Id: ilwisdataset.cpp b1c9c12ad373e40b955162b45d704070d4ebf7b0 2019-06-19 16:50:15 +0200 Even Rouault $")
 
 namespace GDAL
 {
@@ -603,7 +603,7 @@ CPLErr ILWISDataset::WriteGeoReference()
 /*                          GetProjectionRef()                          */
 /************************************************************************/
 
-const char *ILWISDataset::GetProjectionRef()
+const char *ILWISDataset::_GetProjectionRef()
 
 {
    return pszProjection;
@@ -613,7 +613,7 @@ const char *ILWISDataset::GetProjectionRef()
 /*                           SetProjection()                            */
 /************************************************************************/
 
-CPLErr ILWISDataset::SetProjection( const char * pszNewProjection )
+CPLErr ILWISDataset::_SetProjection( const char * pszNewProjection )
 
 {
     CPLFree( pszProjection );
