@@ -6,7 +6,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2007, Ivan Lucena
- * Copyright (c) 2007-2013, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2007-2013, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files ( the "Software" ),
@@ -42,7 +42,7 @@
 
 #include <algorithm>
 
-CPL_CVSID("$Id: IntergraphBand.cpp 6ef13199b493973da285decbfcd5e2a763954b97 2018-06-07 05:46:42 -0400 luzpaz $")
+CPL_CVSID("$Id: IntergraphBand.cpp e1050e4c829d75d3913ed2c37d26bf84ebf8e5d1 2020-02-27 01:40:46 +0100 Even Rouault $")
 
 using std::fill;
 
@@ -150,7 +150,7 @@ IntergraphRasterBand::IntergraphRasterBand( IntergraphDataset *poDSIn,
     // Get tile directory
     // --------------------------------------------------------------------
 
-    eFormat = (INGR_Format) hHeaderOne.DataTypeCode;
+    uint16 eFormatUntyped = (INGR_Format) hHeaderOne.DataTypeCode;
 
     bTiled = hHeaderOne.DataTypeCode == TiledRasterData;
 
@@ -165,7 +165,7 @@ IntergraphRasterBand::IntergraphRasterBand( IntergraphDataset *poDSIn,
         if (nTiles == 0)
             return;
 
-        eFormat = (INGR_Format) hTileDir.DataTypeCode;
+        eFormatUntyped = hTileDir.DataTypeCode;
 
         // ----------------------------------------------------------------
         // Set blocks dimensions based on tiles
@@ -190,7 +190,7 @@ IntergraphRasterBand::IntergraphRasterBand( IntergraphDataset *poDSIn,
     // --------------------------------------------------------------------
     // Get the Data Type from Format
     // --------------------------------------------------------------------
-    eDataType = INGR_GetDataType( static_cast<uint16>(eFormat) );
+    eDataType = INGR_GetDataType( eFormatUntyped );
 
     // --------------------------------------------------------------------
     // Allocate buffer for a Block of data
@@ -203,9 +203,10 @@ IntergraphRasterBand::IntergraphRasterBand( IntergraphDataset *poDSIn,
         nBlockXSize > INT_MAX / (nBlockYSize *
                                  (GDALGetDataTypeSizeBytes( eDataType ))) )
     {
-        CPLError(CE_Failure, CPLE_AppDefined, "Too big block size");
+        CPLError(CE_Failure, CPLE_AppDefined, "Too big block size / invalid type");
         return;
     }
+    eFormat = static_cast<INGR_Format>(eFormatUntyped);
 
     nBlockBufSize = nBlockXSize * nBlockYSize *
                     (GDALGetDataTypeSize( eDataType ) / 8);
