@@ -53,7 +53,7 @@
 #include <cmath>
 #include <vector>
 
-CPL_CVSID("$Id: jp2kakdataset.cpp 198d510a8188eb2e8c6766be5af43f67163e1fff 2020-03-25 13:36:53 +0100 Even Rouault $")
+CPL_CVSID("$Id: jp2kakdataset.cpp 005bba36b5380fb56d0dd1aeb16fd92050ad17bf 2020-06-28 16:14:44 +0200 Even Rouault $")
 
 // Before v7.5 Kakadu does not advertise its version well
 // After v7.5 Kakadu has KDU_{MAJOR,MINOR,PATCH}_VERSION defines so it is easier
@@ -759,6 +759,8 @@ void JP2KAKDataset::KakaduInitialize()
 
     kdu_cpl_error_message oErrHandler(CE_Failure);
     kdu_cpl_error_message oWarningHandler(CE_Warning);
+    CPL_IGNORE_RET_VAL(oErrHandler);
+    CPL_IGNORE_RET_VAL(oWarningHandler);
 
     kdu_customize_warnings(new kdu_cpl_error_message(CE_Warning));
     kdu_customize_errors(new kdu_cpl_error_message(CE_Failure));
@@ -2321,6 +2323,7 @@ JP2KAKCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
           "{512,512},{256,512},{128,512},{64,512},{32,512},{16,512},{8,512},{4,512},{2,512}",
           "ORGgen_plt", "yes",
           "ORGgen_tlm", nullptr,
+          "ORGtparts", nullptr,
           "Qguard", nullptr,
           "Cmodes", nullptr,
           "Clevels", nullptr,
@@ -2750,6 +2753,7 @@ void GDALRegister_JP2KAK()
 "   <Option name='Clevels' type='string'/>"
 "   <Option name='ORGgen_plt' type='string'/>"
 "   <Option name='ORGgen_tlm' type='string'/>"
+"   <Option name='ORGtparts' type='string'/>"
 "   <Option name='Qguard' type='integer'/>"
 "   <Option name='Sprofile' type='string'/>"
 "   <Option name='Rshift' type='string'/>"
