@@ -32,7 +32,7 @@
 
 #include <cstddef>
 
-CPL_CVSID("$Id: vsidataio.cpp 37478 2017-02-26 03:05:44Z goatbar $");
+CPL_CVSID("$Id: vsidataio.cpp 8ca42e1b9c2e54b75d35e49885df9789a2643aa4 2020-05-17 21:43:40 +0200 Even Rouault $")
 
 CPL_C_START
 #include "jerror.h"
@@ -52,12 +52,12 @@ typedef struct
 typedef my_source_mgr *my_src_ptr;
 
 // Choose an efficiently fread'able size.
-static const size_t INPUT_BUF_SIZE = 4096;
+constexpr size_t INPUT_BUF_SIZE = 4096;
 
 // Initialize source --- called by jpeg_read_header
 // before any data is actually read.
 
-METHODDEF(void)
+static void
 init_source(j_decompress_ptr cinfo)
 {
     my_src_ptr src = (my_src_ptr)cinfo->src;
@@ -99,7 +99,7 @@ init_source(j_decompress_ptr cinfo)
 // Data beyond this point must be rescanned after resumption, so move it to
 // the front of the buffer rather than discarding it.
 
-METHODDEF(boolean)
+static boolean
 fill_input_buffer(j_decompress_ptr cinfo)
 {
     my_src_ptr src = (my_src_ptr)cinfo->src;
@@ -132,7 +132,7 @@ fill_input_buffer(j_decompress_ptr cinfo)
 // copies the remaining buffer bytes to the front of the buffer,
 // then fills up the rest with new data.
 #ifdef IPPJ_HUFF
-METHODDEF(boolean)
+static boolean
 fill_input_buffer_ipp(j_decompress_ptr cinfo)
 {
     my_src_ptr src = (my_src_ptr)cinfo->src;
@@ -192,7 +192,7 @@ fill_input_buffer_ipp(j_decompress_ptr cinfo)
 // Arranging for additional bytes to be discarded before reloading the input
 // buffer is the application writer's problem.
 
-METHODDEF(void)
+static void
 skip_input_data(j_decompress_ptr cinfo, long num_bytes)
 {
     my_src_ptr src = (my_src_ptr)cinfo->src;
@@ -227,7 +227,7 @@ skip_input_data(j_decompress_ptr cinfo, long num_bytes)
 // application must deal with any cleanup that should happen even
 // for error exit.
 
-METHODDEF(void)
+static void
 term_source(CPL_UNUSED j_decompress_ptr cinfo)
 {
     // No work necessary here.
@@ -247,7 +247,7 @@ void jpeg_vsiio_src(j_decompress_ptr cinfo, VSILFILE *infile)
     // one image, we'd likely lose the start of the next one.)
     // This makes it unsafe to use this manager and a different source
     // manager serially with the same JPEG object.  Caveat programmer.
-    if(cinfo->src == NULL)
+    if(cinfo->src == nullptr)
     {
         // First time for this JPEG object?
         cinfo->src = (struct jpeg_source_mgr *)(*cinfo->mem->alloc_small)(
@@ -270,7 +270,7 @@ void jpeg_vsiio_src(j_decompress_ptr cinfo, VSILFILE *infile)
     src->pub.term_source = term_source;
     src->infile = infile;
     src->pub.bytes_in_buffer = 0;     // Forces fill_input_buffer on first read.
-    src->pub.next_input_byte = NULL;  // Until buffer loaded.
+    src->pub.next_input_byte = nullptr;  // Until buffer loaded.
 }
 
 /* ==================================================================== */
@@ -290,12 +290,12 @@ typedef struct
 typedef my_destination_mgr *my_dest_ptr;
 
 // choose an efficiently fwrite'able size.
-static const size_t OUTPUT_BUF_SIZE = 4096;
+constexpr size_t OUTPUT_BUF_SIZE = 4096;
 
 // Initialize destination --- called by jpeg_start_compress
 // before any data is actually written.
 
-METHODDEF(void)
+static void
 init_destination(j_compress_ptr cinfo)
 {
     my_dest_ptr dest = (my_dest_ptr)cinfo->dest;
@@ -329,7 +329,7 @@ init_destination(j_compress_ptr cinfo)
 // Data beyond this point will be regenerated after resumption, so do not
 // write it out when emptying the buffer externally.
 
-METHODDEF(boolean)
+static boolean
 empty_output_buffer(j_compress_ptr cinfo)
 {
     my_dest_ptr dest = (my_dest_ptr)cinfo->dest;
@@ -364,7 +364,7 @@ empty_output_buffer(j_compress_ptr cinfo)
 // NB://not* called by jpeg_abort or jpeg_destroy; surrounding
 // application must deal with any cleanup that should happen even
 // for error exit.
-METHODDEF(void)
+static void
 term_destination(j_compress_ptr cinfo)
 {
     my_dest_ptr dest = (my_dest_ptr)cinfo->dest;
@@ -399,7 +399,7 @@ void jpeg_vsiio_dest(j_compress_ptr cinfo, VSILFILE *outfile)
     // This makes it dangerous to use this manager and a different destination
     // manager serially with the same JPEG object, because their private object
     // sizes may be different.  Caveat programmer.
-    if(cinfo->dest == NULL)
+    if(cinfo->dest == nullptr)
     {
         // First time for this JPEG object?
         cinfo->dest = (struct jpeg_destination_mgr *)(*cinfo->mem->alloc_small)(
