@@ -10,7 +10,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2005-2007 Daylon Graphics Ltd.
- * Copyright (c) 2007-2013, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2007-2013, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -35,7 +35,7 @@
 #include "gdal_pam.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: levellerdataset.cpp e46fca76df8aa6869375620579ff9cf3cff86e16 2018-04-26 22:56:23 +0200 Even Rouault $")
+CPL_CVSID("$Id: levellerdataset.cpp a5d5ed208537a05de4437e97b6a09b7ba44f76c9 2020-03-24 08:27:48 +0100 Kai Pastor $")
 
 static bool str_equal(const char *_s1, const char *_s2) {
     return 0 == strcmp(_s1, _s2);
@@ -302,10 +302,17 @@ public:
                                 GDALDataType eType, char** papszOptions );
 
     virtual CPLErr      GetGeoTransform( double* ) override;
-    virtual const char* GetProjectionRef(void) override;
+    virtual const char* _GetProjectionRef(void) override;
 
     virtual CPLErr      SetGeoTransform( double* ) override;
-    virtual CPLErr      SetProjection(const char*) override;
+    virtual CPLErr      _SetProjection(const char*) override;
+
+    const OGRSpatialReference* GetSpatialRef() const override {
+        return GetSpatialRefFromOldGetProjectionRef();
+    }
+    CPLErr SetSpatialRef(const OGRSpatialReference* poSRS) override {
+        return OldSetProjectionFromSetSpatialRef(poSRS);
+    }
 };
 
 class digital_axis
@@ -841,7 +848,7 @@ CPLErr LevellerDataset::SetGeoTransform( double *padfGeoTransform )
 /*                           SetProjection()                            */
 /************************************************************************/
 
-CPLErr LevellerDataset::SetProjection( const char * pszNewProjection )
+CPLErr LevellerDataset::_SetProjection( const char * pszNewProjection )
 {
     CPLFree(m_pszProjection);
 
@@ -1443,7 +1450,7 @@ bool LevellerDataset::load_from_file(VSILFILE* file, const char* pszFilename)
 /*                          GetProjectionRef()                          */
 /************************************************************************/
 
-const char* LevellerDataset::GetProjectionRef(void)
+const char* LevellerDataset::_GetProjectionRef(void)
 {
     return m_pszProjection == nullptr ? "" : m_pszProjection;
 }
@@ -1554,7 +1561,7 @@ void GDALRegister_Leveller()
     poDriver->SetMetadataItem( GDAL_DCAP_RASTER, "YES" );
     poDriver->SetMetadataItem( GDAL_DMD_EXTENSION, "ter" );
     poDriver->SetMetadataItem( GDAL_DMD_LONGNAME, "Leveller heightfield" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "frmt_leveller.html" );
+    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/raster/leveller.html" );
     poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
 
     poDriver->pfnIdentify = LevellerDataset::Identify;
