@@ -45,7 +45,7 @@
 
 #include "marfa.h"
 
-CPL_CVSID("$Id: Tif_band.cpp 3f68d11104319388dc0f0c2faaf07e60198e8096 2019-10-05 11:41:37 +0200 Even Rouault $")
+CPL_CVSID("$Id: Tif_band.cpp 81d88451b89a7cb8e02020005eb322b0cdaff4de 2020-08-10 08:52:54 -0700 Lucian Plesea $")
 
 NAMESPACE_MRF_START
 
@@ -222,9 +222,9 @@ CPLErr TIF_Band::Compress(buf_mgr &dst, buf_mgr &src)
     return CompressTIF(dst,src,img, papszOptions);
 }
 
-TIF_Band::TIF_Band( GDALMRFDataset *pDS, const ILImage &image,
+TIF_Band::TIF_Band( MRFDataset *pDS, const ILImage &image,
                     int b, int level ):
-    GDALMRFRasterBand(pDS, image, b, int(level))
+    MRFRasterBand(pDS, image, b, int(level))
 {
     // Increase the page buffer by 1K in case Tiff expands data
     pDS->SetPBufferSize(image.pageSizeBytes + 1024);
