@@ -56,7 +56,7 @@
 #include <algorithm>
 #include <vector>
 
-CPL_CVSID("$Id: marfa_dataset.cpp 327bfdc0f5dd563c3b1c4cbf26d34967c5c9c790 2020-02-28 13:51:40 +0100 Even Rouault $")
+CPL_CVSID("$Id: marfa_dataset.cpp c493027f5b0e384cbe56afcd8c945da6e9c1639c 2020-09-05 03:14:45 -0700 Lucian Plesea $")
 
 using std::vector;
 using std::string;
@@ -70,7 +70,7 @@ NAMESPACE_MRF_START
 #endif
 
 // Initialize as invalid
-GDALMRFDataset::GDALMRFDataset() :
+MRFDataset::MRFDataset() :
     zslice(0),
     idxSize(0),
     clonedSource(FALSE),
@@ -104,7 +104,7 @@ GDALMRFDataset::GDALMRFDataset() :
     ifp.acc = GF_Read;
 }
 
-bool GDALMRFDataset::SetPBuffer(unsigned int sz)
+bool MRFDataset::SetPBuffer(unsigned int sz)
 {
     if (sz == 0) {
         CPLFree(pbuffer);
@@ -126,7 +126,7 @@ bool GDALMRFDataset::SetPBuffer(unsigned int sz)
 // Called by dataset destructor or at GDAL termination, to avoid
 // closing datasets whose drivers have already been unloaded
 //
-int GDALMRFDataset::CloseDependentDatasets()
+int MRFDataset::CloseDependentDatasets()
 {
     int bHasDroppedRef = GDALPamDataset::CloseDependentDatasets();
 
@@ -146,12 +146,17 @@ int GDALMRFDataset::CloseDependentDatasets()
     return bHasDroppedRef;
 }
 
-GDALMRFDataset::~GDALMRFDataset()
+MRFDataset::~MRFDataset()
 
 {   // Make sure everything gets written
-    GDALMRFDataset::FlushCache();
+    if (eAccess != GA_ReadOnly && !bCrystalized)
+        if (!Crystalize()) {
+            // Can't return error code from a destructor, just emit the error
+            CPLError(CE_Failure, CPLE_FileIO, "Error creating files");
+        }
 
-    GDALMRFDataset::CloseDependentDatasets();
+    MRFDataset::FlushCache();
+    MRFDataset::CloseDependentDatasets();
 
     if (ifp.FP)
         VSIFCloseL(ifp.FP);
@@ -191,7 +196,7 @@ CPLErr GDALMRFDataset::AdviseRead(int nXOff, int nYOff, int nXSize, int nYSize,
  *
  *
  */
-CPLErr GDALMRFDataset::IRasterIO(GDALRWFlag eRWFlag, int nXOff, int nYOff, int nXSize, int nYSize,
+CPLErr MRFDataset::IRasterIO(GDALRWFlag eRWFlag, int nXOff, int nYOff, int nXSize, int nYSize,
     void *pData, int nBufXSize, int nBufYSize, GDALDataType eBufType,
     int nBandCount, int *panBandMap,
 #if GDAL_VERSION_MAJOR >= 2
@@ -207,6 +212,12 @@ CPLErr GDALMRFDataset::IRasterIO(GDALRWFlag eRWFlag, int nXOff, int nYOff, int n
         static_cast<int>(nPixelSpace), static_cast<int>(nLineSpace),
         static_cast<int>(nBandSpace));
 
+    if (eRWFlag == GF_Write && !bCrystalized)
+        if (!Crystalize()) {
+            CPLError(CE_Failure, CPLE_FileIO, "MRF: Error creating files");
+            return CE_Failure;
+        }
+
     //
     // Call the parent implementation, which splits it into bands and calls their IRasterIO
     //
@@ -224,7 +235,7 @@ CPLErr GDALMRFDataset::IRasterIO(GDALRWFlag eRWFlag, int nXOff, int nYOff, int n
 *  if nOverviews is 0, erase the overviews (reduce to base image only)
 */
 
-CPLErr GDALMRFDataset::IBuildOverviews(
+CPLErr MRFDataset::IBuildOverviews(
     const char * pszResampling,
     int nOverviews, int * panOverviewList,
     int nBandsIn, int * panBandList,
@@ -373,7 +384,7 @@ CPLErr GDALMRFDataset::IBuildOverviews(
             };
 
             int srclevel = int(logbase(panOverviewListNew[i], scale) - 0.5);
-            GDALMRFRasterBand *b = static_cast<GDALMRFRasterBand *>(GetRasterBand(1));
+            MRFRasterBand *b = static_cast<MRFRasterBand *>(GetRasterBand(1));
 
             // Warn for requests for invalid levels
             if (srclevel >= b->GetOverviewCount()) {
@@ -390,7 +401,7 @@ CPLErr GDALMRFDataset::IBuildOverviews(
                 int sampling = EQUALN("Avg", pszResampling, 3) ? SAMPLING_Avg : SAMPLING_Near;
                 // Internal, using PatchOverview
                 if (srclevel > 0)
-                    b = static_cast<GDALMRFRasterBand *>(b->GetOverview(srclevel - 1));
+                    b = static_cast<MRFRasterBand *>(b->GetOverview(srclevel - 1));
 
                 eErr = PatchOverview(0, 0, b->nBlocksPerRow, b->nBlocksPerColumn, srclevel,
                     0, sampling);
@@ -457,15 +468,15 @@ static void list2vec(std::vector<double> &v, const char *pszList) {
     CSLDestroy(papszTokens);
 }
 
-void GDALMRFDataset::SetNoDataValue(const char *pszVal) {
+void MRFDataset::SetNoDataValue(const char *pszVal) {
     list2vec(vNoData, pszVal);
 }
 
-void GDALMRFDataset::SetMinValue(const char *pszVal) {
+void MRFDataset::SetMinValue(const char *pszVal) {
     list2vec(vMin, pszVal);
 }
 
-void GDALMRFDataset::SetMaxValue(const char *pszVal) {
+void MRFDataset::SetMaxValue(const char *pszVal) {
     list2vec(vMax, pszVal);
 }
 
@@ -475,7 +486,7 @@ void GDALMRFDataset::SetMaxValue(const char *pszVal) {
 * Lightweight test, otherwise Open gets called.
 *
 */
-int GDALMRFDataset::Identify(GDALOpenInfo *poOpenInfo)
+int MRFDataset::Identify(GDALOpenInfo *poOpenInfo)
 
 {
   if (STARTS_WITH(poOpenInfo->pszFilename, "<MRF_META>"))
@@ -509,7 +520,7 @@ int GDALMRFDataset::Identify(GDALOpenInfo *poOpenInfo)
 * @return NULL on failure, or the document tree on success.
 *
 */
-CPLXMLNode *GDALMRFDataset::ReadConfig() const
+CPLXMLNode *MRFDataset::ReadConfig() const
 {
     if (fname[0] == '<')
         return CPLParseXMLString(fname);
@@ -525,7 +536,7 @@ CPLXMLNode *GDALMRFDataset::ReadConfig() const
 * @param config The document tree to write
 * @return TRUE on success, FALSE otherwise
 */
-int GDALMRFDataset::WriteConfig(CPLXMLNode *config)
+int MRFDataset::WriteConfig(CPLXMLNode *config)
 {
     if (fname[0] == '<') return FALSE;
     return CPLSerializeXMLTreeToFile(config, fname);
@@ -562,7 +573,7 @@ static int getnum(const vector<string> &theStringVector, const char prefix, int
 *\brief Open a MRF file
 *
 */
-GDALDataset *GDALMRFDataset::Open(GDALOpenInfo *poOpenInfo)
+GDALDataset *MRFDataset::Open(GDALOpenInfo *poOpenInfo)
 
 {
     if( !Identify(poOpenInfo) )
@@ -611,7 +622,7 @@ GDALDataset *GDALMRFDataset::Open(GDALOpenInfo *poOpenInfo)
     if (!config)
         return nullptr;
 
-    GDALMRFDataset *ds = new GDALMRFDataset();
+    MRFDataset *ds = new MRFDataset();
     ds->fname = pszFileName;
     ds->eAccess = poOpenInfo->eAccess;
     ds->level = level;
@@ -622,7 +633,7 @@ GDALDataset *GDALMRFDataset::Open(GDALOpenInfo *poOpenInfo)
 
     if (level != -1) {
         // Open the whole dataset, then pick one level
-        ds->cds = new GDALMRFDataset();
+        ds->cds = new MRFDataset();
         ds->cds->fname = pszFileName;
         ds->cds->eAccess = ds->eAccess;
         ds->zslice = zslice;
@@ -665,17 +676,17 @@ GDALDataset *GDALMRFDataset::Open(GDALOpenInfo *poOpenInfo)
 }
 
 // Adjust the band images with the right offset, then adjust the sizes
-CPLErr GDALMRFDataset::SetVersion(int version) {
+CPLErr MRFDataset::SetVersion(int version) {
     if (!hasVersions || version > verCount) {
         CPLError(CE_Failure, CPLE_AppDefined, "GDAL MRF: Version number error!");
         return CE_Failure;
     }
     // Size of one version index
     for (int bcount = 1; bcount <= nBands; bcount++) {
-        GDALMRFRasterBand *srcband = reinterpret_cast<GDALMRFRasterBand *>(GetRasterBand(bcount));
+        MRFRasterBand *srcband = reinterpret_cast<MRFRasterBand *>(GetRasterBand(bcount));
         srcband->img.idxoffset += idxSize*verCount;
         for (int l = 0; l < srcband->GetOverviewCount(); l++) {
-            GDALMRFRasterBand *band = reinterpret_cast<GDALMRFRasterBand *>(srcband->GetOverview(l));
+            MRFRasterBand *band = reinterpret_cast<MRFRasterBand *>(srcband->GetOverview(l));
             if( band != nullptr )
                 band->img.idxoffset += idxSize*verCount;
         }
@@ -684,15 +695,15 @@ CPLErr GDALMRFDataset::SetVersion(int version) {
     return CE_None;
 }
 
-CPLErr GDALMRFDataset::LevelInit(const int l) {
+CPLErr MRFDataset::LevelInit(const int l) {
     // Test that this level does exist
     if (l < 0 || l >= cds->GetRasterBand(1)->GetOverviewCount()) {
         CPLError(CE_Failure, CPLE_AppDefined, "GDAL MRF: Overview not present!");
         return CE_Failure;
     }
 
-    GDALMRFRasterBand *srcband =
-        reinterpret_cast<GDALMRFRasterBand *>(cds->GetRasterBand(1)->GetOverview(l));
+    MRFRasterBand *srcband =
+        reinterpret_cast<MRFRasterBand *>(cds->GetRasterBand(1)->GetOverview(l));
 
     // Copy the sizes from this level
     full = srcband->img;
@@ -716,7 +727,7 @@ CPLErr GDALMRFDataset::LevelInit(const int l) {
 
     // Add the bands, copy constructor so they can be closed independently
     for (int i = 1; i <= nBands; i++)
-        SetBand(i, new GDALMRFLRasterBand(reinterpret_cast<GDALMRFRasterBand *>
+        SetBand(i, new MRFLRasterBand(reinterpret_cast<MRFRasterBand *>
                                             (cds->GetRasterBand(i)->GetOverview(l))));
     return CE_None;
 }
@@ -739,7 +750,7 @@ inline bool on(const char *pszValue) {
 *
 */
 
-static CPLErr Init_Raster(ILImage &image, GDALMRFDataset *ds, CPLXMLNode *defimage)
+static CPLErr Init_Raster(ILImage &image, MRFDataset *ds, CPLXMLNode *defimage)
 {
     CPLXMLNode *node; // temporary
     if (!defimage) {
@@ -786,7 +797,7 @@ static CPLErr Init_Raster(ILImage &image, GDALMRFDataset *ds, CPLXMLNode *defima
             image.pagesize.y < 1 ||
             image.pagesize.c <= 0 )
         {
-            CPLError(CE_Failure, CPLE_AppDefined, "Invalid PageSize");
+            CPLError(CE_Failure, CPLE_IllegalArg, "Invalid PageSize");
             return CE_Failure;
         }
     }
@@ -802,7 +813,7 @@ static CPLErr Init_Raster(ILImage &image, GDALMRFDataset *ds, CPLXMLNode *defima
     image.comp = CompToken(CPLGetXMLValue(defimage, "Compression", "PNG"));
 
     if (image.comp == IL_ERR_COMP) {
-        CPLError(CE_Failure, CPLE_AppDefined,
+        CPLError(CE_Failure, CPLE_IllegalArg,
             "GDAL MRF: Compression %s is unknown",
             CPLGetXMLValue(defimage, "Compression", nullptr));
         return CE_Failure;
@@ -830,8 +841,6 @@ static CPLErr Init_Raster(ILImage &image, GDALMRFDataset *ds, CPLXMLNode *defima
         int entries = static_cast<int>(getXMLNum(node, "Size", 255));
         GDALPaletteInterp eInterp = GPI_RGB;
         // A flag to convert from HLS to HSV
-        CPLString pModel = CPLGetXMLValue(node, "Model", "RGB");
-
         if ((entries > 0) && (entries < 257)) {
             GDALColorEntry ce_start = { 0, 0, 0, 255 }, ce_end = { 0, 0, 0, 255 };
 
@@ -845,7 +854,7 @@ static CPLErr Init_Raster(ILImage &image, GDALMRFDataset *ds, CPLXMLNode *defima
                 ce_start = GetXMLColorEntry(p);
                 int start_idx = static_cast<int>(getXMLNum(p, "idx", 0));
                 if (start_idx < 0) {
-                    CPLError(CE_Failure, CPLE_AppDefined,
+                    CPLError(CE_Failure, CPLE_IllegalArg,
                         "GDAL MRF: Palette index %d not allowed", start_idx);
                     delete poColorTable;
                     return CE_Failure;
@@ -856,7 +865,7 @@ static CPLErr Init_Raster(ILImage &image, GDALMRFDataset *ds, CPLXMLNode *defima
                     ce_end = GetXMLColorEntry(p);
                     int end_idx = static_cast<int>(getXMLNum(p, "idx", start_idx + 1));
                     if ((end_idx <= start_idx) || (start_idx >= entries)) {
-                        CPLError(CE_Failure, CPLE_AppDefined,
+                        CPLError(CE_Failure, CPLE_IllegalArg,
                             "GDAL MRF: Index Error at index %d", end_idx);
                         delete poColorTable;
                         return CE_Failure;
@@ -870,7 +879,7 @@ static CPLErr Init_Raster(ILImage &image, GDALMRFDataset *ds, CPLXMLNode *defima
             ds->SetColorTable(poColorTable);
         }
         else {
-            CPLError(CE_Failure, CPLE_AppDefined, "GDAL MRF: Palette definition error");
+            CPLError(CE_Failure, CPLE_IllegalArg, "GDAL MRF: Palette definition error");
             return CE_Failure;
         }
     }
@@ -960,7 +969,7 @@ static CPLErr Init_Raster(ILImage &image, GDALMRFDataset *ds, CPLXMLNode *defima
     return CE_None;
 }
 
-char      **GDALMRFDataset::GetFileList()
+char      **MRFDataset::GetFileList()
 {
     char** papszFileList = nullptr;
 
@@ -996,7 +1005,7 @@ static void mkdir_r(string const &fname) {
 }
 
 // Returns the dataset index file or null
-VSILFILE *GDALMRFDataset::IdxFP() {
+VSILFILE *MRFDataset::IdxFP() {
     if (ifp.FP != nullptr)
         return ifp.FP;
 
@@ -1041,7 +1050,7 @@ VSILFILE *GDALMRFDataset::IdxFP() {
 
     if (nullptr != ifp.FP) {
         if (!bCrystalized && !CheckFileSize(current.idxfname, expected_size, GA_Update)) {
-            CPLError(CE_Failure, CPLE_AppDefined, "Can't extend the cache index file %s",
+            CPLError(CE_Failure, CPLE_FileIO, "MRF: Can't extend the cache index file %s",
                 current.idxfname.c_str());
             return nullptr;
         }
@@ -1119,7 +1128,7 @@ VSILFILE *GDALMRFDataset::IdxFP() {
 // Returns the dataset data file or null
 // Data file is opened either in Read or Append mode, never in straight write
 //
-VSILFILE *GDALMRFDataset::DataFP() {
+VSILFILE *MRFDataset::DataFP() {
     if (dfp.FP != nullptr)
         return dfp.FP;
     const char *mode = "rb";
@@ -1167,7 +1176,7 @@ io_error:
 }
 
 // Builds an XML tree from the current MRF.  If written to a file it becomes an MRF
-CPLXMLNode * GDALMRFDataset::BuildConfig()
+CPLXMLNode * MRFDataset::BuildConfig()
 {
     CPLXMLNode *config = CPLCreateXMLNode(nullptr, CXT_Element, "MRF_META");
 
@@ -1286,7 +1295,7 @@ CPLXMLNode * GDALMRFDataset::BuildConfig()
 *
 *
 */
-CPLErr GDALMRFDataset::Initialize(CPLXMLNode *config)
+CPLErr MRFDataset::Initialize(CPLXMLNode *config)
 
 {
     // We only need a basic initialization here, usually gets overwritten by the image params
@@ -1408,7 +1417,7 @@ CPLErr GDALMRFDataset::Initialize(CPLXMLNode *config)
     // We have the options, so we can call rasterband
     for (int i = 1; i <= nBands; i++) {
         // The overviews are low resolution copies of the current one.
-        GDALMRFRasterBand *band = newMRFRasterBand(this, current, i);
+        MRFRasterBand *band = newMRFRasterBand(this, current, i);
         if (!band)
             return CE_Failure;
 
@@ -1518,20 +1527,20 @@ static inline bool make_absolute(CPLString &name, const CPLString &path)
 /**
 *\brief Get the source dataset, open it if necessary
 */
-GDALDataset *GDALMRFDataset::GetSrcDS() {
+GDALDataset *MRFDataset::GetSrcDS() {
     if (poSrcDS) return poSrcDS;
     if (source.empty()) return nullptr;
 
     // Try open the source dataset as is
     poSrcDS = GDALDataset::FromHandle(GDALOpenShared(source.c_str(), GA_ReadOnly));
 
-    // It the open failes, try again with the current dataset path prepended
+    // It the open fails, try again with the current dataset path prepended
     if (!poSrcDS && make_absolute(source, fname))
         poSrcDS = GDALDataset::FromHandle(GDALOpenShared(source.c_str(), GA_ReadOnly));
 
     if (0 == source.find("<MRF_META>") && has_path(fname))
     {   // MRF XML source, might need to patch the file names with the current one
-        GDALMRFDataset *poMRFDS = dynamic_cast<GDALMRFDataset *>(poSrcDS);
+        MRFDataset *poMRFDS = dynamic_cast<MRFDataset *>(poSrcDS);
         if( !poMRFDS )
         {
             delete poSrcDS;
@@ -1551,7 +1560,7 @@ GDALDataset *GDALMRFDataset::GetSrcDS() {
 * @return size of the index file
 */
 
-GIntBig GDALMRFDataset::AddOverviews(int scaleIn) {
+GIntBig MRFDataset::AddOverviews(int scaleIn) {
     // Fit the overlays
     ILImage img = current;
     while (1 != img.pagecount.x*img.pagecount.y)
@@ -1571,7 +1580,7 @@ GIntBig GDALMRFDataset::AddOverviews(int scaleIn) {
 
         // Create and register the the overviews for each band
         for (int i = 1; i <= nBands; i++) {
-            GDALMRFRasterBand *b = reinterpret_cast<GDALMRFRasterBand *>(GetRasterBand(i));
+            MRFRasterBand *b = reinterpret_cast<MRFRasterBand *>(GetRasterBand(i));
             if (!(b->GetOverview(static_cast<int>(img.size.l) - 1)))
                 b->AddOverview(newMRFRasterBand(this, img, i, static_cast<int>(img.size.l)));
         }
@@ -1582,7 +1591,7 @@ GIntBig GDALMRFDataset::AddOverviews(int scaleIn) {
 }
 
 // CreateCopy implemented based on Create
-GDALDataset *GDALMRFDataset::CreateCopy(const char *pszFilename,
+GDALDataset *MRFDataset::CreateCopy(const char *pszFilename,
     GDALDataset *poSrcDS, int /*bStrict*/, char **papszOptions,
     GDALProgressFunc pfnProgress, void *pProgressData)
 {
@@ -1613,13 +1622,13 @@ GDALDataset *GDALMRFDataset::CreateCopy(const char *pszFilename,
         options = CSLAddIfMissing(options, "BLOCKYSIZE", PrintDouble(yb, "%d").c_str());
     }
 
-    GDALMRFDataset *poDS = nullptr;
+    MRFDataset *poDS = nullptr;
     try {
-        poDS = reinterpret_cast<GDALMRFDataset *>(
+        poDS = reinterpret_cast<MRFDataset *>(
             Create(pszFilename, x, y, nBands, dt, options));
 
         if (poDS == nullptr || poDS->bCrystalized)
-            throw CPLString().Printf("Can't create %s",pszFilename);
+            throw CPLString().Printf("MRF: Can't create %s",pszFilename);
 
         img = poDS->current; // Deal with the current one here
 
@@ -1665,7 +1674,8 @@ GDALDataset *GDALMRFDataset::CreateCopy(const char *pszFilename,
             poDS->SetColorTable(poSrcBand1->GetColorTable()->Clone());
 
         // Finally write the XML in the right file name
-        poDS->Crystalize();
+        if (!poDS->Crystalize())
+            throw CPLString("MRF: Error creating files");
     }
     catch (const CPLString& e) {
         if (poDS)
@@ -1751,7 +1761,7 @@ template<typename T> static void ZenFilter(T* buffer, GByte *mask, int nPixels,
 // Custom CopyWholeRaster for Zen JPEG, called when the input has a PER_DATASET mask
 // Works like GDALDatasetCopyWholeRaster, but it does filter the input data based on the mask
 //
-CPLErr GDALMRFDataset::ZenCopy(GDALDataset *poSrc, GDALProgressFunc pfnProgress, void * pProgressData)
+CPLErr MRFDataset::ZenCopy(GDALDataset *poSrc, GDALProgressFunc pfnProgress, void * pProgressData)
 {
     VALIDATE_POINTER1(poSrc, "MRF:ZenCopy", CE_Failure);
 
@@ -1897,7 +1907,7 @@ CPLErr GDALMRFDataset::ZenCopy(GDALDataset *poSrc, GDALProgressFunc pfnProgress,
 
 // Apply open options to the current dataset
 // Called before the configuration is read
-void GDALMRFDataset::ProcessOpenOptions(char **papszOptions)
+void MRFDataset::ProcessOpenOptions(char **papszOptions)
 {
     CPLStringList opt(papszOptions, FALSE);
     no_errors = opt.FetchBoolean("NOERRORS", FALSE);
@@ -1907,7 +1917,7 @@ void GDALMRFDataset::ProcessOpenOptions(char **papszOptions)
 }
 
 // Apply create options to the current dataset, only valid during creation
-void GDALMRFDataset::ProcessCreateOptions(char **papszOptions)
+void MRFDataset::ProcessCreateOptions(char **papszOptions)
 {
     assert(!bCrystalized);
     CPLStringList opt(papszOptions, FALSE);
@@ -1936,7 +1946,7 @@ void GDALMRFDataset::ProcessCreateOptions(char **papszOptions)
     val = opt.FetchNameValue("BLOCKSIZE");
     if (val) img.pagesize.x = img.pagesize.y = atoi(val);
 
-    img.nbo = opt.FetchBoolean("NETBYTEORDER", FALSE);
+    img.nbo = opt.FetchBoolean("NETBYTEORDER", FALSE) != FALSE;
 
     val = opt.FetchNameValue("CACHEDSOURCE");
     if (val) {
@@ -1967,10 +1977,6 @@ void GDALMRFDataset::ProcessCreateOptions(char **papszOptions)
         img.pagesize.c = img.size.c;
 
     // Compression dependent fixups
-#if defined(LERC)
-    if (IL_LERC == img.comp)
-        img.pagesize.c = 1;
-#endif
 }
 
 /**
@@ -1981,18 +1987,17 @@ void GDALMRFDataset::ProcessCreateOptions(char **papszOptions)
  */
 
 GDALDataset *
-GDALMRFDataset::Create(const char * pszName,
+MRFDataset::Create(const char * pszName,
     int nXSize, int nYSize, int nBands,
     GDALDataType eType, char ** papszOptions)
-
-{   // Pending create
+{
     if( nBands == 0 )
     {
         CPLError(CE_Failure, CPLE_NotSupported, "nBands == 0 not supported");
         return nullptr;
     }
 
-    GDALMRFDataset *poDS = new GDALMRFDataset();
+    MRFDataset *poDS = new MRFDataset();
     CPLErr err = CE_None;
     poDS->fname = pszName;
     poDS->nBands = nBands;
@@ -2011,6 +2016,21 @@ GDALMRFDataset::Create(const char * pszName,
         poDS->fname.resize(pos); // Cut the ornamentations
     }
 
+    // Try creating the mrf file early, to avoid failing on Crystalize later
+    if (!STARTS_WITH(poDS->fname.c_str(), "<MRF_META>")) {
+        // Try opening it first, even though we still clobber it later
+        VSILFILE* mainfile = VSIFOpenL(poDS->fname.c_str(), "r+b");
+        if (!mainfile) { // Then try creating it
+            mainfile = VSIFOpenL(poDS->fname.c_str(), "w+b");
+            if (!mainfile) {
+                CPLError(CE_Failure, CPLE_OpenFailed, "MRF: Can't open %s for writing", poDS->fname.c_str());
+                delete poDS;
+                return nullptr;
+            }
+        }
+        VSIFCloseL(mainfile);
+    }
+
     // Use the full, set some initial parameters
     ILImage &img = poDS->full;
     img.size = ILSize(nXSize, nYSize, 1, nBands);
@@ -2022,7 +2042,7 @@ GDALMRFDataset::Create(const char * pszName,
     img.dataoffset = 0;
     img.idxoffset = 0;
     img.hasNoData = false;
-    img.nbo = FALSE;
+    img.nbo = false;
 
     // Set the guard that tells us it needs saving before IO can take place
     poDS->bCrystalized = FALSE;
@@ -2077,28 +2097,33 @@ GDALMRFDataset::Create(const char * pszName,
     return poDS;
 }
 
-void GDALMRFDataset::Crystalize()
-
+int MRFDataset::Crystalize()
 {
-    if (bCrystalized || eAccess != GA_Update)
-        return;
+    if (bCrystalized || eAccess != GA_Update) {
+        bCrystalized = TRUE;
+        return TRUE;
+    }
 
     // No need to write to disk if there is no filename.  This is a
     // memory only dataset.
     if (strlen(GetDescription()) == 0
-        || EQUALN(GetDescription(), "<MRF_META>", 10))
-        return;
+        || EQUALN(GetDescription(), "<MRF_META>", 10)) {
+        bCrystalized = TRUE;
+        return TRUE;
+    }
 
     CPLXMLNode *config = BuildConfig();
-    WriteConfig(config);
+    if (!WriteConfig(config))
+        return FALSE;
     CPLDestroyXMLNode(config);
     if (!nocopy && (!IdxFP() || !DataFP()))
-        throw CPLString().Printf("MRF: %s", strerror(errno));
+        return FALSE;
     bCrystalized = TRUE;
+    return TRUE;
 }
 
 // Copy the first index at the end of the file and bump the version count
-CPLErr GDALMRFDataset::AddVersion()
+CPLErr MRFDataset::AddVersion()
 {
     VSILFILE *l_ifp = IdxFP();
 
@@ -2121,7 +2146,7 @@ CPLErr GDALMRFDataset::AddVersion()
 // To make it multi-processor safe, open the file in append mode
 // and verify after write
 //
-CPLErr GDALMRFDataset::WriteTile(void *buff, GUIntBig infooffset, GUIntBig size)
+CPLErr MRFDataset::WriteTile(void *buff, GUIntBig infooffset, GUIntBig size)
 {
     CPLErr ret = CE_None;
     ILIdx tinfo = { 0, 0 };
@@ -2263,7 +2288,7 @@ CPLErr GDALMRFDataset::WriteTile(void *buff, GUIntBig infooffset, GUIntBig size)
     return ret;
 }
 
-CPLErr GDALMRFDataset::SetGeoTransform(double *gt)
+CPLErr MRFDataset::SetGeoTransform(double *gt)
 
 {
     if (GetAccess() == GA_Update)
@@ -2277,17 +2302,17 @@ CPLErr GDALMRFDataset::SetGeoTransform(double *gt)
     return CE_Failure;
 }
 
-bool GDALMRFDataset::IsSingleTile()
+bool MRFDataset::IsSingleTile()
 {
     if (current.pagecount.l != 1 || !source.empty() || nullptr == DataFP())
         return FALSE;
-    return 0 == reinterpret_cast<GDALMRFRasterBand *>(GetRasterBand(1))->GetOverviewCount();
+    return 0 == reinterpret_cast<MRFRasterBand *>(GetRasterBand(1))->GetOverviewCount();
 }
 
 /*
 *  Returns 0,1,0,0,0,1 even if it was not set
 */
-CPLErr GDALMRFDataset::GetGeoTransform(double *gt)
+CPLErr MRFDataset::GetGeoTransform(double *gt)
 {
     memcpy(gt, GeoTransform, 6 * sizeof(double));
     if (GetMetadata("RPC") || GetGCPCount())
@@ -2303,7 +2328,7 @@ CPLErr GDALMRFDataset::GetGeoTransform(double *gt)
 * The bias is non-zero only when the cloned index is read
 */
 
-CPLErr GDALMRFDataset::ReadTileIdx(ILIdx &tinfo, const ILSize &pos, const ILImage &img, const GIntBig bias)
+CPLErr MRFDataset::ReadTileIdx(ILIdx &tinfo, const ILSize &pos, const ILImage &img, const GIntBig bias)
 
 {
     VSILFILE *l_ifp = IdxFP();
@@ -2363,7 +2388,7 @@ CPLErr GDALMRFDataset::ReadTileIdx(ILIdx &tinfo, const ILSize &pos, const ILImag
     ILIdx *buffer = &buf[0]; // Buffer to copy the source to the clone index
 
     // Fetch the data from the cloned index
-    GDALMRFDataset *pSrc = static_cast<GDALMRFDataset *>(GetSrcDS());
+    MRFDataset *pSrc = static_cast<MRFDataset *>(GetSrcDS());
     if( pSrc == nullptr )
     {
         CPLError(CE_Failure, CPLE_FileIO, "Can't open cloned source index");
