@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: msgdataset.h e13dcd4dc171dfeed63f912ba06b9374ce4f3bb2 2018-03-18 21:37:41Z Even Rouault $
+ * $Id: msgdataset.h d23b5a0d22b88657e4fc31f2513701842f0b0585 2019-08-11 03:09:59 +0200 Even Rouault $
  *
  * Project:  MSG Driver
  * Purpose:  GDALDataset driver for MSG translator for read support.
@@ -42,7 +42,7 @@
 class MSGDataset;
 class ReflectanceCalculator;
 
-class MSGRasterBand : public GDALRasterBand
+class MSGRasterBand final: public GDALRasterBand
 {
   friend class MSGDataset;
 
@@ -65,7 +65,7 @@ class MSGRasterBand : public GDALRasterBand
 /************************************************************************/
 /*                      MSGDataset                                       */
 /************************************************************************/
-class MSGDataset : public GDALDataset
+class MSGDataset final: public GDALDataset
 {
   friend class MSGRasterBand;
 
@@ -74,8 +74,15 @@ class MSGDataset : public GDALDataset
     virtual ~MSGDataset();
 
     static GDALDataset *Open( GDALOpenInfo * );
-    virtual const char *GetProjectionRef() override;
-    virtual CPLErr SetProjection( const char * ) override;
+    virtual const char *_GetProjectionRef() override;
+    virtual CPLErr _SetProjection( const char * ) override;
+    const OGRSpatialReference* GetSpatialRef() const override {
+        return GetSpatialRefFromOldGetProjectionRef();
+    }
+    CPLErr SetSpatialRef(const OGRSpatialReference* poSRS) override {
+        return OldSetProjectionFromSetSpatialRef(poSRS);
+    }
+
     virtual CPLErr GetGeoTransform( double * padfTransform ) override;
 
   private:
