@@ -2,10 +2,10 @@
  *
  * Project:  NGSGEOID driver
  * Purpose:  GDALDataset driver for NGSGEOID dataset.
- * Author:   Even Rouault, <even dot rouault at mines dash paris dot org>
+ * Author:   Even Rouault, <even dot rouault at spatialys.com>
  *
  ******************************************************************************
- * Copyright (c) 2011, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2011, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -32,7 +32,7 @@
 #include "gdal_pam.h"
 #include "ogr_srs_api.h"
 
-CPL_CVSID("$Id: ngsgeoiddataset.cpp 8e5eeb35bf76390e3134a4ea7076dab7d478ea0e 2018-11-14 22:55:13 +0100 Even Rouault $")
+CPL_CVSID("$Id: ngsgeoiddataset.cpp a5d5ed208537a05de4437e97b6a09b7ba44f76c9 2020-03-24 08:27:48 +0100 Kai Pastor $")
 
 #define HEADER_SIZE (4 * 8 + 3 * 4)
 
@@ -44,7 +44,7 @@ CPL_CVSID("$Id: ngsgeoiddataset.cpp 8e5eeb35bf76390e3134a4ea7076dab7d478ea0e 201
 
 class NGSGEOIDRasterBand;
 
-class NGSGEOIDDataset : public GDALPamDataset
+class NGSGEOIDDataset final: public GDALPamDataset
 {
     friend class NGSGEOIDRasterBand;
 
@@ -79,7 +79,7 @@ class NGSGEOIDDataset : public GDALPamDataset
 /* ==================================================================== */
 /************************************************************************/
 
-class NGSGEOIDRasterBand : public GDALPamRasterBand
+class NGSGEOIDRasterBand final: public GDALPamRasterBand
 {
     friend class NGSGEOIDDataset;
 
@@ -467,7 +467,7 @@ void GDALRegister_NGSGEOID()
     poDriver->SetMetadataItem( GDAL_DCAP_RASTER, "YES" );
     poDriver->SetMetadataItem( GDAL_DMD_LONGNAME,
                                "NOAA NGS Geoid Height Grids" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "frmt_ngsgeoid.html" );
+    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/raster/ngsgeoid.html" );
     poDriver->SetMetadataItem( GDAL_DMD_EXTENSION, "bin" );
 
     poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
