@@ -6,7 +6,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2007, Waypoint Information Technology
- * Copyright (c) 2009-2012, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2009-2012, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -37,7 +37,7 @@
 #include "../../ogr/ogrsf_frmts/mitab/mitab.h"
 #endif
 
-CPL_CVSID("$Id: grcdataset.cpp 8e5eeb35bf76390e3134a4ea7076dab7d478ea0e 2018-11-14 22:55:13 +0100 Even Rouault $")
+CPL_CVSID("$Id: grcdataset.cpp f6099e5ed704166bf5cc113a053dd1b2725cb391 2020-03-22 11:20:10 +0100 Kai Pastor $")
 
 /************************************************************************/
 /* ==================================================================== */
@@ -46,7 +46,7 @@ CPL_CVSID("$Id: grcdataset.cpp 8e5eeb35bf76390e3134a4ea7076dab7d478ea0e 2018-11-
 /************************************************************************/
 class NWT_GRCRasterBand;
 
-class NWT_GRCDataset : public GDALPamDataset
+class NWT_GRCDataset final : public GDALPamDataset
 {
   friend class NWT_GRCRasterBand;
 
@@ -80,7 +80,7 @@ class NWT_GRCDataset : public GDALPamDataset
 /* ==================================================================== */
 /************************************************************************/
 
-class NWT_GRCRasterBand : public GDALPamRasterBand
+class NWT_GRCRasterBand final : public GDALPamRasterBand
 {
   friend class NWT_GRCDataset;
 
@@ -262,7 +262,7 @@ NWT_GRCDataset::~NWT_GRCDataset()
     delete poColorTable;
     CSLDestroy( papszCategories );
 
-    FlushCache();
+    NWT_GRCDataset::FlushCache();
     pGrd->fp = nullptr;       // this prevents nwtCloseGrid from closing the fp
     nwtCloseGrid( pGrd );
 
@@ -354,7 +354,7 @@ GDALDataset *NWT_GRCDataset::Open( GDALOpenInfo * poOpenInfo )
 
     poDS->pGrd->fp = poDS->fp;
 
-    if (!nwt_ParseHeader( poDS->pGrd, reinterpret_cast<char *>( poDS->abyHeader ) ) ||
+    if (!nwt_ParseHeader( poDS->pGrd, poDS->abyHeader ) ||
         !GDALCheckDatasetDimensions(poDS->pGrd->nXSide, poDS->pGrd->nYSide) ||
         poDS->pGrd->stClassDict == nullptr)
     {
@@ -411,7 +411,7 @@ void GDALRegister_NWT_GRC()
     poDriver->SetMetadataItem( GDAL_DMD_LONGNAME,
                                "Northwood Classified Grid Format .grc/.tab");
     poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC,
-                               "frmt_various.html#northwood_grc" );
+                               "drivers/raster/nwtgrd.html#driver-capabilities-nwt-grc" );
     poDriver->SetMetadataItem( GDAL_DMD_EXTENSION, "grc" );
     poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
 
