@@ -7,7 +7,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2009, Frank Warmerdam <warmerdam@pobox.com>
- * Copyright (c) 2009-2013, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2009-2013, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -33,7 +33,7 @@
 
 #include <algorithm>
 
-CPL_CVSID("$Id: pcidskdataset2.cpp 59e42692cf156fd8e2d622fc6baa8923205cf4db 2018-08-28 11:55:58 +0200 Even Rouault $")
+CPL_CVSID("$Id: pcidskdataset2.cpp a5d5ed208537a05de4437e97b6a09b7ba44f76c9 2020-03-24 08:27:48 +0100 Kai Pastor $")
 
 const PCIDSK::PCIDSKInterfaces *PCIDSK2GetInterfaces(void);
 
@@ -99,7 +99,7 @@ PCIDSK2Band::PCIDSK2Band( PCIDSKChannel *poChannelIn )
 
     if( poChannel->GetType() == CHN_BIT )
     {
-        SetMetadataItem( "NBITS", "1", "IMAGE_STRUCTURE" );
+        PCIDSK2Band::SetMetadataItem( "NBITS", "1", "IMAGE_STRUCTURE" );
 
         if( !STARTS_WITH_CI(poChannel->GetDescription().c_str(),
                     "Contents Not Specified") )
@@ -517,8 +517,9 @@ void PCIDSK2Band::RefreshOverviewList()
 /* -------------------------------------------------------------------- */
     for( int iOver = 0; iOver < poChannel->GetOverviewCount(); iOver++ )
     {
-        apoOverviews.push_back(
-            new PCIDSK2Band( poChannel->GetOverview(iOver) ) );
+        auto poOvrBand = new PCIDSK2Band( poChannel->GetOverview(iOver) );
+        poOvrBand->eAccess = eAccess;
+        apoOverviews.push_back( poOvrBand );
     }
 }
 
@@ -710,7 +711,7 @@ char **PCIDSK2Band::GetMetadataDomainList()
 {
     return BuildMetadataDomainList(GDALPamRasterBand::GetMetadataDomainList(),
                                    TRUE,
-                                   "", NULL);
+                                   "", nullptr);
 }
 
 /************************************************************************/
@@ -828,6 +829,9 @@ PCIDSK2Dataset::~PCIDSK2Dataset()
         apoLayers.pop_back();
     }
 
+    if( m_poSRS )
+        m_poSRS->Release();
+
     try {
         if( poFile != nullptr)
             delete poFile;
@@ -1144,7 +1148,7 @@ char **PCIDSK2Dataset::GetMetadataDomainList()
 {
     return BuildMetadataDomainList(GDALPamDataset::GetMetadataDomainList(),
                                    TRUE,
-                                   "", NULL);
+                                   "", nullptr);
 }
 
 /************************************************************************/
@@ -1331,14 +1335,12 @@ CPLErr PCIDSK2Dataset::GetGeoTransform( double * padfTransform )
 }
 
 /************************************************************************/
-/*                           SetProjection()                            */
+/*                           SetSpatialRef()                            */
 /************************************************************************/
 
-CPLErr PCIDSK2Dataset::SetProjection( const char *pszWKT )
+CPLErr PCIDSK2Dataset::SetSpatialRef( const OGRSpatialReference* poSRS )
 
 {
-    osSRS = "";
-
     PCIDSKGeoref *poGeoref = nullptr;
 
     try
@@ -1353,20 +1355,18 @@ CPLErr PCIDSK2Dataset::SetProjection( const char *pszWKT )
 
     if( poGeoref == nullptr )
     {
-        return GDALPamDataset::SetProjection( pszWKT );
+        return GDALPamDataset::SetSpatialRef( poSRS );
     }
 
     char *pszGeosys = nullptr;
     char *pszUnits = nullptr;
     double *padfPrjParams = nullptr;
 
-    OGRSpatialReference oSRS;
-
-    if( ! (oSRS.importFromWkt(pszWKT ) == OGRERR_NONE
-        && oSRS.exportToPCI( &pszGeosys, &pszUnits,
-                             &padfPrjParams ) == OGRERR_NONE ) )
+    if( poSRS == nullptr ||
+        poSRS->exportToPCI( &pszGeosys, &pszUnits,
+                             &padfPrjParams ) != OGRERR_NONE )
     {
-        return GDALPamDataset::SetProjection( pszWKT );
+        return GDALPamDataset::SetSpatialRef( poSRS );
     }
 
     if( GetAccess() == GA_ReadOnly )
@@ -1427,13 +1427,13 @@ CPLErr PCIDSK2Dataset::SetProjection( const char *pszWKT )
 }
 
 /************************************************************************/
-/*                          GetProjectionRef()                          */
+/*                          GetSpatialRef()                             */
 /************************************************************************/
 
-const char *PCIDSK2Dataset::GetProjectionRef()
+const OGRSpatialReference *PCIDSK2Dataset::GetSpatialRef() const
 {
-    if( osSRS != "" )
-        return osSRS.c_str();
+    if( m_poSRS )
+        return m_poSRS;
 
     PCIDSKGeoref *poGeoref = nullptr;
 
@@ -1449,8 +1449,7 @@ const char *PCIDSK2Dataset::GetProjectionRef()
 
     if( poGeoref == nullptr )
     {
-        osSRS = GDALPamDataset::GetProjectionRef();
-        return osSRS.c_str();
+        return GDALPamDataset::GetSpatialRef();
     }
 
     CPLString osGeosys;
@@ -1482,20 +1481,17 @@ const char *PCIDSK2Dataset::GetProjectionRef()
     }
 
     OGRSpatialReference oSRS;
+    oSRS.SetAxisMappingStrategy(OAMS_TRADITIONAL_GIS_ORDER);
     if( oSRS.importFromPCI( osGeosys, pszUnits,
                             &(adfParameters[0]) ) == OGRERR_NONE )
     {
-        char *pszWKT = nullptr;
-        oSRS.exportToWkt( &pszWKT );
-        osSRS = pszWKT;
-        CPLFree( pszWKT );
+        m_poSRS = oSRS.Clone();
+        return m_poSRS;
     }
     else
     {
-        osSRS = GDALPamDataset::GetProjectionRef();
+        return GDALPamDataset::GetSpatialRef();
     }
-
-    return osSRS.c_str();
 }
 
 /************************************************************************/
@@ -2255,7 +2251,7 @@ void GDALRegister_PCIDSK()
     poDriver->SetMetadataItem( GDAL_DCAP_RASTER, "YES" );
     poDriver->SetMetadataItem( GDAL_DCAP_VECTOR, "YES" );
     poDriver->SetMetadataItem( GDAL_DMD_LONGNAME, "PCIDSK Database File" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "frmt_pcidsk.html" );
+    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/raster/pcidsk.html" );
     poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
     poDriver->SetMetadataItem( GDAL_DMD_EXTENSION, "pix" );
     poDriver->SetMetadataItem( GDAL_DMD_CREATIONDATATYPES,
