@@ -212,9 +212,9 @@ CPCIDSKAPModelSegment::CPCIDSKAPModelSegment(PCIDSKFile *fileIn, int segmentIn,
     CPCIDSKSegment(fileIn, segmentIn, segment_pointer)
 {
     filled_ = false;
-    io_params_ = NULL;
-    eo_params_ = NULL;
-    misc_params_ = NULL;
+    io_params_ = nullptr;
+    eo_params_ = nullptr;
+    misc_params_ = nullptr;
     UpdateFromDisk();
 }
  
@@ -252,7 +252,7 @@ unsigned int CPCIDSKAPModelSegment::GetDownsampleFactor(void) const
 // Interior Orientation Parameters
 PCIDSKAPModelIOParams const& CPCIDSKAPModelSegment::GetInteriorOrientationParams(void) const
 {
-    if (io_params_ == NULL) {
+    if (io_params_ == nullptr) {
         throw PCIDSKException("There was a failure in reading the APModel IO params.");
     }
     return *io_params_;
@@ -261,7 +261,7 @@ PCIDSKAPModelIOParams const& CPCIDSKAPModelSegment::GetInteriorOrientationParams
 // Exterior Orientation Parameters
 PCIDSKAPModelEOParams const& CPCIDSKAPModelSegment::GetExteriorOrientationParams(void) const
 {
-    if (eo_params_ == NULL) {
+    if (eo_params_ == nullptr) {
         throw PCIDSKException("There was a failure in reading the APModel EO params.");
     }
     return *eo_params_;
@@ -269,7 +269,7 @@ PCIDSKAPModelEOParams const& CPCIDSKAPModelSegment::GetExteriorOrientationParams
 
 PCIDSKAPModelMiscParams const& CPCIDSKAPModelSegment::GetAdditionalParams(void) const
 {
-    if (misc_params_ == NULL) {
+    if (misc_params_ == nullptr) {
         throw PCIDSKException("There was a failure in reading the APModel camera params.");
     }
     return *misc_params_;
