@@ -97,7 +97,8 @@ void CPCIDSKGeoref::Load()
 /* -------------------------------------------------------------------- */
 /*      Load the segment contents into a buffer.                        */
 /* -------------------------------------------------------------------- */
-    seg_data.SetSize( (int) (data_size - 1024) );
+    // data_size < 1024 will throw an exception in SetSize()
+    seg_data.SetSize( data_size < 1024 ? -1 : (int) (data_size - 1024) );
 
     ReadFromFile( seg_data.buffer, 0, data_size - 1024 );
 
