@@ -2,10 +2,10 @@
  *
  * Project:  PDF driver
  * Purpose:  GDALDataset driver for PDF dataset (writable vector dataset)
- * Author:   Even Rouault, <even dot rouault at mines dash paris dot org>
+ * Author:   Even Rouault, <even dot rouault at spatialys.com>
  *
  ******************************************************************************
- * Copyright (c) 2010-2014, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2010-2014, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -31,7 +31,7 @@
 #include "memdataset.h"
 #include "pdfcreatefromcomposition.h"
 
-CPL_CVSID("$Id: pdfwritabledataset.cpp 5a04126b888092d810db40222dce30479b5ff901 2019-04-09 18:05:52 +0200 Even Rouault $")
+CPL_CVSID("$Id: pdfwritabledataset.cpp 3583f56e13546beb20b7f0d16a5f13b6940a70d1 2019-08-10 12:12:12 +0200 Even Rouault $")
 
 /************************************************************************/
 /*                      PDFWritableVectorDataset()                      */
@@ -194,6 +194,50 @@ OGRErr PDFWritableVectorDataset::SyncToDisk()
         return OGRERR_FAILURE;
     }
 
+    double dfRatio = (sGlobalExtent.MaxY - sGlobalExtent.MinY) / (sGlobalExtent.MaxX - sGlobalExtent.MinX);
+
+    int nWidth, nHeight;
+
+    if (dfRatio < 1)
+    {
+        nWidth = 1024;
+        const double dfHeight = nWidth * dfRatio;
+        if( dfHeight < 1 || dfHeight > INT_MAX || CPLIsNan(dfHeight) )
+        {
+            CPLError(CE_Failure, CPLE_AppDefined, "Invalid image dimensions");
+            return OGRERR_FAILURE;
+        }
+        nHeight = static_cast<int>(dfHeight);
+    }
+    else
+    {
+        nHeight = 1024;
+        const double dfWidth = nHeight / dfRatio;
+        if( dfWidth < 1 || dfWidth > INT_MAX || CPLIsNan(dfWidth) )
+        {
+            CPLError(CE_Failure, CPLE_AppDefined, "Invalid image dimensions");
+            return OGRERR_FAILURE;
+        }
+        nWidth = static_cast<int>(dfWidth);
+    }
+
+    double adfGeoTransform[6];
+    adfGeoTransform[0] = sGlobalExtent.MinX;
+    adfGeoTransform[1] = (sGlobalExtent.MaxX - sGlobalExtent.MinX) / nWidth;
+    adfGeoTransform[2] = 0;
+    adfGeoTransform[3] = sGlobalExtent.MaxY;
+    adfGeoTransform[4] = 0;
+    adfGeoTransform[5] = - (sGlobalExtent.MaxY - sGlobalExtent.MinY) / nHeight;
+
+    // Do again a check against 0, because the above divisions might
+    // transform a difference close to 0, to plain 0.
+    if (adfGeoTransform[1] == 0 || adfGeoTransform[5] == 0)
+    {
+        CPLError(CE_Failure, CPLE_AppDefined,
+                 "Cannot compute spatial extent of features");
+        return OGRERR_FAILURE;
+    }
+
     PDFCompressMethod eStreamCompressMethod = COMPRESS_DEFLATE;
     const char* pszStreamCompressMethod = CSLFetchNameValue(papszOptions, "STREAM_COMPRESS");
     if (pszStreamCompressMethod)
@@ -284,43 +328,8 @@ OGRErr PDFWritableVectorDataset::SyncToDisk()
 
     GDALPDFWriter oWriter(fp);
 
-    double dfRatio = (sGlobalExtent.MaxY - sGlobalExtent.MinY) / (sGlobalExtent.MaxX - sGlobalExtent.MinX);
-
-    int nWidth, nHeight;
-
-    if (dfRatio < 1)
-    {
-        nWidth = 1024;
-        const double dfHeight = nWidth * dfRatio;
-        if( dfHeight < 1 || dfHeight > INT_MAX || CPLIsNan(dfHeight) )
-        {
-            CPLError(CE_Failure, CPLE_AppDefined, "Invalid image dimensions");
-            return OGRERR_FAILURE;
-        }
-        nHeight = static_cast<int>(dfHeight);
-    }
-    else
-    {
-        nHeight = 1024;
-        const double dfWidth = nHeight / dfRatio;
-        if( dfWidth < 1 || dfWidth > INT_MAX || CPLIsNan(dfWidth) )
-        {
-            CPLError(CE_Failure, CPLE_AppDefined, "Invalid image dimensions");
-            return OGRERR_FAILURE;
-        }
-        nWidth = static_cast<int>(dfWidth);
-    }
-
     GDALDataset* poSrcDS = MEMDataset::Create( "MEM:::", nWidth, nHeight, 0, GDT_Byte, nullptr );
 
-    double adfGeoTransform[6];
-    adfGeoTransform[0] = sGlobalExtent.MinX;
-    adfGeoTransform[1] = (sGlobalExtent.MaxX - sGlobalExtent.MinX) / nWidth;
-    adfGeoTransform[2] = 0;
-    adfGeoTransform[3] = sGlobalExtent.MaxY;
-    adfGeoTransform[4] = 0;
-    adfGeoTransform[5] = - (sGlobalExtent.MaxY - sGlobalExtent.MinY) / nHeight;
-
     poSrcDS->SetGeoTransform(adfGeoTransform);
 
     OGRSpatialReference* poSRS = papoLayers[0]->GetSpatialRef();
