@@ -2,10 +2,10 @@
  *
  * Project:  GDAL Rasterlite driver
  * Purpose:  Implement GDAL Rasterlite support using OGR SQLite driver
- * Author:   Even Rouault, <even dot rouault at mines dash paris dot org>
+ * Author:   Even Rouault, <even dot rouault at spatialys.com>
  *
  **********************************************************************
- * Copyright (c) 2009-2012, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2009-2012, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -32,7 +32,7 @@
 
 #include "rasterlitedataset.h"
 
-CPL_CVSID("$Id: rasterlitecreatecopy.cpp 60ca1b5baf5621486946751a91177c9e5e79cde8 2018-03-27 18:22:50 +0200 Even Rouault $")
+CPL_CVSID("$Id: rasterlitecreatecopy.cpp 355b41831cd2685c85d1aabe5b95665a2c6e99b7 2019-06-19 17:07:04 +0200 Even Rouault $")
 
 /************************************************************************/
 /*                  RasterliteGetTileDriverOptions ()                   */
@@ -121,6 +121,8 @@ static int RasterliteInsertSRID(OGRDataSourceH hDS, const char* pszWKT)
         OGRSpatialReferenceH hSRS = OSRNewSpatialReference(pszWKT);
         if (hSRS)
         {
+            OSRSetAxisMappingStrategy(hSRS, OAMS_TRADITIONAL_GIS_ORDER);
+
             const char* pszAuthorityName = OSRGetAuthorityName(hSRS, nullptr);
             if (pszAuthorityName) osAuthorityName = pszAuthorityName;
 
