@@ -34,7 +34,7 @@
 #include <cmath>
 #include <cstdlib>
 
-CPL_CVSID("$Id: btdataset.cpp f6099e5ed704166bf5cc113a053dd1b2725cb391 2020-03-22 11:20:10 +0100 Kai Pastor $")
+CPL_CVSID("$Id: btdataset.cpp 8ca42e1b9c2e54b75d35e49885df9789a2643aa4 2020-05-17 21:43:40 +0200 Even Rouault $")
 
 /************************************************************************/
 /* ==================================================================== */
@@ -508,11 +508,11 @@ CPLErr BTDataset::_SetProjection( const char *pszNewProjection )
 /*      Parse projection.                                               */
 /* -------------------------------------------------------------------- */
     OGRSpatialReference oSRS( pszProjection );
-    GInt16  nShortTemp = 0;
 
 /* -------------------------------------------------------------------- */
 /*      Linear units.                                                   */
 /* -------------------------------------------------------------------- */
+#if 0
     if( oSRS.IsGeographic() )
     {
         // nShortTemp = 0;
@@ -529,8 +529,8 @@ CPLErr BTDataset::_SetProjection( const char *pszNewProjection )
         else
             nShortTemp = 1;
     }
-
-    nShortTemp = CPL_LSBWORD16( 1 );
+#endif
+    GInt16 nShortTemp = CPL_LSBWORD16( 1 );
     memcpy( abyHeader + 22, &nShortTemp, 2 );
 
 /* -------------------------------------------------------------------- */
