@@ -55,7 +55,7 @@
 #include "ogr_spatialref.h"
 #include "ogr_srs_api.h"
 
-CPL_CVSID("$Id: envidataset.cpp 02822b670881d4508f4e8ecde755d29bd745139b 2020-08-17 12:27:19 +0200 Even Rouault $")
+CPL_CVSID("$Id: envidataset.cpp 48a13a1c21ceb752549164fc3e14135bd4bc5006 2020-08-17 12:27:19 +0200 Even Rouault $")
 
 // TODO(schwehr): This really should be defined in port/somewhere.h.
 constexpr double kdfDegToRad = M_PI / 180.0;
@@ -458,6 +458,13 @@ void ENVIDataset::FlushCache()
     }
     bOK &= VSIFPrintfL(fp, "}\n") >= 0;
 
+    int bHasNoData = FALSE;
+    double dfNoDataValue = band->GetNoDataValue(&bHasNoData);
+    if( bHasNoData )
+    {
+        bOK &= VSIFPrintfL(fp, "data ignore value = %.18g\n", dfNoDataValue) >= 0;
+    }
+
     // Write the metadata that was read into the ENVI domain.
     char **papszENVIMetadata = GetMetadata("ENVI");
 
@@ -497,7 +504,8 @@ void ENVIDataset::FlushCache()
              poKey == "class names" ||
              poKey == "band names" ||
              poKey == "map info" ||
-             poKey == "projection info" )
+             poKey == "projection info" ||
+             poKey == "data ignore value" )
         {
             CSLDestroy(papszTokens);
             continue;
@@ -2807,6 +2815,16 @@ CPLErr ENVIRasterBand::SetCategoryNames( char **papszCategoryNamesIn )
     return RawRasterBand::SetCategoryNames(papszCategoryNamesIn);
 }
 
+/************************************************************************/
+/*                            SetNoDataValue()                          */
+/************************************************************************/
+
+CPLErr ENVIRasterBand::SetNoDataValue( double dfNoDataValue )
+{
+    reinterpret_cast<ENVIDataset *>(poDS)->bHeaderDirty = true;
+    return RawRasterBand::SetNoDataValue(dfNoDataValue);
+}
+
 /************************************************************************/
 /*                         GDALRegister_ENVI()                          */
 /************************************************************************/
