@@ -34,7 +34,7 @@
 #include "ogr_spatialref.h"
 #include "rawdataset.h"
 
-CPL_CVSID("$Id: lcpdataset.cpp a3f8b8b84d38c65717e1d9f08f8be85782cf7094 2020-06-02 15:04:46 +0200 Even Rouault $")
+CPL_CVSID("$Id: lcpdataset.cpp e7efc038927632305377810d471f2eee5953c3d4 2020-06-02 15:04:46 +0200 Even Rouault $")
 
 constexpr size_t LCP_HEADER_SIZE = 7316;
 constexpr int LCP_MAX_BANDS = 10;
@@ -1364,7 +1364,6 @@ GDALDataset *LCPDataset::CreateCopy( const char * pszFilename,
             VSIMalloc3( sizeof( GInt32 ), nBands, LCP_MAX_CLASSES ) );
     memset( panClasses, 0, sizeof( GInt32 ) * nBands * LCP_MAX_CLASSES );
 
-    CPLErr eErr = CE_None;
     if( bCalculateStats )
     {
 
@@ -1372,7 +1371,7 @@ GDALDataset *LCPDataset::CreateCopy( const char * pszFilename,
         {
             GDALRasterBand *poBand = poSrcDS->GetRasterBand( i + 1 );
             double dfDummy = 0.0;
-            eErr = poBand->GetStatistics( FALSE, TRUE, &padfMin[i],
+            CPLErr eErr = poBand->GetStatistics( FALSE, TRUE, &padfMin[i],
                                           &padfMax[i], &dfDummy, &dfDummy );
             if( eErr != CE_None )
             {
@@ -1596,7 +1595,7 @@ GDALDataset *LCPDataset::CreateCopy( const char * pszFilename,
         for( int iBand = 0; iBand < nBands; iBand++ )
         {
             GDALRasterBand * poBand = poSrcDS->GetRasterBand( iBand+1 );
-            eErr = poBand->RasterIO( GF_Read, 0, iLine, nXSize, 1,
+            CPLErr eErr = poBand->RasterIO( GF_Read, 0, iLine, nXSize, 1,
                                      panScanline + iBand, nXSize, 1, GDT_Int16,
                                      nBands * 2, nBands * nXSize * 2, nullptr );
             // Not sure what to do here.
