@@ -49,7 +49,7 @@
 
 #include "rmfdataset.h"
 
-CPL_CVSID("$Id: rmflzw.cpp d898728d97791409670c719b872025e2fd9bffa6 2019-08-13 17:35:26 +0200 Even Rouault $")
+CPL_CVSID("$Id: rmflzw.cpp b55a33407a80673ec314b165c82f47dd02e9dc9c 2020-04-27 20:37:55 +0200 Even Rouault $")
 
 // Code marks that there is no predecessor in the string
 constexpr GUInt32 NO_PRED = 0xFFFF;
@@ -82,7 +82,7 @@ static GUInt32 UnsanitizedMul(GUInt32 a, GUInt32 b)
     return a * b;
 }
 
-static void LZWUpdateTab(LZWStringTab *poCodeTab, GUInt32 iPred, char bFoll)
+static void LZWUpdateTab(LZWStringTab *poCodeTab, GUInt32 iPred, char bFollow)
 {
 /* -------------------------------------------------------------------- */
 /* Hash uses the 'mid-square' algorithm. I.E. for a hash val of n bits  */
@@ -91,7 +91,7 @@ static void LZWUpdateTab(LZWStringTab *poCodeTab, GUInt32 iPred, char bFoll)
 /* It will NOT notice if the table is full. This must be handled        */
 /* elsewhere                                                            */
 /* -------------------------------------------------------------------- */
-    GUInt32 nLocal = CPLUnsanitizedAdd<GUInt32>(iPred, bFoll) | 0x0800;
+    GUInt32 nLocal = CPLUnsanitizedAdd<GUInt32>(iPred, bFollow) | 0x0800;
     nLocal = (UnsanitizedMul(nLocal, nLocal) >> 6) & 0x0FFF;      // middle 12 bits of result
 
     // If string is not used
@@ -117,7 +117,7 @@ static void LZWUpdateTab(LZWStringTab *poCodeTab, GUInt32 iPred, char bFoll)
     poCodeTab[nNext].bUsed = true;
     poCodeTab[nNext].iNext = 0;
     poCodeTab[nNext].iPredecessor = iPred;
-    poCodeTab[nNext].iFollower = static_cast<GByte>(bFoll);
+    poCodeTab[nNext].iFollower = static_cast<GByte>(bFollow);
 }
 
 /************************************************************************/
@@ -142,16 +142,16 @@ static LZWStringTab* LZWCreateTab()
 /*                            LZWFindIndex()                            */
 /************************************************************************/
 
-static GUInt32 LZWFindIndex(const LZWStringTab* poCodeTab, GUInt32 iPred, char bFoll)
+static GUInt32 LZWFindIndex(const LZWStringTab* poCodeTab, GUInt32 iPred, char bFollow)
 {
-    GUInt32 nLocal = CPLUnsanitizedAdd<GUInt32>(iPred, bFoll) | 0x0800;
+    GUInt32 nLocal = CPLUnsanitizedAdd<GUInt32>(iPred, bFollow) | 0x0800;
     nLocal = (UnsanitizedMul(nLocal, nLocal) >> 6) & 0x0FFF;      // middle 12 bits of result
 
     do
     {
         CPLAssert(nLocal < TABSIZE);
         if(poCodeTab[nLocal].iPredecessor == iPred &&
-           poCodeTab[nLocal].iFollower == static_cast<GByte>(bFoll))
+           poCodeTab[nLocal].iFollower == static_cast<GByte>(bFollow))
         {
             return nLocal;
         }
