@@ -6,7 +6,7 @@
  *
  ******************************************************************************
  * Copyright (c) 1999, Frank Warmerdam
- * Copyright (c) 2008-2011, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2011, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -32,7 +32,7 @@
 #include "ogr_spatialref.h"
 #include "sdts_al.h"
 
-CPL_CVSID("$Id: sdtsdataset.cpp 8e5eeb35bf76390e3134a4ea7076dab7d478ea0e 2018-11-14 22:55:13 +0100 Even Rouault $")
+CPL_CVSID("$Id: sdtsdataset.cpp f6099e5ed704166bf5cc113a053dd1b2725cb391 2020-03-22 11:20:10 +0100 Kai Pastor $")
 
 /**
  \file sdtsdataset.cpp
@@ -48,7 +48,7 @@ CPL_CVSID("$Id: sdtsdataset.cpp 8e5eeb35bf76390e3134a4ea7076dab7d478ea0e 2018-11
 
 class SDTSRasterBand;
 
-class SDTSDataset : public GDALPamDataset
+class SDTSDataset final: public GDALPamDataset
 {
     friend class SDTSRasterBand;
 
@@ -70,7 +70,7 @@ class SDTSDataset : public GDALPamDataset
     virtual CPLErr GetGeoTransform( double * ) override;
 };
 
-class SDTSRasterBand : public GDALPamRasterBand
+class SDTSRasterBand final: public GDALPamRasterBand
 {
     friend class SDTSDataset;
 
@@ -406,7 +406,7 @@ void GDALRegister_SDTS()
     poDriver->SetDescription( "SDTS" );
     poDriver->SetMetadataItem( GDAL_DCAP_RASTER, "YES" );
     poDriver->SetMetadataItem( GDAL_DMD_LONGNAME, "SDTS Raster" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "frmt_various.html#SDTS" );
+    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/raster/sdts.html" );
     poDriver->SetMetadataItem( GDAL_DMD_EXTENSION, "ddf" );
     poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
 
