@@ -54,7 +54,7 @@
 #include "ogr_core.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: vrtpansharpened.cpp 685b96644b37dcd526ccb68cbb763f67a4108800 2020-03-20 17:27:19 +0100 Even Rouault $")
+CPL_CVSID("$Id: vrtpansharpened.cpp 6363f9cc6462c0a160f9a232d03d4b435c949567 2020-11-17 19:21:57 +0100 Even Rouault $")
 
 /************************************************************************/
 /*                    GDALCreatePansharpenedVRT()                       */
@@ -180,6 +180,15 @@ int VRTPansharpenedDataset::CloseDependentDatasets()
     }
     nBands = 0;
 
+    // Destroy the overviews before m_poPansharpener as they might reference
+    // files that are in m_apoDatasetsToClose.
+    for( size_t i=0; i<m_apoOverviewDatasets.size();i++)
+    {
+        bHasDroppedRef = TRUE;
+        delete m_apoOverviewDatasets[i];
+    }
+    m_apoOverviewDatasets.resize(0);
+
     if( m_poPansharpener != nullptr )
     {
         // Delete the pansharper object before closing the dataset
@@ -198,13 +207,6 @@ int VRTPansharpenedDataset::CloseDependentDatasets()
         m_apoDatasetsToClose.resize(0);
     }
 
-    for( size_t i=0; i<m_apoOverviewDatasets.size();i++)
-    {
-        bHasDroppedRef = TRUE;
-        delete m_apoOverviewDatasets[i];
-    }
-    m_apoOverviewDatasets.resize(0);
-
     if( poMainDatasetLocal != this )
     {
         // To avoid killing us
