@@ -6,7 +6,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2006, Frank Warmerdam
- * Copyright (c) 2008-2013, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2013, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -155,7 +155,7 @@ CPLErr WCSRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
                                nBlockXSize * nResFactor,
                                nBlockYSize * nResFactor,
                                nBlockXSize, nBlockYSize,
-                               band_count, &nBand, &psResult );
+                               band_count, &nBand, nullptr, &psResult );
     if( eErr != CE_None )
         return eErr;
 
