@@ -39,7 +39,7 @@
 #include "cpl_error.h"
 #include "cpl_multiproc.h"
 
-CPL_CVSID("$Id: gdalhashsetbandblockcache.cpp c590dcec36eb6dcd7c5451623b859e7227475b44 2019-11-13 16:36:03 +0100 Even Rouault $")
+CPL_CVSID("$Id: gdalhashsetbandblockcache.cpp 2cef454ab06723a32379690b46581a40eb2e5af2 2019-11-13 16:36:03 +0100 Even Rouault $")
 
 //! @cond Doxygen_Suppress
 
@@ -112,7 +112,7 @@ GDALHashSetBandBlockCache::GDALHashSetBandBlockCache(
 
 GDALHashSetBandBlockCache::~GDALHashSetBandBlockCache()
 {
-    FlushCache();
+    GDALHashSetBandBlockCache::FlushCache();
     CPLDestroyLock(hLock);
 }
 
