@@ -47,7 +47,7 @@
 #include "ogr_core.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: gdalpamdataset.cpp 66ea9bfa6e0e4ba27b0ae8ce7c75f3d5ad11da63 2020-01-28 12:30:39 +0100 Even Rouault $")
+CPL_CVSID("$Id: gdalpamdataset.cpp 86d08a5e15b4cd22fb0a94482b0c8343db2d304f 2020-09-12 17:17:49 +0200 Even Rouault $")
 
 /************************************************************************/
 /*                           GDALPamDataset()                           */
@@ -294,6 +294,11 @@ CPLXMLNode *GDALPamDataset::SerializeToXML( const char *pszUnused )
         }
     }
 
+/* -------------------------------------------------------------------- */
+/*      Save MDArray statistics                                         */
+/* -------------------------------------------------------------------- */
+    SerializeMDArrayStatistics(psDSTree);
+
 /* -------------------------------------------------------------------- */
 /*      We don't want to return anything if we had no metadata to       */
 /*      attach.                                                         */
@@ -307,6 +312,44 @@ CPLXMLNode *GDALPamDataset::SerializeToXML( const char *pszUnused )
     return psDSTree;
 }
 
+/************************************************************************/
+/*                       SerializeMDArrayStatistics()                   */
+/************************************************************************/
+
+void GDALPamDataset::SerializeMDArrayStatistics(CPLXMLNode* psDSTree)
+
+{
+    if( !psPam->oMapMDArrayStatistics.empty() )
+    {
+        CPLXMLNode* psMDArrayStats = CPLCreateXMLNode(
+            psDSTree, CXT_Element, "MDArrayStatistics" );
+        for( const auto& kv: psPam->oMapMDArrayStatistics )
+        {
+            CPLXMLNode* psMDArray = CPLCreateXMLNode(
+                psMDArrayStats, CXT_Element, "MDArray" );
+            CPLAddXMLAttributeAndValue(psMDArray, "id", kv.first.c_str());
+            CPLCreateXMLElementAndValue(psMDArray,
+                                        "ApproxStats",
+                                        kv.second.bApproxStats ? "1" : "0");
+            CPLCreateXMLElementAndValue(psMDArray,
+                                        "Minimum",
+                                        CPLSPrintf("%.18g", kv.second.dfMin));
+            CPLCreateXMLElementAndValue(psMDArray,
+                                        "Maximum",
+                                        CPLSPrintf("%.18g", kv.second.dfMax));
+            CPLCreateXMLElementAndValue(psMDArray,
+                                        "Mean",
+                                        CPLSPrintf("%.18g", kv.second.dfMean));
+            CPLCreateXMLElementAndValue(psMDArray,
+                                        "StdDev",
+                                        CPLSPrintf("%.18g", kv.second.dfStdDev));
+            CPLCreateXMLElementAndValue(psMDArray,
+                                        "ValidSampleCount",
+                                        CPLSPrintf(CPL_FRMT_GUIB, kv.second.nValidCount));
+        }
+    }
+}
+
 /************************************************************************/
 /*                           PamInitialize()                            */
 /************************************************************************/
@@ -590,6 +633,41 @@ CPLErr GDALPamDataset::XMLInit( CPLXMLNode *psTree, const char *pszUnused )
         poPamBand->XMLInit( psBandTree, pszUnused );
     }
 
+/* -------------------------------------------------------------------- */
+/*      Load MDArray statistics                                         */
+/* -------------------------------------------------------------------- */
+    CPLXMLNode* psMDArrayStats = CPLGetXMLNode(psTree, "MDArrayStatistics" );
+    if( psMDArrayStats )
+    {
+        for( CPLXMLNode *psIter = psMDArrayStats->psChild;
+            psIter != nullptr;
+            psIter = psIter->psNext )
+        {
+            if( psIter->eType != CXT_Element
+                || !EQUAL(psIter->pszValue,"MDArray") )
+                continue;
+
+            const char* pszId = CPLGetXMLValue(psIter, "id", nullptr);
+            if( pszId == nullptr )
+                continue;
+
+            GDALDatasetPamInfo::Statistics sStats;
+            sStats.bApproxStats = CPLTestBool(
+                CPLGetXMLValue(psIter, "ApproxStats", "false"));
+            sStats.dfMin = CPLAtofM(
+                CPLGetXMLValue(psIter, "Minimum", "0"));
+            sStats.dfMax = CPLAtofM(
+                CPLGetXMLValue(psIter, "Maximum", "0"));
+            sStats.dfMean = CPLAtofM(
+                CPLGetXMLValue(psIter, "Mean", "0"));
+            sStats.dfStdDev = CPLAtofM(
+                CPLGetXMLValue(psIter, "StdDev", "0"));
+            sStats.nValidCount = static_cast<GUInt64>(CPLAtoGIntBig(
+                CPLGetXMLValue(psIter, "ValidSampleCount", "0")));
+            psPam->oMapMDArrayStatistics[pszId] = sStats;
+        }
+    }
+
 /* -------------------------------------------------------------------- */
 /*      Clear dirty flag.                                               */
 /* -------------------------------------------------------------------- */
@@ -761,7 +839,8 @@ CPLErr GDALPamDataset::TryLoadXML(char **papszSiblingFiles)
     int nLastErrNo = CPLGetLastErrorNo();
     CPLString osLastErrorMsg = CPLGetLastErrorMsg();
 
-    if (papszSiblingFiles != nullptr && IsPamFilenameAPotentialSiblingFile())
+    if( papszSiblingFiles != nullptr && IsPamFilenameAPotentialSiblingFile() &&
+        GDALCanReliablyUseSiblingFileList(psPam->pszPamFilename) )
     {
         const int iSibling =
             CSLFindString( papszSiblingFiles,
@@ -1117,6 +1196,7 @@ char **GDALPamDataset::GetFileList()
     char **papszFileList = GDALDataset::GetFileList();
 
     if( psPam && !psPam->osPhysicalFilename.empty()
+        && GDALCanReliablyUseSiblingFileList(psPam->osPhysicalFilename.c_str())
         && CSLFindString( papszFileList, psPam->osPhysicalFilename ) == -1 )
     {
         papszFileList = CSLInsertString( papszFileList, 0,
@@ -1129,7 +1209,9 @@ char **GDALPamDataset::GetFileList()
         if (!bAddPamFile)
         {
             VSIStatBufL sStatBuf;
-            if (oOvManager.GetSiblingFiles() != nullptr && IsPamFilenameAPotentialSiblingFile())
+            if (oOvManager.GetSiblingFiles() != nullptr &&
+                IsPamFilenameAPotentialSiblingFile() &&
+                GDALCanReliablyUseSiblingFileList(psPam->pszPamFilename) )
             {
                 bAddPamFile = CSLFindString(oOvManager.GetSiblingFiles(),
                                   CPLGetFilename(psPam->pszPamFilename)) >= 0;
@@ -1147,6 +1229,7 @@ char **GDALPamDataset::GetFileList()
     }
 
     if( psPam && !psPam->osAuxFilename.empty() &&
+        GDALCanReliablyUseSiblingFileList(psPam->osAuxFilename.c_str()) &&
         CSLFindString( papszFileList, psPam->osAuxFilename ) == -1 )
     {
         papszFileList = CSLAddString( papszFileList, psPam->osAuxFilename );
@@ -1478,7 +1561,7 @@ CPLErr GDALPamDataset::TryLoadAux(char **papszSiblingFiles)
     if( strlen(pszPhysicalFile) == 0 )
         return CE_None;
 
-    if( papszSiblingFiles )
+    if( papszSiblingFiles && GDALCanReliablyUseSiblingFileList(pszPhysicalFile) )
     {
         CPLString osAuxFilename = CPLResetExtension( pszPhysicalFile, "aux");
         int iSibling = CSLFindString( papszSiblingFiles,
@@ -1683,3 +1766,106 @@ CPLErr GDALPamDataset::_SetGCPs( int nGCPCount,
     }
 }
 //! @endcond
+
+/************************************************************************/
+/*                          ClearStatistics()                           */
+/************************************************************************/
+
+void GDALPamDataset::ClearStatistics()
+{
+    PamInitialize();
+    if( !psPam )
+        return;
+    for( int i = 1; i <= nBands; ++i )
+    {
+        bool bChanged = false;
+        GDALRasterBand* poBand = GetRasterBand(i);
+        char** papszOldMD = poBand->GetMetadata();
+        char** papszNewMD = nullptr;
+        for( char** papszIter = papszOldMD; papszIter && papszIter[0]; ++papszIter )
+        {
+            if( STARTS_WITH_CI(*papszIter, "STATISTICS_") )
+            {
+                MarkPamDirty();
+                bChanged = true;
+            }
+            else
+            {
+                papszNewMD = CSLAddString(papszNewMD, *papszIter);
+            }
+        }
+        if( bChanged )
+        {
+            poBand->SetMetadata(papszNewMD);
+        }
+        CSLDestroy(papszNewMD);
+    }
+
+    if( !psPam->oMapMDArrayStatistics.empty() )
+    {
+        MarkPamDirty();
+        psPam->oMapMDArrayStatistics.clear();
+    }
+}
+
+/************************************************************************/
+/*                       GetMDArrayStatistics()                         */
+/************************************************************************/
+
+//! @cond Doxygen_Suppress
+bool GDALPamDataset::GetMDArrayStatistics( const char* pszMDArrayId,
+                                           bool *pbApprox,
+                                           double *pdfMin, double *pdfMax,
+                                           double *pdfMean, double *pdfStdDev,
+                                           GUInt64 *pnValidCount )
+{
+    PamInitialize();
+    if( !psPam )
+    {
+        return false;
+    }
+    auto oIter = psPam->oMapMDArrayStatistics.find(pszMDArrayId);
+    if( oIter == psPam->oMapMDArrayStatistics.end() )
+    {
+        return false;
+    }
+    if( pbApprox )
+        *pbApprox = oIter->second.bApproxStats;
+    if( pdfMin )
+        *pdfMin = oIter->second.dfMin;
+    if( pdfMax )
+        *pdfMax = oIter->second.dfMax;
+    if( pdfMean )
+        *pdfMean = oIter->second.dfMean;
+    if( pdfStdDev )
+        *pdfStdDev = oIter->second.dfStdDev;
+    if( pnValidCount )
+        *pnValidCount = oIter->second.nValidCount;
+    return true;
+}
+
+/************************************************************************/
+/*                      StoreMDArrayStatistics()                        */
+/************************************************************************/
+
+//! @cond Doxygen_Suppress
+void GDALPamDataset::StoreMDArrayStatistics( const char* pszMDArrayId,
+                                 bool bApproxStats,
+                                 double dfMin, double dfMax,
+                                 double dfMean, double dfStdDev,
+                                 GUInt64 nValidCount )
+{
+    PamInitialize();
+    if( !psPam )
+        return;
+    MarkPamDirty();
+    GDALDatasetPamInfo::Statistics sStats;
+    sStats.bApproxStats = bApproxStats;
+    sStats.dfMin = dfMin;
+    sStats.dfMax = dfMax;
+    sStats.dfMean = dfMean;
+    sStats.dfStdDev = dfStdDev;
+    sStats.nValidCount = nValidCount;
+    psPam->oMapMDArrayStatistics[pszMDArrayId] = sStats;
+}
+//! @endcond
