@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: reader_alos.h 2c3d60220a2d6b41496ded571e231b96435bffa0 2016-11-25 14:09:24Z Even Rouault $
+ * $Id: reader_alos.h e37e476c4cf8f4b0df8995e0d95d5d672fca1a9b 2018-05-05 16:54:18 +0200 Even Rouault $
  *
  * Project:  GDAL Core
  * Purpose:  Read metadata from Alos imagery.
@@ -60,9 +60,9 @@ protected:
     char** LoadRPCTxtFile();
     virtual time_t GetAcquisitionTimeFromString(const char* pszDateTime) override;
 protected:
-    CPLString m_osIMDSourceFilename;
-    CPLString m_osHDRSourceFilename;
-    CPLString m_osRPBSourceFilename;
+    CPLString m_osIMDSourceFilename{};
+    CPLString m_osHDRSourceFilename{};
+    CPLString m_osRPBSourceFilename{};
 };
 
 #endif // READER_ALOS_H_INCLUDED
