@@ -28,7 +28,7 @@
 
 #include "cpl_port.h"
 
-CPL_CVSID("$Id: rasterio_ssse3.cpp ec7b85e6bb8f9737693a31f0bf7166e31e10992e 2018-04-16 00:08:36 +0200 Even Rouault $")
+CPL_CVSID("$Id: rasterio_ssse3.cpp 003ad4e9e410423af8b35843956f781e44a8daac 2019-02-18 15:48:35 +0100 Even Rouault $")
 
 #if defined(HAVE_SSSE3_AT_COMPILE_TIME) && ( defined(__x86_64) || defined(_M_X64) )
 
@@ -37,21 +37,21 @@ CPL_CVSID("$Id: rasterio_ssse3.cpp ec7b85e6bb8f9737693a31f0bf7166e31e10992e 2018
 
 void GDALUnrolledCopy_GByte_2_1_SSSE3( GByte* CPL_RESTRICT pDest,
                                              const GByte* CPL_RESTRICT pSrc,
-                                             int nIters );
+                                             GInt64 nIters );
 
 void GDALUnrolledCopy_GByte_3_1_SSSE3( GByte* CPL_RESTRICT pDest,
                                              const GByte* CPL_RESTRICT pSrc,
-                                             int nIters );
+                                             GInt64 nIters );
 
 void GDALUnrolledCopy_GByte_4_1_SSSE3( GByte* CPL_RESTRICT pDest,
                                              const GByte* CPL_RESTRICT pSrc,
-                                             int nIters );
+                                             GInt64 nIters );
 
 void GDALUnrolledCopy_GByte_2_1_SSSE3( GByte* CPL_RESTRICT pDest,
                                              const GByte* CPL_RESTRICT pSrc,
-                                             int nIters )
+                                             GInt64 nIters )
 {
-    int i;
+    decltype(nIters) i;
     const __m128i xmm_shuffle0 = _mm_set_epi8(-1  ,-1  ,-1  ,-1,
                                               -1  ,-1  ,-1  ,-1,
                                               14  ,12  ,10  ,8,
@@ -87,9 +87,9 @@ void GDALUnrolledCopy_GByte_2_1_SSSE3( GByte* CPL_RESTRICT pDest,
 
 void GDALUnrolledCopy_GByte_3_1_SSSE3( GByte* CPL_RESTRICT pDest,
                                              const GByte* CPL_RESTRICT pSrc,
-                                             int nIters )
+                                             GInt64 nIters )
 {
-    int i;
+    decltype(nIters) i;
     const __m128i xmm_shuffle0 = _mm_set_epi8(-1  ,-1  ,-1  ,-1,
                                               -1  ,-1  ,-1  ,-1,
                                               -1  ,-1  ,15  ,12,
@@ -133,9 +133,9 @@ void GDALUnrolledCopy_GByte_3_1_SSSE3( GByte* CPL_RESTRICT pDest,
 
 void GDALUnrolledCopy_GByte_4_1_SSSE3( GByte* CPL_RESTRICT pDest,
                                              const GByte* CPL_RESTRICT pSrc,
-                                             int nIters )
+                                             GInt64 nIters )
 {
-    int i;
+    decltype(nIters) i;
     const __m128i xmm_shuffle0 = _mm_set_epi8(-1  ,-1  ,-1  ,-1,
                                               -1  ,-1  ,-1  ,-1,
                                               -1  ,-1  ,-1  ,-1,
