@@ -52,7 +52,7 @@
 #include "gdal.h"
 #include "gdal_priv.h"
 
-CPL_CVSID("$Id: rawdataset.cpp 836e617286bda23e1c1736ca1ef20cc89abdddff 2019-11-11 16:53:14 +0100 Even Rouault $")
+CPL_CVSID("$Id: rawdataset.cpp 0ce239f27fb438e8f3300e97e004c5a698f58ce6 2020-12-28 23:38:31 +0100 Even Rouault $")
 
 /************************************************************************/
 /*                           RawRasterBand()                            */
@@ -1389,10 +1389,21 @@ bool RAWDatasetCheckMemoryUsage(int nXSize, int nYSize, int nBands,
     // Currently each RawRasterBand need to allocate nLineSize
     GIntBig nLineSize =
         static_cast<GIntBig>(std::abs(nPixelOffset)) * (nXSize - 1) + nDTSize;
-    constexpr int knMAX_BUFFER_MEM = INT_MAX / 4;
-    if( nBands > 0 && nLineSize > knMAX_BUFFER_MEM / nBands )
+#if SIZEOF_VOIDP == 8
+    const char* pszDefault = "1024";
+#else
+    const char* pszDefault = "512";
+#endif
+    constexpr int MB_IN_BYTES = 1024 * 1024;
+    const GIntBig nMAX_BUFFER_MEM =
+        static_cast<GIntBig>(atoi(CPLGetConfigOption("RAW_MEM_ALLOC_LIMIT_MB", pszDefault))) * MB_IN_BYTES;
+    if( nBands > 0 && nLineSize > nMAX_BUFFER_MEM / nBands )
     {
-        CPLError(CE_Failure, CPLE_OutOfMemory, "Too much memory needed");
+        CPLError(CE_Failure, CPLE_OutOfMemory,
+                 CPL_FRMT_GIB " MB of RAM would be needed to open the dataset. If you are "
+                 "comfortable with this, you can set the RAW_MEM_ALLOC_LIMIT_MB "
+                 "configuration option to that value or above",
+                 (static_cast<GIntBig>(nLineSize) * nBands + MB_IN_BYTES - 1) / MB_IN_BYTES);
         return false;
     }
 
