@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gnm.h 8c1b90d2923ad24707b0fb51accc3074272924f2 2019-03-23 21:38:44 +0100 Even Rouault $
+ * $Id: gnm.h 2854064296f013181ac011aa4f8473566a46fd4a 2019-08-15 15:36:49 +0200 Even Rouault $
  *
  * Project:  GDAL/OGR Geography Network support (Geographic Network Model)
  * Purpose:  GNM general public declarations.
@@ -78,7 +78,9 @@ public:
     virtual ~GNMNetwork();
 
     // GDALDataset Interface
-    virtual const char *GetProjectionRef(void) override;
+    const OGRSpatialReference* GetSpatialRef() const override {
+        return GetSpatialRefFromOldGetProjectionRef();
+    }
     virtual char      **GetFileList(void) override;
 
     // GNMNetwork Interface
@@ -169,6 +171,10 @@ protected:
     virtual int CheckNetworkExist( const char* pszFilename,
                                    char** papszOptions ) = 0;
 
+//! @cond Doxygen_Suppress
+    const char *_GetProjectionRef(void) override;
+//! @endcond
+
 protected:
 //! @cond Doxygen_Suppress
     CPLString m_soName;
@@ -633,6 +639,10 @@ typedef enum
 
 class CPL_DLL GNMRule
 {
+    // to hopefully please Coverity Scan which complains about missing
+    // move assignment operator for performance reasons
+    GNMRule& operator==(GNMRule&&) = delete;
+
 public:
     /** Constructor */
     GNMRule();
