@@ -30,18 +30,15 @@
 
 #include "gnm_frmts.h"
 
-CPL_CVSID("$Id: gnmregisterall.cpp ff8146d84de7cba8e09d212d5481ea7d2ede3e98 2017-06-27 20:47:31Z Even Rouault $")
+CPL_CVSID("$Id: gnmregisterall.cpp 98a60d744b13223d27fa49e36781d99c949a3cdd 2019-01-21 15:18:45Z Robert Coup $")
 
 void GNMRegisterAllInternal()
 {
-    CPLDebug("GNM", "GNMRegisterAllInternal");
 #ifdef GNMFILE_ENABLED
-    CPLDebug("GNM", "RegisterGNMFile");
     RegisterGNMFile();
 #endif
 
 #ifdef GNMDB_ENABLED
-    CPLDebug("GNM", "RegisterGNMdatabase");
     RegisterGNMDatabase();
 #endif
 
