@@ -56,7 +56,7 @@
 
 #include "proj.h"
 
-CPL_CVSID("$Id: ogr_fromepsg.cpp b1c9c12ad373e40b955162b45d704070d4ebf7b0 2019-06-19 16:50:15 +0200 Even Rouault $")
+CPL_CVSID("$Id: ogr_fromepsg.cpp bf6918d5188541fc61110004bbb0a0ac8d1443a1 2020-10-26 17:26:58 +0100 Even Rouault $")
 
 extern void OGRsnPrintDouble( char * pszStrBuf, size_t size, double dfValue );
 
@@ -286,87 +286,6 @@ OGRErr OSRSetStatePlaneWithUnits( OGRSpatialReferenceH hSRS,
                        dfOverrideUnit );
 }
 
-/************************************************************************/
-/*                           GetEPSGGeogCS()                            */
-/************************************************************************/
-
-/** Try to establish what the EPSG code for this coordinate systems
- * GEOGCS might be.  Returns -1 if no reasonable guess can be made.
- *
- * @return EPSG code
- */
-
-// TODO: We really need to do some name lookups.
-
-int OGRSpatialReference::GetEPSGGeogCS() const
-
-{
-    const char *pszAuthName = GetAuthorityName( "GEOGCS" );
-
-/* -------------------------------------------------------------------- */
-/*      Do we already have it?                                          */
-/* -------------------------------------------------------------------- */
-    if( pszAuthName != nullptr && EQUAL(pszAuthName, "epsg") )
-        return atoi(GetAuthorityCode( "GEOGCS" ));
-
-/* -------------------------------------------------------------------- */
-/*      Get the datum and geogcs names.                                 */
-/* -------------------------------------------------------------------- */
-    const char *pszGEOGCS = GetAttrValue( "GEOGCS" );
-    const char *pszDatum = GetAttrValue( "DATUM" );
-
-    // We can only operate on coordinate systems with a geogcs.
-    if( pszGEOGCS == nullptr || pszDatum == nullptr )
-        return -1;
-
-/* -------------------------------------------------------------------- */
-/*      Is this a "well known" geographic coordinate system?            */
-/* -------------------------------------------------------------------- */
-    const bool bWGS = strstr(pszGEOGCS, "WGS") != nullptr
-        || strstr(pszDatum, "WGS")
-        || strstr(pszGEOGCS, "World Geodetic System")
-        || strstr(pszGEOGCS, "World_Geodetic_System")
-        || strstr(pszDatum, "World Geodetic System")
-        || strstr(pszDatum, "World_Geodetic_System");
-
-    const bool bNAD = strstr(pszGEOGCS, "NAD") != nullptr
-        || strstr(pszDatum, "NAD")
-        || strstr(pszGEOGCS, "North American")
-        || strstr(pszGEOGCS, "North_American")
-        || strstr(pszDatum, "North American")
-        || strstr(pszDatum, "North_American");
-
-    if( bWGS && (strstr(pszGEOGCS, "84") || strstr(pszDatum, "84")) )
-        return 4326;
-
-    if( bWGS && (strstr(pszGEOGCS, "72") || strstr(pszDatum, "72")) )
-        return 4322;
-
-    if( bNAD && (strstr(pszGEOGCS, "83") || strstr(pszDatum, "83")) )
-        return 4269;
-
-    if( bNAD && (strstr(pszGEOGCS, "27") || strstr(pszDatum, "27")) )
-        return 4267;
-
-/* -------------------------------------------------------------------- */
-/*      If we know the datum, associate the most likely GCS with        */
-/*      it.                                                             */
-/* -------------------------------------------------------------------- */
-    pszAuthName = GetAuthorityName( "GEOGCS|DATUM" );
-
-    if( pszAuthName != nullptr
-        && EQUAL(pszAuthName, "epsg")
-        && GetPrimeMeridian() == 0.0 )
-    {
-        const int nDatum = atoi(GetAuthorityCode("GEOGCS|DATUM"));
-
-        if( nDatum >= 6000 && nDatum <= 6999 )
-            return nDatum - 2000;
-    }
-
-    return -1;
-}
-
 /************************************************************************/
 /*                          AutoIdentifyEPSG()                          */
 /************************************************************************/
