@@ -39,7 +39,7 @@
 #include "ogr_core.h"
 #include "ogr_srs_api.h"
 
-CPL_CVSID("$Id: ogr_srs_dict.cpp 4942e6b19a5f82ab343ec686154644effd0fcbde 2018-04-18 21:13:03 +0200 Even Rouault $")
+CPL_CVSID("$Id: ogr_srs_dict.cpp 8e5eeb35bf76390e3134a4ea7076dab7d478ea0e 2018-11-14 22:55:13 +0100 Even Rouault $")
 
 /************************************************************************/
 /*                           importFromDict()                           */
@@ -70,6 +70,27 @@ CPL_CVSID("$Id: ogr_srs_dict.cpp 4942e6b19a5f82ab343ec686154644effd0fcbde 2018-0
 OGRErr OGRSpatialReference::importFromDict( const char *pszDictFile,
                                             const char *pszCode )
 
+{
+    CPLString osWKT(lookupInDict(pszDictFile, pszCode));
+    if( osWKT.empty() )
+        return OGRERR_UNSUPPORTED_SRS;
+
+    OGRErr eErr = importFromWkt( osWKT );
+    if( eErr == OGRERR_NONE && strstr(pszDictFile, "esri_") == nullptr )
+    {
+        morphFromESRI();
+    }
+
+    return eErr;
+}
+
+/************************************************************************/
+/*                          lookupInDict()                              */
+/************************************************************************/
+
+CPLString OGRSpatialReference::lookupInDict( const char *pszDictFile,
+                                             const char *pszCode )
+
 {
 /* -------------------------------------------------------------------- */
 /*      Find and open file.                                             */
@@ -77,16 +98,16 @@ OGRErr OGRSpatialReference::importFromDict( const char *pszDictFile,
     CPLString osDictFile(pszDictFile);
     const char *pszFilename = CPLFindFile( "gdal", pszDictFile );
     if( pszFilename == nullptr )
-        return OGRERR_UNSUPPORTED_SRS;
+        return CPLString();
 
     VSILFILE *fp = VSIFOpenL( pszFilename, "rb" );
     if( fp == nullptr )
-        return OGRERR_UNSUPPORTED_SRS;
+        return CPLString();
 
 /* -------------------------------------------------------------------- */
 /*      Process lines.                                                  */
 /* -------------------------------------------------------------------- */
-    OGRErr eErr = OGRERR_UNSUPPORTED_SRS;
+    CPLString osWKT;
     const char *pszLine = nullptr;
 
     while( (pszLine = CPLReadLineL(fp)) != nullptr )
@@ -97,8 +118,8 @@ OGRErr OGRSpatialReference::importFromDict( const char *pszDictFile,
 
         if( STARTS_WITH_CI(pszLine, "include ") )
         {
-            eErr = importFromDict( pszLine + 8, pszCode );
-            if( eErr != OGRERR_UNSUPPORTED_SRS )
+            osWKT = lookupInDict( pszLine + 8, pszCode );
+            if( !osWKT.empty() )
                 break;
             continue;
         }
@@ -109,13 +130,7 @@ OGRErr OGRSpatialReference::importFromDict( const char *pszDictFile,
         if( EQUALN(pszLine, pszCode, strlen(pszCode))
             && pszLine[strlen(pszCode)] == ',' )
         {
-            const char *pszWKT = pszLine + strlen(pszCode)+1;
-
-            eErr = importFromWkt( pszWKT );
-            if( eErr == OGRERR_NONE && osDictFile.find("esri_") == 0 )
-            {
-                morphFromESRI();
-            }
+            osWKT = pszLine + strlen(pszCode)+1;
             break;
         }
     }
@@ -125,7 +140,7 @@ OGRErr OGRSpatialReference::importFromDict( const char *pszDictFile,
 /* -------------------------------------------------------------------- */
     VSIFCloseL( fp );
 
-    return eErr;
+    return osWKT;
 }
 
 /************************************************************************/
