@@ -7,7 +7,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2005, Andrey Kiselev <dron@ak4719.spb.edu>
- * Copyright (c) 2008-2012, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2012, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -33,7 +33,9 @@
 #include "cpl_csv.h"
 #include "ogr_p.h"
 
-CPL_CVSID("$Id: ogr_srs_panorama.cpp ba2ef4045f82fd2260f1732e9e46a927277ac93d 2018-05-06 19:07:03 +0200 Even Rouault $")
+#include <cmath>
+
+CPL_CVSID("$Id: ogr_srs_panorama.cpp 03ef20ef2cf10814a86d8601e9031c9d63462dd5 2020-02-09 18:10:31 +0300 drons $")
 
 constexpr double TO_DEGREES = 57.2957795130823208766;
 constexpr double TO_RADIANS = 0.017453292519943295769;
@@ -94,6 +96,8 @@ constexpr long PAN_ELLIPSOID_KRASSOVSKY  = 1L;  // Krassovsky, 1940
 // constexpr long PAN_ELLIPSOID_BESSEL1841  = 7L;  // Bessel, 1841
 // constexpr long PAN_ELLIPSOID_AIRY1830    = 8L;  // Airy, 1830
 constexpr long PAN_ELLIPSOID_WGS84       = 9L;  // WGS, 1984 (GPS)
+constexpr long PAN_ELLIPSOID_GSK2011     = 46L;   // GSK-2011
+constexpr long PAN_ELLIPSOID_PZ90        = 47L;   // PZ90
 
 /************************************************************************/
 /*  Correspondence between "Panorama" and EPSG datum codes.             */
@@ -146,6 +150,44 @@ constexpr int aoEllips[] =
 
 constexpr int NUMBER_OF_ELLIPSOIDS = static_cast<int>(CPL_ARRAYSIZE(aoEllips));
 
+/************************************************************************/
+/*  Correspondence between "Panorama" and EPSG vertical CS.             */
+/************************************************************************/
+
+constexpr int aoVCS[] =
+{
+    0,
+    8357,   //1
+    5711,   //2
+    0,      //3
+    5710,   //4
+    5710,   //5
+    0,      //6
+    0,      //7
+    0,      //8
+    0,      //9
+    5716,   //10
+    5733,   //11
+    0,      //12
+    0,      //13
+    0,      //14
+    0,      //15
+    5709,   //16
+    5776,   //17
+    0,      //18
+    0,      //19
+    5717,   //20
+    5613,   //21
+    0,      //22
+    5775,   //23
+    5702,   //24
+    5705,   //25
+    0,      //26
+    5714    //27
+};
+
+constexpr int NUMBER_OF_VERTICALCS = (sizeof(aoVCS)/sizeof(aoVCS[0]));
+
 /************************************************************************/
 /*                        OSRImportFromPanorama()                       */
 /************************************************************************/
@@ -183,7 +225,7 @@ OGRErr OSRImportFromPanorama( OGRSpatialReferenceH hSRS,
  * @param iProjSys Input projection system code, used in GIS "Panorama".
  *
  *      <h4>Supported Projections</h4>
- * <pre>
+ * \code{.unparsed}
  *      1:  Gauss-Kruger (Transverse Mercator)
  *      2:  Lambert Conformal Conic 2SP
  *      5:  Stereographic
@@ -200,22 +242,22 @@ OGRErr OSRImportFromPanorama( OGRSpatialReferenceH hSRS,
  *      27: Equirectangular
  *      28: Cylindrical Equal Area (Lambert)
  *      29: International Map of the World Polyconic
- * </pre>
+ * \endcode
  *
  * @param iDatum Input coordinate system.
  *
  *      <h4>Supported Datums</h4>
- * <pre>
+ * \code{.unparsed}
  *       1: Pulkovo, 1942
  *       2: WGS, 1984
  *       3: OSGB 1936 (British National Grid)
  *       9: Pulkovo, 1995
- * </pre>
+ * \endcode
  *
  * @param iEllips Input spheroid.
  *
  *      <h4>Supported Spheroids</h4>
- * <pre>
+ * \code{.unparsed}
  *       1: Krassovsky, 1940
  *       2: WGS, 1972
  *       3: International, 1924 (Hayford, 1909)
@@ -225,11 +267,11 @@ OGRErr OSRImportFromPanorama( OGRSpatialReferenceH hSRS,
  *       7: Bessel, 1841
  *       8: Airy, 1830
  *       9: WGS, 1984 (GPS)
- * </pre>
+ * \endcode
  *
  * @param padfPrjParams Array of 8 coordinate system parameters:
  *
- * <pre>
+ * \code{.unparsed}
  *      [0]  Latitude of the first standard parallel (radians)
  *      [1]  Latitude of the second standard parallel (radians)
  *      [2]  Latitude of center of projection (radians)
@@ -238,7 +280,7 @@ OGRErr OSRImportFromPanorama( OGRSpatialReferenceH hSRS,
  *      [5]  False Easting
  *      [6]  False Northing
  *      [7]  Zone number
- * </pre>
+ * \endcode
  *
  * Particular projection uses different parameters, unused ones may be set to
  * zero. If NULL supplied instead of array pointer default values will be used
@@ -434,6 +476,18 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
             oGCS.importFromEPSG( aoDatums[iDatum] );
             CopyGeogCSFrom( &oGCS );
         }
+        else if( iEllips == PAN_ELLIPSOID_GSK2011 )
+        {
+            OGRSpatialReference oGCS;
+            oGCS.importFromEPSG( 7683 );
+            CopyGeogCSFrom( &oGCS );
+        }
+        else if( iEllips == PAN_ELLIPSOID_PZ90 )
+        {
+            SetGeogCS( "PZ-90.11", "Parametry_Zemli_1990_11",
+                       "PZ-90", 6378136, 298.257839303);
+            SetAuthority( "SPHEROID", "EPSG", 7054 );
+        }
         else if( iEllips > 0
                  && iEllips < NUMBER_OF_ELLIPSOIDS
                  && aoEllips[iEllips] )
@@ -459,9 +513,8 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
             else
             {
                 CPLError( CE_Warning, CPLE_AppDefined,
-                          "Failed to lookup ellipsoid code %ld, likely due to "
-                          "missing GDAL gcs.csv "
-                          "file.  Falling back to use Pulkovo 42.", iEllips );
+                          "Failed to lookup ellipsoid code %ld. "
+                          "Falling back to use Pulkovo 42.", iEllips );
                 SetWellKnownGeogCS( "EPSG:4284" );
             }
 
@@ -483,14 +536,82 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
     if( IsLocal() || IsProjected() )
         SetLinearUnits( SRS_UL_METER, 1.0 );
 
-    FixupOrdering();
-
     if( bProjAllocated && padfPrjParams )
         CPLFree( padfPrjParams );
 
     return OGRERR_NONE;
 }
 
+/**
+ * Import vertical coordinate system from "Panorama" GIS projection definition.
+ *
+ * @param iVCS Input vertical coordinate system ID.
+ *
+ * <h4>Supported VCS</h4>
+ * \code{.unparsed}
+ *   1: Baltic 1977 height (EPSG:5705)
+ *   2: AHD height (EPSG:5711)
+ *   4: Ostend height (EPSG:5710)
+ *   5: Ostend height (EPSG:5710)
+ *  10: Piraeus height (EPSG:5716)
+ *  11: DNN height (EPSG:5733)
+ *  16: NAP height (EPSG:5709)
+ *  17: NN54 height (EPSG:5776)
+ *  20: N60 height (EPSG:5717)
+ *  21: RH2000 height (EPSG:5613)
+ *  23: Antalya height (EPSG:5775)
+ *  24: NGVD29 height (ftUS) (EPSG:5702)
+ *  25: Baltic 1977 height (EPSG:5705)
+ *  27: MSL height (EPSG:5714)
+ * \endcode   
+ */
+OGRErr OGRSpatialReference::importVertCSFromPanorama(int iVCS)
+{
+    if(iVCS < 0 || iVCS >= NUMBER_OF_VERTICALCS)
+    {
+        return OGRERR_CORRUPT_DATA;
+    }
+
+    const int nEPSG = aoVCS[iVCS];
+
+    if(nEPSG == 0 )
+    {
+        CPLError(CE_Warning, CPLE_NotSupported, 
+                 "Vertical coordinate system (Panorama index %d) not supported", iVCS);
+        return OGRERR_UNSUPPORTED_SRS;
+    }
+
+    OGRSpatialReference sr;
+    sr.SetAxisMappingStrategy(OAMS_TRADITIONAL_GIS_ORDER);
+    OGRErr eImportFromEPSGErr = sr.importFromEPSG(nEPSG);
+    if(eImportFromEPSGErr != OGRERR_NONE)
+    {
+        CPLError(CE_Warning, CPLE_None, 
+                 "Vertical coordinate system (Panorama index %d, EPSG %d) "
+                 "import from EPSG error", iVCS, nEPSG);
+        return OGRERR_UNSUPPORTED_SRS;
+    }
+
+    if(sr.IsVertical() != 1)
+    {
+        CPLError(CE_Warning, CPLE_None, 
+                 "Coordinate system (Panorama index %d, EPSG %d) "
+                 "is not Vertical", iVCS, nEPSG);
+        return OGRERR_UNSUPPORTED_SRS;
+    }
+
+    OGRErr eSetVertCSErr = SetVertCS(sr.GetAttrValue("VERT_CS"), 
+                                     sr.GetAttrValue("VERT_DATUM"));
+    if(eSetVertCSErr != OGRERR_NONE)
+    {
+        CPLError(CE_Warning, CPLE_None, 
+                "Vertical coordinate system (Panorama index %d, EPSG %d) "
+                "set error", iVCS, nEPSG);
+        return eSetVertCSErr;
+    }
+    return OGRERR_NONE;
+}
+
 /************************************************************************/
 /*                      OSRExportToPanorama()                           */
 /************************************************************************/
@@ -805,8 +926,8 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
 
                 if( OSRGetEllipsoidInfo( aoEllips[i], nullptr,
                                          &dfSM, &dfIF ) == OGRERR_NONE
-                    && CPLIsEqual(dfSemiMajor, dfSM)
-                    && CPLIsEqual(dfInvFlattening, dfIF) )
+                    && std::abs(dfSemiMajor - dfSM) < 1e-10 * dfSemiMajor
+                    && std::abs(dfInvFlattening - dfIF) < 1e-10 * dfInvFlattening )
                 {
                     *piEllips = i;
                     break;
