@@ -40,7 +40,7 @@
 #include "ogr_geometry.h"
 #include "ogr_p.h"
 
-CPL_CVSID("$Id: ogrcircularstring.cpp ba2ef4045f82fd2260f1732e9e46a927277ac93d 2018-05-06 19:07:03 +0200 Even Rouault $")
+CPL_CVSID("$Id: ogrcircularstring.cpp c7d51c5ead794772b42f3c58c394bfff6045f8d6 2019-08-22 09:59:35 +0200 Even Rouault $")
 
 static inline double dist(double x0, double y0, double x1, double y1)
 {
@@ -203,17 +203,19 @@ OGRErr OGRCircularString::importFromWkt( const char ** ppszInput )
 /*                            exportToWkt()                             */
 /************************************************************************/
 
-OGRErr
-OGRCircularString::exportToWkt( char ** ppszDstText,
-                                CPL_UNUSED OGRwkbVariant eWkbVariant ) const
-
+std::string OGRCircularString::exportToWkt(const OGRWktOptions& opts,
+                                           OGRErr *err) const
 {
     if( !IsValidFast() )
     {
-        return OGRERR_FAILURE;
+        if (err)
+            *err = OGRERR_FAILURE;
+        return std::string();
     }
 
-    return OGRSimpleCurve::exportToWkt(ppszDstText, wkbVariantIso);
+    OGRWktOptions optsModified(opts);
+    optsModified.variant = wkbVariantIso;
+    return OGRSimpleCurve::exportToWkt(optsModified, err);
 }
 
 /************************************************************************/
