@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_aeronavfaa.h 842d122d2f23aaebb28362e083b52d6bc7dbcde2 2019-08-11 17:42:34 +0200 Even Rouault $
+ * $Id: ogr_aeronavfaa.h bc3d9f5351962c422f3e57a9ab1a251d91659192 2020-05-09 21:07:14 +0200 Even Rouault $
  *
  * Project:  AeronavFAA Translator
  * Purpose:  Definition of classes for OGR AeronavFAA driver.
@@ -52,7 +52,7 @@ typedef struct
 /*                         OGRAeronavFAALayer                           */
 /************************************************************************/
 
-class OGRAeronavFAALayer CPL_NON_FINAL: public OGRLayer
+class OGRAeronavFAALayer CPL_NON_FINAL: public OGRLayer, public OGRGetNextFeatureThroughRaw<OGRAeronavFAALayer>
 {
 protected:
     OGRFeatureDefn*    poFeatureDefn;
@@ -72,7 +72,7 @@ protected:
                         virtual ~OGRAeronavFAALayer();
 
     virtual void                ResetReading() override;
-    virtual OGRFeature *        GetNextFeature() override;
+    DEFINE_GET_NEXT_FEATURE_THROUGH_RAW(OGRAeronavFAALayer)
 
     virtual OGRFeatureDefn *    GetLayerDefn() override { return poFeatureDefn; }
 
