@@ -30,7 +30,7 @@
 #include "ogr_p.h"
 #include "ogrgeojsonreader.h"
 
-CPL_CVSID("$Id: ogramigocloudlayer.cpp 8e5eeb35bf76390e3134a4ea7076dab7d478ea0e 2018-11-14 22:55:13 +0100 Even Rouault $")
+CPL_CVSID("$Id: ogramigocloudlayer.cpp 465f27bef2d7c8c84a11e17e5782498ecf5961c3 2021-02-22 12:01:13 -0500 Victor $")
 
 /************************************************************************/
 /*                         OGRAmigoCloudLayer()                            */
@@ -123,19 +123,7 @@ OGRFeature *OGRAmigoCloudLayer::BuildFeature(json_object* poRowObj)
             }
             else if( json_object_get_type(poVal) == json_type_string )
             {
-                if( poFeatureDefn->GetFieldDefn(i)->GetType() == OFTDateTime )
-                {
-                    OGRField sField;
-                    if( OGRParseXMLDateTime( json_object_get_string(poVal),
-                                             &sField) )
-                    {
-                        poFeature->SetField(i, &sField);
-                    }
-                }
-                else
-                {
-                    poFeature->SetField(i, json_object_get_string(poVal));
-                }
+                poFeature->SetField(i, json_object_get_string(poVal));
             }
             else if( json_object_get_type(poVal) == json_type_int ||
                      json_object_get_type(poVal) == json_type_boolean )
@@ -390,12 +378,13 @@ void OGRAmigoCloudLayer::EstablishLayerDefn(const char* pszLayerName,
                 }
                 else if(EQUAL(fieldType.c_str(), "date"))
                 {
-                    if(!EQUAL(fieldName.c_str(), "created_at") &&
-                       !EQUAL(fieldName.c_str(), "updated_at"))
-                    {
-                        OGRFieldDefn oFieldDefn(fieldName.c_str(), OFTDateTime);
-                        poFeatureDefn->AddFieldDefn(&oFieldDefn);
-                    }
+                    OGRFieldDefn oFieldDefn(fieldName.c_str(), OFTDate);
+                    poFeatureDefn->AddFieldDefn(&oFieldDefn);
+                }
+                else if(EQUAL(fieldType.c_str(), "datetime"))
+                {
+                    OGRFieldDefn oFieldDefn(fieldName.c_str(), OFTDateTime);
+                    poFeatureDefn->AddFieldDefn(&oFieldDefn);
                 }
                 else if(EQUAL(fieldType.c_str(), "geometry"))
                 {
