@@ -31,8 +31,9 @@
 #include "ogr_pgdump.h"
 #include "ogrgeojsonreader.h"
 #include <sstream>
+#include <iomanip>
 
-CPL_CVSID("$Id: ogramigocloudtablelayer.cpp 327bfdc0f5dd563c3b1c4cbf26d34967c5c9c790 2020-02-28 13:51:40 +0100 Even Rouault $")
+CPL_CVSID("$Id: ogramigocloudtablelayer.cpp abcd03be837d5bd1c9ada635fcda974745bf3714 2021-02-25 05:19:28 -0500 Victor Chernetsky $")
 
 /************************************************************************/
 /*                    OGRAMIGOCLOUDEscapeIdentifier( )                     */
@@ -57,42 +58,27 @@ CPLString OGRAMIGOCLOUDEscapeIdentifier(const char* pszStr)
     return osStr;
 }
 
-/************************************************************************/
-/*                    OGRAMIGOCLOUDEscapeLiteral( )                        */
-/************************************************************************/
-
-CPLString OGRAMIGOCLOUDEscapeLiteral(const char* pszStr)
-{
-    CPLString osStr;
-
-    char ch = '\0';
-    for( int i=0; (ch = pszStr[i]) != '\0'; i++ )
-    {
-        if (ch == '\'')
-            osStr.append(1, ch);
-        osStr.append(1, ch);
-    }
-
-    return osStr;
-}
-
-std::string OGRAMIGOCLOUDJsonEncode(const std::string &value) {
-    std::stringstream escaped;
-    escaped.fill('0');
-    escaped << std::hex;
-
-    for (std::string::const_iterator i = value.begin(), n = value.end(); i != n; ++i) {
-        std::string::value_type c = (*i);
-
-        if ( c == '"') {
-            escaped << "\\\"";
-            continue;
+std::string OGRAMIGOCLOUDJsonEncode(const std::string &s) {
+    std::ostringstream o;
+    for (auto c = s.cbegin(); c != s.cend(); c++) {
+        switch (*c) {
+            case '"': o << "\\\""; break;
+            case '\\': o << "\\\\"; break;
+            case '\b': o << "\\b"; break;
+            case '\f': o << "\\f"; break;
+            case '\n': o << "\\n"; break;
+            case '\r': o << "\\r"; break;
+            case '\t': o << "\\t"; break;
+            default:
+                if (*c <= '\x1f') {
+                    o << "\\u"
+                      << std::hex << std::setw(4) << std::setfill('0') << (int)*c;
+                } else {
+                    o << *c;
+                }
         }
-
-        escaped << c;
     }
-
-    return escaped.str();
+    return o.str();
 }
 
 /************************************************************************/
@@ -433,7 +419,7 @@ OGRErr OGRAmigoCloudTableLayer::ICreateFeature( OGRFeature *poFeature )
         if( poFeature->GetGeomFieldRef(i) == nullptr )
             continue;
 
-        record << "\"" << OGRAMIGOCLOUDEscapeLiteral(poFeatureDefn->GetGeomFieldDefn(i)->GetNameRef()) << "\":";
+        record << "\"" << OGRAMIGOCLOUDJsonEncode(poFeatureDefn->GetGeomFieldDefn(i)->GetNameRef()) << "\":";
 
         OGRGeometry* poGeom = poFeature->GetGeomFieldRef(i);
         if( poGeom == nullptr )
@@ -454,6 +440,7 @@ OGRErr OGRAmigoCloudTableLayer::ICreateFeature( OGRFeature *poFeature )
             delete poNewGeom;
         }
         else
+
             pszEWKB = OGRGeometryToHexEWKB(poGeom, nSRID, 2, 1);
         record << "\"" << pszEWKB << "\"";
         CPLFree(pszEWKB);
@@ -487,9 +474,9 @@ OGRErr OGRAmigoCloudTableLayer::ICreateFeature( OGRFeature *poFeature )
             OGRFieldType eType = poFeatureDefn->GetFieldDefn(i)->GetType();
             if( eType == OFTString || eType == OFTDateTime || eType == OFTDate || eType == OFTTime )
             {
-                record << "\"" << OGRAMIGOCLOUDEscapeLiteral(value.c_str()) << "\"";
+                record << "\"" << OGRAMIGOCLOUDJsonEncode(value.c_str()) << "\"";
             } else
-                record << OGRAMIGOCLOUDEscapeLiteral(value.c_str());
+                record << OGRAMIGOCLOUDJsonEncode(value.c_str());
         }
         else
             record << "null";
@@ -574,7 +561,7 @@ OGRErr OGRAmigoCloudTableLayer::ISetFeature( OGRFeature *poFeature )
                 if(eType == OFTString || eType == OFTDateTime || eType == OFTDate || eType == OFTTime)
                 {
                     osSQL += "'";
-                    osSQL += OGRAMIGOCLOUDEscapeLiteral(poFeature->GetFieldAsString(i));
+                    osSQL += OGRAMIGOCLOUDJsonEncode(poFeature->GetFieldAsString(i));
                     osSQL += "'";
                 }
                 else if((eType == OFTInteger || eType == OFTInteger64) &&
@@ -709,9 +696,9 @@ CPLString OGRAmigoCloudTableLayer::GetSRS_SQL(const char* pszGeomCol)
 
     osSQL.Printf("SELECT srid, srtext FROM spatial_ref_sys WHERE srid IN "
                 "(SELECT Find_SRID('%s', '%s', '%s'))",
-                OGRAMIGOCLOUDEscapeLiteral(poDS->GetCurrentSchema()).c_str(),
-                OGRAMIGOCLOUDEscapeLiteral(osTableName).c_str(),
-                OGRAMIGOCLOUDEscapeLiteral(pszGeomCol).c_str());
+                 OGRAMIGOCLOUDJsonEncode(poDS->GetCurrentSchema()).c_str(),
+                 OGRAMIGOCLOUDJsonEncode(osTableName).c_str(),
+                 OGRAMIGOCLOUDJsonEncode(pszGeomCol).c_str());
 
     return osSQL;
 }
