@@ -28,6 +28,9 @@
  *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  *  SOFTWARE.
  *******************************************************************************/
+
+#include "cpl_port.h"
+#include "cpl_safemaths.hpp"
 #include "cadheader.h"
 #include "opencad_api.h"
 #include "dwg/io.h"
@@ -36,7 +39,7 @@
 #include <iostream>
 #include <time.h>
 
-#if (defined(__sun__) || defined(__FreeBSD__)) && __GNUC__ == 4 && __GNUC_MINOR__ == 8
+#if ((defined(__sun__) || defined(__FreeBSD__)) && __GNUC__ == 4 && __GNUC_MINOR__ == 8) || defined(__ANDROID__)
 // gcc 4.8 on Solaris 11.3 or FreeBSD 11 doesn't have std::string
 #include <sstream>
 template <typename T> std::string to_string(T val)
@@ -59,6 +62,7 @@ typedef struct
 #define FillCADConstantDetail( x, y ) {CADHeader::x, y, "$"#x}
 
 static const CADHeaderConstantDetail CADHeaderConstantDetails[]{
+        FillCADConstantDetail( OPENCADVER, 777),
         FillCADConstantDetail( ACADMAINTVER, 70 ), FillCADConstantDetail( ACADVER, 1 ),
         FillCADConstantDetail( ANGBASE, 50 ), FillCADConstantDetail( ANGDIR, 70 ), FillCADConstantDetail( ATTMODE, 70 ),
         FillCADConstantDetail( AUNITS, 70 ), FillCADConstantDetail( AUPREC, 70 ), FillCADConstantDetail( CECOLOR, 62 ),
@@ -185,25 +189,38 @@ void CADHandle::addOffset( unsigned char val )
 
 long CADHandle::getAsLong( const CADHandle& ref_handle ) const
 {
-    switch( code )
+    // FIXME: Remove GDAL specific code. The library cannot compile as separate project.
+    try
     {
-        case 0x06:
+        switch( code )
         {
-            return getAsLong(ref_handle.handleOrOffset) + 1;
-        }
-        case 0x08:
-        {
-            return getAsLong(ref_handle.handleOrOffset) - 1;
-        }
-        case 0x0A:
-        {
-            return getAsLong(ref_handle.handleOrOffset) + getAsLong(handleOrOffset);
-        }
-        case 0x0C:
-        {
-            return getAsLong(ref_handle.handleOrOffset) - getAsLong(handleOrOffset);
+            case 0x06:
+            {
+                return static_cast<long>((CPLSM(static_cast<GInt64>(getAsLong(ref_handle.handleOrOffset))) +
+                        CPLSM(static_cast<GInt64>(1))).v());
+            }
+            case 0x08:
+            {
+                return static_cast<long>((CPLSM(static_cast<GInt64>(getAsLong(ref_handle.handleOrOffset))) -
+                        CPLSM(static_cast<GInt64>(1))).v());
+            }
+            case 0x0A:
+            {
+                return static_cast<long>((CPLSM(static_cast<GInt64>(getAsLong(ref_handle.handleOrOffset))) +
+                        CPLSM(static_cast<GInt64>(getAsLong(handleOrOffset)))).v());
+            }
+            case 0x0C:
+            {
+                return static_cast<long>((CPLSM(static_cast<GInt64>(getAsLong(ref_handle.handleOrOffset))) -
+                        CPLSM(static_cast<GInt64>(getAsLong(handleOrOffset)))).v());
+            }
         }
     }
+    catch( const CPLSafeIntOverflow& )
+    {
+        // TODO: handle this differently ?
+        return 0;
+    }
 
     return getAsLong(handleOrOffset);
 }
@@ -218,8 +235,14 @@ long CADHandle::getAsLong(const std::vector<unsigned char>& handle)
     long result = 0;
     if( handle.empty() )
         return result;
-    memcpy( &result, handle.data(), handle.size() );
-    SwapEndianness( result, handle.size() );
+    size_t copySize = handle.size();
+    if( copySize > sizeof(long) )
+        copySize = sizeof(long);
+    memcpy( &result, handle.data(), copySize );
+    // NOTE: Second argument below was previously handle.size(). This was
+    // clearly wrong (consider the case where handle.size() > sizeof(long))
+    // but I don't know what the correct value should be
+    SwapEndianness( result, copySize );
     return result;
 }
 
@@ -296,6 +319,7 @@ CADVariant::CADVariant( double x, double y, double z ) :
 {
     char str_buff[256];
     snprintf( str_buff, sizeof(str_buff), "[%.15g,%.15g,%.15g]", x, y, z );
+    str_buff[sizeof(str_buff)-1] = '\0';
     stringVal = str_buff;
 }
 
@@ -310,16 +334,23 @@ CADVariant::CADVariant( const string& val ) :
 {
 }
 
-CADVariant::CADVariant( time_t val ) :
+CADVariant::CADVariant( long julianday, long milliseconds ) :
     type        ( DataType::DATETIME ),
     decimalVal  ( 0 ),
     xVal        ( 0 ),
     yVal        ( 0 ),
-    zVal        ( 0 ),
-    dateTimeVal ( val )
+    zVal        ( 0 )
 {
-    char str_buff[256];
-    strftime(str_buff, 255, "%Y-%m-%d %H:%M:%S", localtime(&dateTimeVal));
+    double dfSeconds = double( milliseconds ) / 1000;
+    double dfUnix = 0;
+    if(julianday != 0)
+        dfUnix = ( double( julianday ) - 2440587.5 ) * 86400.0;
+    dateTimeVal = static_cast<time_t>( dfUnix + dfSeconds );
+
+    char str_buff[256] = "Invalid date";
+    struct tm *poLocaltime = localtime(&dateTimeVal);
+    if(poLocaltime)
+        strftime(str_buff, 255, "%Y-%m-%d %H:%M:%S", poLocaltime);
     stringVal = str_buff;
 }
 
@@ -335,33 +366,6 @@ CADVariant::CADVariant( const CADHandle& val ) :
 {
 }
 
-CADVariant::CADVariant( const CADVariant& orig ) :
-    type        ( orig.type ),
-    decimalVal  ( orig.decimalVal ),
-    xVal        ( orig.xVal ),
-    yVal        ( orig.yVal ),
-    zVal        ( orig.zVal ),
-    stringVal   ( orig.stringVal ),
-    handleVal   ( orig.handleVal ),
-    dateTimeVal ( orig.dateTimeVal )
-{
-}
-
-CADVariant& CADVariant::operator=( const CADVariant& orig )
-{
-    if( this == & orig )
-        return * this;
-    type        = orig.type;
-    stringVal   = orig.stringVal;
-    decimalVal  = orig.decimalVal;
-    xVal        = orig.xVal;
-    yVal        = orig.yVal;
-    zVal        = orig.zVal;
-    handleVal   = orig.handleVal;
-    dateTimeVal = orig.dateTimeVal;
-    return * this;
-}
-
 long CADVariant::getDecimal() const
 {
     return decimalVal;
@@ -464,12 +468,7 @@ int CADHeader::addValue( short code, long julianday, long milliseconds )
     // unix -> julian        return ( unixSecs / 86400.0 ) + 2440587.5;
     // julian -> unix        return (julian - 2440587.5) * 86400.0
 
-    double dfSeconds = double( milliseconds ) / 1000;
-    double dfUnix = 0;
-    if(julianday != 0)
-        dfUnix = ( double( julianday ) - 2440587.5 ) * 86400.0;
-    time_t fullSeconds = static_cast<time_t>( dfUnix + dfSeconds );
-    return addValue( code, CADVariant( fullSeconds ) );
+    return addValue( code, CADVariant( julianday, milliseconds ) );
 }
 
 int CADHeader::getGroupCode( short code )
