@@ -30,7 +30,7 @@
 #include "ogr_dods.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ogrdodsfielddefn.cpp 103562a4b99e01eef1f5cb350b2dccaa6fe01e81 2017-12-14 19:39:15Z Even Rouault $")
+CPL_CVSID("$Id: ogrdodsfielddefn.cpp 6747f53c24c9f07541386397ab8887beafc0000a 2019-03-23 14:40:45 +0100 Even Rouault $")
 
 /************************************************************************/
 /*                          OGRDODSFieldDefn()                          */
@@ -74,8 +74,9 @@ bool OGRDODSFieldDefn::Initialize( AttrTable *poEntry,
                                    BaseType *poSuperSeq )
 
 {
-    const char *l_pszFieldScope = poEntry->get_attr("scope").c_str();
-    if( l_pszFieldScope == nullptr )
+    auto osScope(poEntry->get_attr("scope"));
+    const char *l_pszFieldScope = osScope.c_str();
+    if( osScope.empty() )
         l_pszFieldScope = "dds";
 
     return Initialize( poEntry->get_attr("name").c_str(), l_pszFieldScope,
