@@ -30,7 +30,7 @@
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrdgnv8datasource.cpp 4a1f1d2ec47f0fb8ee3f6a95a715cf01f6b5482a 2018-04-18 12:16:32 +0200 Even Rouault $")
+CPL_CVSID("$Id: ogrdgnv8datasource.cpp a3bd06c8ed331ed68d3e8d374ae512c26769a56a 2019-04-20 23:52:31 +0200 Even Rouault $")
 
 /************************************************************************/
 /*                        OGRDGNV8DataSource()                          */
@@ -336,7 +336,7 @@ char **OGRDGNV8DataSource::GetMetadataDomainList()
 {
     return BuildMetadataDomainList(GDALDataset::GetMetadataDomainList(),
                                    TRUE,
-                                   "DGN", NULL);
+                                   "DGN", nullptr);
 }
 
 /************************************************************************/
