@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_dxf.h 4221746d6e88e2ec813e59d5fb9c34c77fcee655 2020-05-28 14:49:59 +0200 Even Rouault $
+ * $Id: ogr_dxf.h 23ce60aecb9a6eb91f9dda2e4075215e70e971ca 2020-07-25 21:34:53 +1000 Alan Thomas $
  *
  * Project:  DXF Translator
  * Purpose:  Definition of classes for OGR .dxf driver.
@@ -196,54 +196,48 @@ class OGRDXFAffineTransform
 {
 public:
     OGRDXFAffineTransform() :
-        adfMatrix{{1.0,0.0,0.0},{0.0,1.0,0.0},{0.0,0.0,1.0}}, adfVector{0.0} {}
+        adfData{1.0,0.0,0.0, 0.0,1.0,0.0, 0.0,0.0,1.0, 0.0,0.0,0.0} {}
 
-    double adfMatrix[3][3]; // adfMatrix[1][2] is row 2, column 3
-    double adfVector[3];
+    double adfData[12]; // Column-major: adfMatrix[5] is column 2, row 3
+                        // Last 3 elements are translation
 
     // Left composition (composes oOther o this), modifying this
     void ComposeWith( const OGRDXFInsertTransformer& oCT )
     {
-        double adfNew[3][3];
+        double adfNew[12];
 
-        adfNew[0][0] = oCT.dfXScale * cos(oCT.dfAngle) * adfMatrix[0][0] -
-            oCT.dfYScale * sin(oCT.dfAngle) * adfMatrix[1][0];
-        adfNew[0][1] = oCT.dfXScale * cos(oCT.dfAngle) * adfMatrix[0][1] -
-            oCT.dfYScale * sin(oCT.dfAngle) * adfMatrix[1][1];
-        adfNew[0][2] = 0.0;
+        adfNew[0] = oCT.dfXScale * cos(oCT.dfAngle) * adfData[0] -
+            oCT.dfYScale * sin(oCT.dfAngle) * adfData[1];
+        adfNew[1] = oCT.dfXScale * sin(oCT.dfAngle) * adfData[0] +
+            oCT.dfYScale * cos(oCT.dfAngle) * adfData[1];
+        adfNew[2] = oCT.dfZScale * adfData[2];
 
-        adfNew[1][0] = oCT.dfXScale * sin(oCT.dfAngle) * adfMatrix[0][0] +
-            oCT.dfYScale * cos(oCT.dfAngle) * adfMatrix[1][0];
-        adfNew[1][1] = oCT.dfXScale * sin(oCT.dfAngle) * adfMatrix[0][1] +
-            oCT.dfYScale * cos(oCT.dfAngle) * adfMatrix[1][1];
-        adfNew[1][2] = 0.0;
+        adfNew[3] = oCT.dfXScale * cos(oCT.dfAngle) * adfData[3] -
+            oCT.dfYScale * sin(oCT.dfAngle) * adfData[4];
+        adfNew[4] = oCT.dfXScale * sin(oCT.dfAngle) * adfData[3] +
+            oCT.dfYScale * cos(oCT.dfAngle) * adfData[4];
+        adfNew[5] = oCT.dfZScale * adfData[5];
 
-        adfNew[2][0] = 0.0;
-        adfNew[2][1] = 0.0;
-        adfNew[2][2] = oCT.dfZScale * adfMatrix[2][2];
+        adfNew[6] = oCT.dfXScale * cos(oCT.dfAngle) * adfData[6] -
+            oCT.dfYScale * sin(oCT.dfAngle) * adfData[7];
+        adfNew[7] = oCT.dfXScale * sin(oCT.dfAngle) * adfData[6] +
+            oCT.dfYScale * cos(oCT.dfAngle) * adfData[7];
+        adfNew[8] = oCT.dfZScale * adfData[8];
 
-        memcpy( adfMatrix, adfNew, sizeof(adfNew) );
+        adfNew[9] = oCT.dfXScale * cos(oCT.dfAngle) * adfData[9] -
+            oCT.dfYScale * sin(oCT.dfAngle) * adfData[10] +
+            oCT.dfXOffset;
+        adfNew[10] = oCT.dfXScale * sin(oCT.dfAngle) * adfData[9] +
+            oCT.dfYScale * cos(oCT.dfAngle) * adfData[10] +
+            oCT.dfYOffset;
+        adfNew[11] = oCT.dfZScale * adfData[11] + oCT.dfZOffset;
 
-        double adfNewVector[3];
-
-        adfNewVector[0] = oCT.dfXScale * cos(oCT.dfAngle) * adfVector[0] -
-            oCT.dfYScale * sin(oCT.dfAngle) * adfVector[1];
-        adfNewVector[1] = oCT.dfXScale * sin(oCT.dfAngle) * adfVector[0] +
-            oCT.dfYScale * cos(oCT.dfAngle) * adfVector[1];
-        adfNewVector[2] = oCT.dfZScale * adfVector[2];
-
-        adfVector[0] = adfNewVector[0] + oCT.dfXOffset;
-        adfVector[1] = adfNewVector[1] + oCT.dfYOffset;
-        adfVector[2] = adfNewVector[2] + oCT.dfZOffset;
+        memcpy( adfData, adfNew, sizeof(adfNew) );
     }
 
     void SetField(OGRFeature* poFeature, const char* pszFieldName) const
     {
-        double* padfList = new double[12];
-        memcpy( padfList, adfMatrix, sizeof(adfMatrix) );
-        memcpy( padfList + 9, adfVector, sizeof(adfVector) );
-        poFeature->SetField(pszFieldName, 12, padfList);
-        delete[] padfList;
+        poFeature->SetField(pszFieldName, 12, adfData);
     }
 };
 
