@@ -5,7 +5,7 @@
  * Author:   Björn Harrtell <bjorn at wololo dot org>
  *
  ******************************************************************************
- * Copyright (c) 2018-2019, Björn Harrtell <bjorn at wololo dot org>
+ * Copyright (c) 2018-2020, Björn Harrtell <bjorn at wololo dot org>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -31,6 +31,7 @@
 
 #include "ogrsf_frmts.h"
 #include "ogr_p.h"
+#include "ogreditablelayer.h"
 
 #include "header_generated.h"
 #include "feature_generated.h"
@@ -94,6 +95,7 @@ class OGRFlatGeobufLayer final : public OGRLayer
 
         // creation
         bool m_create = false;
+        bool m_update = false;
         std::vector<std::shared_ptr<FlatGeobuf::Item>> m_featureItems; // feature item description used to create spatial index
         bool m_bCreateSpatialIndexAtClose = true;
         bool m_bVerifyBuffers = true;
@@ -101,7 +103,7 @@ class OGRFlatGeobufLayer final : public OGRLayer
         VSILFILE *m_poFpWrite = nullptr;
         uint64_t m_writeOffset = 0; // current write offset
         uint16_t m_indexNodeSize = 0;
-        std::string m_oTempFile; // holds generated temp file name for two pass writing
+        std::string m_osTempFile; // holds generated temp file name for two pass writing
         uint32_t m_maxFeatureSize  = 0;
 
         // shared
@@ -121,12 +123,17 @@ class OGRFlatGeobufLayer final : public OGRLayer
         void Create();
         void writeHeader(VSILFILE *poFp, uint64_t featuresCount, std::vector<double> *extentVector);
 
-        OGRwkbGeometryType getOGRwkbGeometryType();
+        // construction
+        OGRFlatGeobufLayer(const FlatGeobuf::Header *, GByte *headerBuf, const char *pszFilename, VSILFILE *poFp, uint64_t offset, bool update);
+        OGRFlatGeobufLayer(const char *pszLayerName, const char *pszFilename, OGRSpatialReference *poSpatialRef, OGRwkbGeometryType eGType, bool bCreateSpatialIndexAtClose, VSILFILE *poFpWrite, std::string &osTempFile);
+
     public:
-        OGRFlatGeobufLayer(const FlatGeobuf::Header *, GByte *headerBuf, const char *pszFilename, VSILFILE *poFp, uint64_t offset);
-        OGRFlatGeobufLayer(const char *pszLayerName, const char *pszFilename, OGRSpatialReference *poSpatialRef, OGRwkbGeometryType eGType, VSILFILE *poFpWrite, const std::string& oTempFile, bool bCreateSpatialIndexAtClose);
         virtual ~OGRFlatGeobufLayer();
 
+        static OGRFlatGeobufLayer *Open(const FlatGeobuf::Header *, GByte *headerBuf, const char *pszFilename, VSILFILE *poFp, uint64_t offset, bool update);
+        static OGRFlatGeobufLayer *Open(const char* pszFilename, VSILFILE *fp, bool bVerifyBuffers, bool update);
+        static OGRFlatGeobufLayer *Create(const char *pszLayerName, const char *pszFilename, OGRSpatialReference *poSpatialRef, OGRwkbGeometryType eGType, bool bCreateSpatialIndexAtClose, char **papszOptions);
+
         virtual OGRFeature *GetFeature(GIntBig nFeatureId) override;
         virtual OGRFeature *GetNextFeature() override;
         virtual OGRErr CreateField(OGRFieldDefn *poField, int bApproxOK = true) override;
@@ -137,26 +144,45 @@ class OGRFlatGeobufLayer final : public OGRLayer
         virtual OGRFeatureDefn *GetLayerDefn() override { return m_poFeatureDefn; }
         virtual GIntBig GetFeatureCount(int bForce) override;
         virtual OGRErr GetExtent(OGREnvelope* psExtent, int bForce) override;
-        virtual OGRErr      GetExtent( int iGeomField, OGREnvelope *psExtent,
+        virtual OGRErr GetExtent( int iGeomField, OGREnvelope *psExtent,
                                        int bForce ) override
                 { return OGRLayer::GetExtent(iGeomField, psExtent, bForce); }
 
         void VerifyBuffers( int bFlag ) { m_bVerifyBuffers = CPL_TO_BOOL(bFlag); }
 
         const std::string& GetFilename() const { return m_osFilename; }
+
+        static std::string GetTempFilePath(const CPLString &fileName, CSLConstList papszOptions);
+        static VSILFILE *CreateOutputFile(const CPLString &pszFilename, CSLConstList papszOptions, bool isTemp);
+
+        uint16_t GetIndexNodeSize() const { return m_indexNodeSize; }
+        OGRwkbGeometryType getOGRwkbGeometryType();
+};
+
+class OGRFlatGeobufEditableLayer final: public OGREditableLayer
+{
+    public:
+        OGRFlatGeobufEditableLayer(OGRFlatGeobufLayer *poFlatGeobufLayer, char **papszOpenOptions);
+
+        virtual GIntBig     GetFeatureCount( int bForce = TRUE ) override;
+
+        const std::string&  GetFilename() const {
+            return static_cast<OGRFlatGeobufLayer *>(m_poDecoratedLayer)->GetFilename();
+        }
 };
 
 class OGRFlatGeobufDataset final: public GDALDataset
 {
     private:
-        std::vector<std::unique_ptr<OGRFlatGeobufLayer>> m_apoLayers;
+        std::vector<std::unique_ptr<OGRLayer>> m_apoLayers;
         bool m_bCreate = false;
+        bool m_bUpdate = false;
         bool m_bIsDir = false;
 
         bool OpenFile(const char* pszFilename, VSILFILE* fp, bool bVerifyBuffers);
 
     public:
-        explicit OGRFlatGeobufDataset(const char *pszName, bool bIsDir, bool bCreate);
+        explicit OGRFlatGeobufDataset(const char *pszName, bool bIsDir, bool bCreate, bool bUpdate);
         ~OGRFlatGeobufDataset();
 
         static GDALDataset *Open(GDALOpenInfo*);
@@ -177,6 +203,5 @@ class OGRFlatGeobufDataset final: public GDALDataset
         char** GetFileList() override;
 };
 
-
 #endif /* ndef OGR_FLATGEOBUF_H_INCLUDED */
 
