@@ -31,7 +31,7 @@
 #include "ogr_api.h"
 #include "ograpispy.h"
 
-CPL_CVSID("$Id: ogrdatasource.cpp b1c9c12ad373e40b955162b45d704070d4ebf7b0 2019-06-19 16:50:15 +0200 Even Rouault $")
+CPL_CVSID("$Id: ogrdatasource.cpp ba3554dcc5a5f63eb7bc2a92a6cbb3f995b729ee 2020-10-21 15:43:49 +0200 Even Rouault $")
 
 /************************************************************************/
 /*                           ~OGRDataSource()                           */
@@ -60,16 +60,8 @@ void OGR_DS_Destroy( OGRDataSourceH hDS )
 {
     if( hDS == nullptr )
         return;
-#ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
-        OGRAPISpyPreClose(hDS);
-#endif
-    delete reinterpret_cast<GDALDataset *>(hDS);
+    GDALClose( reinterpret_cast<GDALDatasetH>(hDS) );
     //VALIDATE_POINTER0( hDS, "OGR_DS_Destroy" );
-#ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
-      OGRAPISpyPostClose();
-#endif
 }
 
 /************************************************************************/
@@ -179,7 +171,7 @@ OGRErr OGR_DS_DeleteLayer( OGRDataSourceH hDS, int iLayer )
 
 #ifdef OGRAPISPY_ENABLED
     if( bOGRAPISpyEnabled )
-        OGRAPISpy_DS_DeleteLayer(hDS, iLayer);
+        OGRAPISpy_DS_DeleteLayer(reinterpret_cast<GDALDatasetH>(hDS), iLayer);
 #endif
 
     OGRErr eErr = reinterpret_cast<GDALDataset *>(hDS)->DeleteLayer( iLayer );
@@ -191,17 +183,17 @@ OGRErr OGR_DS_DeleteLayer( OGRDataSourceH hDS, int iLayer )
 /*                       OGR_DS_GetLayerByName()                        */
 /************************************************************************/
 
-OGRLayerH OGR_DS_GetLayerByName( OGRDataSourceH hDS, const char *pszName )
+OGRLayerH OGR_DS_GetLayerByName( OGRDataSourceH hDS, const char *pszLayerName )
 
 {
     VALIDATE_POINTER1( hDS, "OGR_DS_GetLayerByName", nullptr );
 
     OGRLayerH hLayer = OGRLayer::ToHandle(
-        reinterpret_cast<GDALDataset *>(hDS)->GetLayerByName( pszName ));
+        reinterpret_cast<GDALDataset *>(hDS)->GetLayerByName( pszLayerName ));
 
 #ifdef OGRAPISPY_ENABLED
     if( bOGRAPISpyEnabled )
-        OGRAPISpy_DS_GetLayerByName(hDS, pszName, hLayer);
+        OGRAPISpy_DS_GetLayerByName(reinterpret_cast<GDALDatasetH>(hDS), pszLayerName, hLayer);
 #endif
 
     return hLayer;
@@ -225,12 +217,13 @@ OGRLayerH OGR_DS_ExecuteSQL( OGRDataSourceH hDS,
 
 #ifdef OGRAPISPY_ENABLED
     if( bOGRAPISpyEnabled )
-        OGRAPISpy_DS_ExecuteSQL(hDS, pszStatement, hSpatialFilter, pszDialect, hLayer);
+        OGRAPISpy_DS_ExecuteSQL(reinterpret_cast<GDALDatasetH>(hDS), pszStatement, hSpatialFilter, pszDialect, hLayer);
 #endif
 
     return hLayer;
 }
 
+
 /************************************************************************/
 /*                      OGR_DS_ReleaseResultSet()                       */
 /************************************************************************/
@@ -242,7 +235,7 @@ void OGR_DS_ReleaseResultSet( OGRDataSourceH hDS, OGRLayerH hLayer )
 
 #ifdef OGRAPISPY_ENABLED
     if( bOGRAPISpyEnabled )
-        OGRAPISpy_DS_ReleaseResultSet(hDS, hLayer);
+        OGRAPISpy_DS_ReleaseResultSet(reinterpret_cast<GDALDatasetH>(hDS), hLayer);
 #endif
 
     reinterpret_cast<GDALDataset *>(hDS)->ReleaseResultSet( OGRLayer::FromHandle(hLayer) );
@@ -252,13 +245,13 @@ void OGR_DS_ReleaseResultSet( OGRDataSourceH hDS, OGRLayerH hLayer )
 /*                       OGR_DS_TestCapability()                        */
 /************************************************************************/
 
-int OGR_DS_TestCapability( OGRDataSourceH hDS, const char *pszCap )
+int OGR_DS_TestCapability( OGRDataSourceH hDS, const char *pszCapability )
 
 {
     VALIDATE_POINTER1( hDS, "OGR_DS_TestCapability", 0 );
-    VALIDATE_POINTER1( pszCap, "OGR_DS_TestCapability", 0 );
+    VALIDATE_POINTER1( pszCapability, "OGR_DS_TestCapability", 0 );
 
-    return reinterpret_cast<GDALDataset *>(hDS)->TestCapability( pszCap );
+    return reinterpret_cast<GDALDataset *>(hDS)->TestCapability( pszCapability );
 }
 
 /************************************************************************/
@@ -272,7 +265,7 @@ int OGR_DS_GetLayerCount( OGRDataSourceH hDS )
 
 #ifdef OGRAPISPY_ENABLED
     if( bOGRAPISpyEnabled )
-        OGRAPISpy_DS_GetLayerCount(hDS);
+        OGRAPISpy_DS_GetLayerCount(reinterpret_cast<GDALDatasetH>(hDS));
 #endif
 
     return reinterpret_cast<GDALDataset *>(hDS)->GetLayerCount();
@@ -292,7 +285,7 @@ OGRLayerH OGR_DS_GetLayer( OGRDataSourceH hDS, int iLayer )
 
 #ifdef OGRAPISPY_ENABLED
     if( bOGRAPISpyEnabled )
-        OGRAPISpy_DS_GetLayer(hDS, iLayer, hLayer);
+        OGRAPISpy_DS_GetLayer(reinterpret_cast<GDALDatasetH>(hDS), iLayer, hLayer);
 #endif
 
     return hLayer;
