@@ -31,7 +31,7 @@
 
 #include <map>
 
-CPL_CVSID("$Id: ogreditablelayer.cpp 5ab91604befd4158ee68481c627257965f2c703b 2018-09-14 21:33:02 +0200 Even Rouault $")
+CPL_CVSID("$Id: ogreditablelayer.cpp 07880b5ca268a13af619c6a1774f9696cd7f6992 2019-03-28 00:41:48 +0100 Even Rouault $")
 
 //! @cond Doxygen_Suppress
 
@@ -177,10 +177,21 @@ OGRFeature* OGREditableLayer::Translate(OGRFeatureDefn* poTargetDefn,
     OGRFeature* poRet = new OGRFeature(poTargetDefn);
 
     std::map<CPLString, int> oMapTargetFieldNameToIdx;
-    for( int iField = 0; iField < poTargetDefn->GetFieldCount(); iField++ )
+    std::map<CPLString, int>* poMap = &oMapTargetFieldNameToIdx;
+    if( poTargetDefn == m_poEditableFeatureDefn &&
+        !m_oMapEditableFDefnFieldNameToIdx.empty() )
     {
-        oMapTargetFieldNameToIdx[
-            poTargetDefn->GetFieldDefn(iField)->GetNameRef()] = iField;
+        poMap = &m_oMapEditableFDefnFieldNameToIdx;
+    }
+    else
+    {
+        for( int iField = 0; iField < poTargetDefn->GetFieldCount(); iField++ )
+        {
+            oMapTargetFieldNameToIdx[
+                poTargetDefn->GetFieldDefn(iField)->GetNameRef()] = iField;
+        }
+        if( poTargetDefn == m_poEditableFeatureDefn )
+            m_oMapEditableFDefnFieldNameToIdx = oMapTargetFieldNameToIdx;
     }
 
     int* panMap = static_cast<int *>(CPLMalloc( sizeof(int) * poSrcFeature->GetFieldCount() ));
@@ -194,9 +205,9 @@ OGRFeature* OGREditableLayer::Translate(OGRFeatureDefn* poTargetDefn,
         }
         else
         {
-            auto oIter = oMapTargetFieldNameToIdx.find(pszFieldName);
+            auto oIter = poMap->find(pszFieldName);
             panMap[iField] =
-                (oIter == oMapTargetFieldNameToIdx.end()) ? -1 : oIter->second;
+                (oIter == poMap->end()) ? -1 : oIter->second;
         }
     }
     poRet->SetFieldsFrom( poSrcFeature, panMap, TRUE );
@@ -342,6 +353,19 @@ OGRErr      OGREditableLayer::ISetFeature( OGRFeature *poFeature )
 {
     if( !m_poDecoratedLayer ) return OGRERR_FAILURE;
 
+    if( !m_bStructureModified &&
+        m_oSetDeleted.empty() &&
+        m_oSetEdited.empty() &&
+        m_oSetCreated.empty() &&
+        m_poDecoratedLayer->TestCapability(OLCRandomWrite) )
+    {
+        OGRFeature* poTargetFeature = Translate(m_poDecoratedLayer->GetLayerDefn(),
+                                                poFeature, false, false);
+        OGRErr eErr = m_poDecoratedLayer->SetFeature(poTargetFeature);
+        delete poTargetFeature;
+        return eErr;
+    }
+
     OGRFeature* poMemFeature = Translate(m_poMemLayer->GetLayerDefn(),
                                          poFeature, false, false);
     OGRErr eErr = m_poMemLayer->SetFeature(poMemFeature);
@@ -370,11 +394,15 @@ OGRErr      OGREditableLayer::ICreateFeature( OGRFeature *poFeature )
     if( !m_poDecoratedLayer ) return OGRERR_FAILURE;
 
     if( !m_bStructureModified &&
+        m_oSetDeleted.empty() &&
+        m_oSetCreated.empty() &&
         m_poDecoratedLayer->TestCapability(OLCSequentialWrite) )
     {
         OGRFeature* poTargetFeature = Translate(m_poDecoratedLayer->GetLayerDefn(),
                                                 poFeature, false, false);
         OGRErr eErr = m_poDecoratedLayer->CreateFeature(poTargetFeature);
+        if( poFeature->GetFID() < 0 )
+            poFeature->SetFID(poTargetFeature->GetFID());
         delete poTargetFeature;
         return eErr;
     }
@@ -622,7 +650,8 @@ int         OGREditableLayer::TestCapability( const char * pszCap )
         EQUAL(pszCap, OLCAlterFieldDefn) ||
         EQUAL(pszCap, OLCDeleteFeature) )
     {
-        return TRUE;
+        return m_poDecoratedLayer->TestCapability(OLCCreateField) == TRUE ||
+               m_poDecoratedLayer->TestCapability(OLCSequentialWrite) == TRUE;
     }
     if( EQUAL(pszCap, OLCCreateGeomField) )
         return m_bSupportsCreateGeomField;
@@ -643,6 +672,8 @@ OGRErr      OGREditableLayer::CreateField( OGRFieldDefn *poField,
 {
     if( !m_poDecoratedLayer ) return OGRERR_FAILURE;
 
+    m_oMapEditableFDefnFieldNameToIdx.clear();
+
     // workarounds a bug in certain QGIS versions (2.0 for example)
     SetIgnoredFields(nullptr);
 
@@ -678,6 +709,8 @@ OGRErr      OGREditableLayer::DeleteField( int iField )
 {
     if( !m_poDecoratedLayer ) return OGRERR_FAILURE;
 
+    m_oMapEditableFDefnFieldNameToIdx.clear();
+
     // workarounds a bug in certain QGIS versions (2.0 for example)
     SetIgnoredFields(nullptr);
 
@@ -704,6 +737,9 @@ OGRErr      OGREditableLayer::DeleteField( int iField )
 OGRErr      OGREditableLayer::ReorderFields( int* panMap )
 {
     if( !m_poDecoratedLayer ) return OGRERR_FAILURE;
+
+    m_oMapEditableFDefnFieldNameToIdx.clear();
+
     OGRErr eErr = m_poMemLayer->ReorderFields(panMap);
     if( eErr == OGRERR_NONE )
     {
@@ -722,6 +758,9 @@ OGRErr      OGREditableLayer::AlterFieldDefn( int iField,
                                               int nFlagsIn )
 {
     if( !m_poDecoratedLayer ) return OGRERR_FAILURE;
+
+    m_oMapEditableFDefnFieldNameToIdx.clear();
+
     OGRErr eErr = m_poMemLayer->AlterFieldDefn(iField, poNewFieldDefn, nFlagsIn);
     if( eErr == OGRERR_NONE )
     {
