@@ -31,7 +31,7 @@
 #include "ogr_api.h"
 #include "ograpispy.h"
 
-CPL_CVSID("$Id: ogrsfdriverregistrar.cpp b1c9c12ad373e40b955162b45d704070d4ebf7b0 2019-06-19 16:50:15 +0200 Even Rouault $")
+CPL_CVSID("$Id: ogrsfdriverregistrar.cpp ba3554dcc5a5f63eb7bc2a92a6cbb3f995b729ee 2020-10-21 15:43:49 +0200 Even Rouault $")
 
 /************************************************************************/
 /*                         OGRSFDriverRegistrar                         */
@@ -106,19 +106,11 @@ OGRDataSourceH OGROpen( const char *pszName, int bUpdate,
 {
     VALIDATE_POINTER1( pszName, "OGROpen", nullptr );
 
-#ifdef OGRAPISPY_ENABLED
-    int iSnapshot = OGRAPISpyOpenTakeSnapshot(pszName, bUpdate);
-#endif
-
     GDALDatasetH hDS = GDALOpenEx(pszName, GDAL_OF_VECTOR |
                             ((bUpdate) ? GDAL_OF_UPDATE: 0), nullptr, nullptr, nullptr);
     if( hDS != nullptr && pahDriverList != nullptr )
         *pahDriverList = reinterpret_cast<OGRSFDriverH>(GDALGetDatasetDriver(hDS));
 
-#ifdef OGRAPISPY_ENABLED
-    OGRAPISpyOpen(pszName, bUpdate, iSnapshot, &hDS);
-#endif
-
     return reinterpret_cast<OGRDataSourceH>(hDS);
 }
 
@@ -148,17 +140,8 @@ OGRErr OGRReleaseDataSource( OGRDataSourceH hDS )
 {
     VALIDATE_POINTER1( hDS, "OGRReleaseDataSource", OGRERR_INVALID_HANDLE );
 
-#ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
-        OGRAPISpyPreClose(hDS);
-#endif
     GDALClose( reinterpret_cast<GDALDatasetH>(hDS) );
 
-#ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
-        OGRAPISpyPostClose();
-#endif
-
     return OGRERR_NONE;
 }
 
